# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'
require 'tg_mdk/mdk_dto/pay_now_id_param'
require 'tg_mdk/mdk_dto/account_param'
require 'tg_mdk/mdk_dto/card_param'
require 'tg_mdk/mdk_dto/recurring_charge_param'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =カード決済、MPIのみ継承する親クラス
      #
      # @author:: VeriTrans Inc.
      #
      class AbstractPaymentCreditRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # === タンキングフラグを取得する
        # @return:: tanking タンキングフラグ
        #
        def tanking
          pay_now_id_param.tanking
        end

        #
        # === タンキングフラグを設定する
        # タンキングフラグを指定します。
        # @param:: tanking タンキングフラグ
        #
        def tanking=(tanking)
          pay_now_id_param.tanking = tanking
        end

        #
        # === カードIDを取得する
        # @return:: カードID
        #
        def card_id
          exist_card_param
          return pay_now_id_param.account_param.card_param.card_id
        end

        #
        # === カードIDを設定する
        # カードIDを指定します。
        # @param:: card_id カードID
        #
        def card_id=(card_id)
          exist_card_param
          pay_now_id_param.account_param.card_param.card_id = card_id
        end

        #
        # === 標準カードフラグを取得する
        # @return:: 標準カードフラグ
        #
        def default_card
          exist_card_param
          return pay_now_id_param.account_param.card_param.default_card
        end

        #
        # === 標準カードフラグを設定する
        # 標準カードフラグを指定します。
        # @param:: default_card 標準カードフラグ
        #
        def default_card=(default_card)
          exist_card_param
          pay_now_id_param.account_param.card_param.default_card = default_card
        end

        #
        # === 洗替実施フラグを取得する
        # @return:: 洗替実施フラグ
        #
        def updater
          exist_card_param
          return pay_now_id_param.account_param.card_param.updater
        end

        #
        # === 洗替実施フラグを設定する
        # 洗替実施フラグを指定します。
        # @param:: updater 洗替実施フラグ
        #
        def updater=(updater)
          exist_card_param
          pay_now_id_param.account_param.card_param.updater = updater
        end

        #
        # ===トークンを取得する
        # @return:: トークン
        #
        def token
          pay_now_id_param.token
        end

        #
        # ===トークンを設定する
        # トークンを指定します。
        # @param:: token トークン
        #
        def token=(token)
          pay_now_id_param.token = token
        end

        #
        # ===会員IDワンタイムトークンを取得する
        # @return:: ワンタイムトークン
        #
        def onetime_token
          exist_account_param
          return pay_now_id_param.account_param.onetime_token
        end

        #
        # ===会員IDワンタイムトークンを設定する
        # 会員IDワンタイムトークンを指定します。
        # @param:: onetime_token ワンタイムトークン
        #
        def onetime_token=(onetime_token)
          exist_account_param
          pay_now_id_param.account_param.onetime_token = onetime_token
        end

        #
        # === 課金グループIDを取得する
        # @return:: 課金グループID
        #
        def group_id
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.group_id
        end

        #
        # === 課金グループIDを設定する
        # 課金グループIDを指定します。
        # @param:: group_id 課金グループID
        #
        def group_id=(group_id)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.group_id = group_id
        end

        #
        # === 課金開始日を取得する
        # @return:: 課金開始日
        #
        def start_date
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.start_date
        end

        #
        # === 課金開始日を設定する
        # 課金開始日を指定します。
        # @param:: start_date 課金開始日
        #
        def start_date=(start_date)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.start_date = start_date
        end

        #
        # === 課金終了日を取得する
        # @return:: 課金終了日
        #
        def end_date
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.end_date
        end

        #
        # === 課金終了日を設定する
        # 終了開始日を指定します。
        # @param:: end_date 課金終了日
        #
        def end_date=(end_date)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.end_date = end_date
        end

        #
        # === 都度/初回課金金額を取得する
        # @return:: 都度/初回課金金額
        #
        def one_time_amount
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.one_time_amount
        end

        #
        # === 都度/初回課金金額を設定する
        # 都度/初回課金金額を指定します。
        # @param:: one_time_amount 都度/初回課金金額
        #
        def one_time_amount=(one_time_amount)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.one_time_amount = one_time_amount
        end

        #
        # === 継続課金金額を取得する
        # @return:: 継続課金金額
        #
        def recurring_amount
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.amount
        end

        #
        # === 継続課金金額を設定する
        # 継続課金金額を指定します。
        # @param:: recurring_amount 継続課金金額
        #
        def recurring_amount=(recurring_amount)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.amount = recurring_amount
        end

        #
        # === 継続課金用メモ1を取得する
        # @return:: 継続課金用メモ1
        #
        def recurring_memo1
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.recurring_memo1
        end

        #
        # === 継続課金用メモ1を設定する
        # 継続課金用メモ1を指定します。
        # @param:: recurring_memo1 継続課金用メモ1
        #
        def recurring_memo1=(recurring_memo1)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.recurring_memo1 = recurring_memo1
        end

        #
        # === 継続課金用メモ2を取得する
        # @return:: 継続課金用メモ2
        #
        def recurring_memo2
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.recurring_memo2
        end

        #
        # === 継続課金用メモ2を設定する
        # 継続課金用メモ2を指定します。
        # @param:: recurring_memo2 継続課金用メモ2
        #
        def recurring_memo2=(recurring_memo2)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.recurring_memo2 = recurring_memo2
        end

        #
        # === 継続課金用メモ3を取得する
        # @return:: 継続課金用メモ3
        #
        def recurring_memo3
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.recurring_memo3
        end

        #
        # === 継続課金用メモ3を設定する
        # 継続課金用メモ3を指定します。
        # @param:: recurring_memo3 継続課金用メモ3
        #
        def recurring_memo3=(recurring_memo3)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.recurring_memo3 = recurring_memo3
        end

        #
        # === 課金オプション利用フラグを取得する
        # @return:: 課金オプション利用フラグ
        #
        def use_charge_option
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.use_charge_option
        end

        #
        # === 課金オプション利用フラグを設定する
        # 課金オプション利用フラグを指定します。
        # @param:: use_charge_option 課金オプション利用フラグ
        #
        def use_charge_option=(use_charge_option)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.use_charge_option = use_charge_option
        end

        #
        # === 売上日を取得する
        # @return:: 売上日
        #
        def recurring_sales_day
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.sales_day
        end

        #
        # === 売上日を設定する
        # 売上日を指定します。
        # @param:: recurring_sales_day 売上日
        #
        def recurring_sales_day=(recurring_sales_day)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.sales_day = recurring_sales_day
        end

        #
        # === 仕向先会社コードを取得する
        # @return:: 仕向先会社コード
        #
        def recurring_acquire_code
          exist_recurring_charge_param
          return pay_now_id_param.account_param.exist_recurring_charge_param.acquire_code
        end

        #
        # === 仕向先会社コードを設定する
        # 仕向先会社コードを指定します。
        # @param:: recurring_acquire_code 仕向先会社コード
        #
        def recurring_acquire_code=(recurring_acquire_code)
          exist_recurring_charge_param
          pay_now_id_param.account_param.recurring_charge_param.acquire_code = recurring_acquire_code
        end

        private

        #
        # === account_paramが設定されているか判定する
        # account_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、pay_now_id_paramに設定します。
        #
        def exist_account_param
          if pay_now_id_param.account_param.nil?
            pay_now_id_param.account_param = AccountParam.new
          end
        end

        #
        # === card_paramが設定されているか判定する
        # card_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_card_param
          exist_account_param
          if pay_now_id_param.account_param.card_param.nil?
            pay_now_id_param.account_param.card_param = CardParam.new
          end
        end

        #
        # === recurring_charge_paramが設定されているか判定する
        # recurring_charge_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_recurring_charge_param
          exist_account_param
          if pay_now_id_param.account_param.recurring_charge_param.nil?
            pay_now_id_param.account_param.recurring_charge_param = RecurringChargeParam.new
          end
        end

      end
    end
  end
end
