# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'
require 'tg_mdk/mdk_dto/pay_now_id_param'
require 'tg_mdk/mdk_dto/account_param'
require 'tg_mdk/mdk_dto/bank_account_param'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =銀行振込決済のみ継承する親クラス
      #
      # @author:: VeriTrans Inc.
      #
      class AbstractPaymentVirtualaccRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===銀行口座関連付け拒否フラグを取得する
        # @return:: 銀行口座関連付け拒否フラグ
        #
        def reject_bank_account
          exist_bank_account_param
          return pay_now_id_param.account_param.bank_account_param.reject_bank_account
        end

        #
        # ===銀行口座関連付け拒否フラグを設定する
        # 銀行口座関連付け拒否フラグを指定します。
        # @param:: reject_bank_account 銀行口座関連付け拒否フラグ
        #
        def reject_bank_account=(reject_bank_account)
          exist_bank_account_param
          pay_now_id_param.account_param.bank_account_param.reject_bank_account = reject_bank_account
        end

        private

        #
        # === account_paramが設定されているか判定する
        # account_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、pay_now_id_paramに設定します。
        #
        def exist_account_param
          if pay_now_id_param.account_param.nil?
            pay_now_id_param.account_param = AccountParam.new
          end
        end

        #
        # ===bank_account_paramが設定されているか判定する
        # bank_account_paramが設定されているか判定します。
        # 設定されていない場合はインスタンスを生成し、account_paramに設定します。
        #
        def exist_bank_account_param
          exist_account_param
          if pay_now_id_param.account_param.bank_account_param.nil?
            pay_now_id_param.account_param.bank_account_param = BankAccountParam.new
          end
        end

      end
    end
  end
end
