# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：Alipay、コマンド名：与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class AlipayAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
          @with_capture = WITH_CAPTURE
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "alipay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"

        #
        # 売上フラグ
        # "true"： 与信・売上
        #
        WITH_CAPTURE = "true"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を日本円と中国元で指定します。
        # - 日本円(JPY)：1 - 9999999
        # - 中国元(CNY)：100 - 5000000
        #                      取引金額を100倍した値を指定します。（amount=決済金額×100）
        #                      上限金額は中国元換算で50,000元。
        # （例　
        # 日本円：1円の場合は1を指定します。
        # 中国元：1.99元の場合は199を指定します。）
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===通貨を取得する
        # @return:: 通貨
        #
        def currency
          @currency = nil unless instance_variable_defined?(:@currency)
          @currency
        end

        #
        # ===通貨を設定する
        # 決済通貨を指定します。
        # "JPY"：日本円
        # "CNY"：中国元（オンライン決済のみ）
        # @param:: currency 通貨
        #
        def currency=(currency)
          @currency = currency
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 決済完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # payType=0（オンライン決済）：指定必須
        # payType=1（バーコード決済（店舗スキャン型））：指定できません
        # payType=2（バーコード決済（消費者スキャン型））：指定できません
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 決済エラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # payType=0（オンライン決済）：指定必須
        # payType=1（バーコード決済（店舗スキャン型））：指定できません
        # payType=2（バーコード決済（消費者スキャン型））：指定できません
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def commodity_name
          @commodity_name = nil unless instance_variable_defined?(:@commodity_name)
          @commodity_name
        end

        #
        # ===商品名を設定する
        # 商品名
        # - 文字列100桁以内
        # 
        # payType=0（オンライン決済）：指定必須
        # payType=1（バーコード決済（店舗スキャン型））：指定必須
        # payType=2（バーコード決済（消費者スキャン型））：指定必須
        # @param:: commodity_name 商品名
        #
        def commodity_name=(commodity_name)
          @commodity_name = commodity_name
        end

        #
        # ===商品詳細を取得する
        # @return:: 商品詳細
        #
        def commodity_description
          @commodity_description = nil unless instance_variable_defined?(:@commodity_description)
          @commodity_description
        end

        #
        # ===商品詳細を設定する
        # 商品詳細
        # - 文字列200桁以内
        # 
        # payType=0（オンライン決済）：指定任意 
        # payType=1（バーコード決済（店舗スキャン型））：指定できません
        # payType=2（バーコード決済（消費者スキャン型））：指定任意（商品詳細を指定する場合は商品IDの指定が必須）
        # @param:: commodity_description 商品詳細
        #
        def commodity_description=(commodity_description)
          @commodity_description = commodity_description
        end

        #
        # ===商品IDを取得する
        # @return:: 商品ID
        #
        def commodity_id
          @commodity_id = nil unless instance_variable_defined?(:@commodity_id)
          @commodity_id
        end

        #
        # ===商品IDを設定する
        # マーチャントシステム内で商品やサービスを特定するID
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定できません
        # payType=2（バーコード決済（消費者スキャン型））：指定任意
        # @param:: commodity_id 商品ID
        #
        def commodity_id=(commodity_id)
          @commodity_id = commodity_id
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上（設定可能な値は"true"のみです。）
        # ※未指定の場合は、true:与信同時売上。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===決済種別を取得する
        # @return:: 決済種別
        #
        def pay_type
          @pay_type = nil unless instance_variable_defined?(:@pay_type)
          @pay_type
        end

        #
        # ===決済種別を設定する
        # 決済種別を指定します。
        # "0"：オンライン決済
        # "1"：バーコード決済（店舗スキャン型）
        # "2"：バーコード決済（消費者スキャン型）
        # ※未指定の場合は、0：オンライン決済。
        # @param:: pay_type 決済種別
        #
        def pay_type=(pay_type)
          @pay_type = pay_type
        end

        #
        # ===ユーザ識別コードを取得する
        # @return:: ユーザ識別コード
        #
        def identity_code
          @identity_code = nil unless instance_variable_defined?(:@identity_code)
          @identity_code
        end

        #
        # ===ユーザ識別コードを設定する
        # 消費者をAlipayユーザとして識別するためのコードを指定します。
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定必須
        # payType=2（バーコード決済（消費者スキャン型））：指定できません
        # @param:: identity_code ユーザ識別コード
        #
        def identity_code=(identity_code)
          @identity_code = identity_code
        end

        #
        # ===レスポンスタイプを取得する
        # @return:: レスポンスタイプ
        #
        def response_type
          @response_type = nil unless instance_variable_defined?(:@response_type)
          @response_type
        end

        #
        # ===レスポンスタイプを設定する
        # レスポンスのタイプを指定します。
        # "0"：取引確定時にレスポンスを返却する。
        # "1"：即時にレスポンスを返却する。（取引確定については、Confirmコマンドを利用する）
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定任意
        # payType=2（バーコード決済（消費者スキャン型））：指定できません
        # 
        # ※未指定の場合は、0：取引確定時にレスポンスを返却する。
        # @param:: response_type レスポンスタイプ
        #
        def response_type=(response_type)
          @response_type = response_type
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定任意
        # payType=2（バーコード決済（消費者スキャン型））：指定任意
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗名を取得する
        # @return:: 店舗名
        #
        def store_name
          @store_name = nil unless instance_variable_defined?(:@store_name)
          @store_name
        end

        #
        # ===店舗名を設定する
        # 店舗名を指定します。
        # - 最大文字数：64byte
        # 
        # payType=0（オンライン決済）：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定任意
        # payType=2（バーコード決済（消費者スキャン型））：指定任意
        # @param:: store_name 店舗名
        #
        def store_name=(store_name)
          @store_name = store_name
        end

        #
        # ===デバイスタイプを取得する
        # @return:: デバイスタイプ
        #
        def device_type
          @device_type = nil unless instance_variable_defined?(:@device_type)
          @device_type
        end

        #
        # ===デバイスタイプを設定する
        # デバイスのタイプを指定します。
        # "0"：PC
        # "1"：スマートフォン
        # 
        # payType=0（オンライン決済）：指定任意
        # payType=1（バーコード決済（店舗スキャン型））：指定できません
        # payType=2（バーコード決済（消費者スキャン型））：指定できません
        # 
        # ※未指定の場合は、0：PC
        # @param:: device_type デバイスタイプ
        #
        def device_type=(device_type)
          @device_type = device_type
        end


      end
    end
  end
end
