# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/response_base_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：Alipay、コマンド名：決済確認の応答Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class AlipayConfirmResponseDto < Veritrans::Tercerog::Mdk::ResponseBaseDto

        #
        # ===決済サービスタイプを取得する
        # 決済サービスの区分が固定値として指定されます。
        # "alipay"： Alipay決済
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスタイプを設定する
        # @param:: service_type 決済サービスタイプ
        #
        def service_type=(service_type)
          @service_type = service_type
        end

        #
        # ===処理結果コードを取得する
        # 確認請求処理後、応答電文に含まれる値。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # - pending：保留状態
        # @return:: 処理結果コード
        #
        def mstatus
          @mstatus = nil unless instance_variable_defined?(:@mstatus)
          @mstatus
        end

        #
        # ===処理結果コードを設定する
        # @param:: mstatus 処理結果コード
        #
        def mstatus=(mstatus)
          @mstatus = mstatus
        end

        #
        # ===詳細結果コードを取得する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @return:: 詳細結果コード
        #
        def v_result_code
          @v_result_code = nil unless instance_variable_defined?(:@v_result_code)
          @v_result_code
        end

        #
        # ===詳細結果コードを設定する
        # @param:: v_result_code 詳細結果コード
        #
        def v_result_code=(v_result_code)
          @v_result_code = v_result_code
        end

        #
        # ===エラーメッセージを取得する
        # 処理結果に対するメッセージを返却します。
        # @return:: エラーメッセージ
        #
        def merr_msg
          @merr_msg = nil unless instance_variable_defined?(:@merr_msg)
          @merr_msg
        end

        #
        # ===エラーメッセージを設定する
        # @param:: merr_msg エラーメッセージ
        #
        def merr_msg=(merr_msg)
          @merr_msg = merr_msg
        end

        #
        # ===電文IDを取得する
        # @return:: 電文ID
        #
        def march_txn
          @march_txn = nil unless instance_variable_defined?(:@march_txn)
          @march_txn
        end

        #
        # ===電文IDを設定する
        # @param:: march_txn 電文ID
        #
        def march_txn=(march_txn)
          @march_txn = march_txn
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===取引毎に付くIDを取得する
        # @return:: 取引毎に付くID
        #
        def cust_txn
          @cust_txn = nil unless instance_variable_defined?(:@cust_txn)
          @cust_txn
        end

        #
        # ===取引毎に付くIDを設定する
        # @param:: cust_txn 取引毎に付くID
        #
        def cust_txn=(cust_txn)
          @cust_txn = cust_txn
        end

        #
        # ===MDKバージョンを取得する
        # 電文のバージョン番号を返却します。
        # @return:: MDKバージョン
        #
        def txn_version
          @txn_version = nil unless instance_variable_defined?(:@txn_version)
          @txn_version
        end

        #
        # ===MDKバージョンを設定する
        # @param:: txn_version MDKバージョン
        #
        def txn_version=(txn_version)
          @txn_version = txn_version
        end

        #
        # ===決済センターとの取引IDを取得する
        # VeriTrans4Gが発番するID
        # @return:: 決済センターとの取引ID
        #
        def center_trade_id
          @center_trade_id = nil unless instance_variable_defined?(:@center_trade_id)
          @center_trade_id
        end

        #
        # ===決済センターとの取引IDを設定する
        # @param:: center_trade_id 決済センターとの取引ID
        #
        def center_trade_id=(center_trade_id)
          @center_trade_id = center_trade_id
        end

        #
        # ===決済時刻（日本時間）を取得する
        # Alipayで決済が確定した日時（日本時間） を返します。
        # @return:: 決済時刻（日本時間）
        #
        def pay_time_jp
          @pay_time_jp = nil unless instance_variable_defined?(:@pay_time_jp)
          @pay_time_jp
        end

        #
        # ===決済時刻（日本時間）を設定する
        # @param:: pay_time_jp 決済時刻（日本時間）
        #
        def pay_time_jp=(pay_time_jp)
          @pay_time_jp = pay_time_jp
        end

        #
        # ===決済時刻（中国時間）を取得する
        # Alipayで決済が確定した日時（中国時間） を返します。
        # @return:: 決済時刻（中国時間）
        #
        def pay_time_cn
          @pay_time_cn = nil unless instance_variable_defined?(:@pay_time_cn)
          @pay_time_cn
        end

        #
        # ===決済時刻（中国時間）を設定する
        # @param:: pay_time_cn 決済時刻（中国時間）
        #
        def pay_time_cn=(pay_time_cn)
          @pay_time_cn = pay_time_cn
        end

        #
        # ===請求金額（中国元）を取得する
        # Alipayから請求される金額（中国元）
        # @return:: 請求金額（中国元）
        #
        def buyer_charged_amount_cny
          @buyer_charged_amount_cny = nil unless instance_variable_defined?(:@buyer_charged_amount_cny)
          @buyer_charged_amount_cny
        end

        #
        # ===請求金額（中国元）を設定する
        # @param:: buyer_charged_amount_cny 請求金額（中国元）
        #
        def buyer_charged_amount_cny=(buyer_charged_amount_cny)
          @buyer_charged_amount_cny = buyer_charged_amount_cny
        end


        #
        # ===PayNowIDオブジェクトを取得する
        # @return:: PayNowIDオブジェクト
        #
        def pay_now_id_response
          @pay_now_id_response = nil unless instance_variable_defined?(:@pay_now_id_response)
          @pay_now_id_response
        end

        #
        # ===PayNowIDオブジェクトを設定する
        # @param:: pay_now_id_response PayNowIDオブジェクト
        #
        def pay_now_id_response=(pay_now_id_response)
          @pay_now_id_response = pay_now_id_response
        end

      end
    end
  end
end
