# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：alipayx、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class AlipayxAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "alipayx"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "barcode":バーコード決済
        # - "scancode":スキャンコード決済
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 999999999999(12桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上（設定可能な値は"true"のみです。）
        # ※未指定の場合は、true:与信同時売上。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===レスポンスタイプを取得する
        # @return:: レスポンスタイプ
        #
        def response_type
          @response_type = nil unless instance_variable_defined?(:@response_type)
          @response_type
        end

        #
        # ===レスポンスタイプを設定する
        # レスポンスのタイプを指定します。
        # "0"：取引確定時にレスポンスを返却する。
        # "1"：即時にレスポンスを返却する。（取引確定については、Confirmコマンドを利用する）
        # 
        # serviceOptionType="barcode"：指定任意
        # 上記以外、指定不可。
        # ※未指定の場合は、0：取引確定時にレスポンスを返却する。
        # @param:: response_type レスポンスタイプ
        #
        def response_type=(response_type)
          @response_type = response_type
        end

        #
        # ===識別コードを取得する
        # @return:: 識別コード
        #
        def identity_code
          @identity_code = nil unless instance_variable_defined?(:@identity_code)
          @identity_code
        end

        #
        # ===識別コードを設定する
        # 識別コードを指定します。
        # ※serviceOptionType="barcode"：指定必須
        # 上記以外、指定不可。
        # @param:: identity_code 識別コード
        #
        def identity_code=(identity_code)
          @identity_code = identity_code
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def order_title
          @order_title = nil unless instance_variable_defined?(:@order_title)
          @order_title
        end

        #
        # ===商品名を設定する
        # 商品名を指定します。
        # - 最大文字数:256byte
        # @param:: order_title 商品名
        #
        def order_title=(order_title)
          @order_title = order_title
        end

        #
        # ===商品詳細を取得する
        # @return:: 商品詳細
        #
        def order_detail
          @order_detail = nil unless instance_variable_defined?(:@order_detail)
          @order_detail
        end

        #
        # ===商品詳細を設定する
        # 識別コードを指定します。
        # - 最大文字数:400byte
        # @param:: order_detail 商品詳細
        #
        def order_detail=(order_detail)
          @order_detail = order_detail
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗IDを指定します。
        # ※半角英数字、"-"（ハイフン）、 "_"（アンダースコア）も使用可能です。
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗名を取得する
        # @return:: 店舗名
        #
        def store_name
          @store_name = nil unless instance_variable_defined?(:@store_name)
          @store_name
        end

        #
        # ===店舗名を設定する
        # 店舗名を指定します。
        # - 最大文字数:128byte
        # @param:: store_name 店舗名
        #
        def store_name=(store_name)
          @store_name = store_name
        end

        #
        # ===端末IDを取得する
        # @return:: 端末ID
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===端末IDを設定する
        # 端末IDを指定します。
        # ※半角英数字、"-"（ハイフン）、 "_"（アンダースコア）も使用可能です。
        # @param:: terminal_id 端末ID
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===従業員IDを取得する
        # @return:: 従業員ID
        #
        def operator_id
          @operator_id = nil unless instance_variable_defined?(:@operator_id)
          @operator_id
        end

        #
        # ===従業員IDを設定する
        # 従業員IDを指定します。
        # ※半角英数字、"-"（ハイフン）、 "_"（アンダースコア）も使用可能です。
        # @param:: operator_id 従業員ID
        #
        def operator_id=(operator_id)
          @operator_id = operator_id
        end

        #
        # ===スキャンコードタイプを取得する
        # @return:: スキャンコードタイプ
        #
        def scancode_type
          @scancode_type = nil unless instance_variable_defined?(:@scancode_type)
          @scancode_type
        end

        #
        # ===スキャンコードタイプを設定する
        # シーンのタイプを指定します。
        # "0"：サービスプロバイダー発行QR利用。
        # "1"：加盟店発行QR利用。
        # 
        # serviceOptionType="scancode"：指定任意
        # 上記以外、指定不可。
        # ※未指定の場合は、0：サービスプロバイダー発行QR利用。
        # @param:: scancode_type スキャンコードタイプ
        #
        def scancode_type=(scancode_type)
          @scancode_type = scancode_type
        end

        #
        # ===ユーザーエージェントを取得する
        # @return:: ユーザーエージェント
        #
        def user_agent
          @user_agent = nil unless instance_variable_defined?(:@user_agent)
          @user_agent
        end

        #
        # ===ユーザーエージェントを設定する
        # ユーザーエージェントを指定します。
        # - 最大文字数:1024byte
        # serviceOptionType="scancode"、かつ、scancodeType="1"の場合、指定必須
        # 上記以外、指定不可。
        # @param:: user_agent ユーザーエージェント
        #
        def user_agent=(user_agent)
          @user_agent = user_agent
        end

        #
        # ===決済成功時リダイレクトURLを取得する
        # @return:: 決済成功時リダイレクトURL
        #
        def success_redirect_url
          @success_redirect_url = nil unless instance_variable_defined?(:@success_redirect_url)
          @success_redirect_url
        end

        #
        # ===決済成功時リダイレクトURLを設定する
        # 決済成功時にリダイレクトするURLを指定します。
        # serviceOptionType="scancode"、かつ、scancodeType="1"の場合、指定任意
        # 上記以外、指定不可。
        # @param:: success_redirect_url 決済成功時リダイレクトURL
        #
        def success_redirect_url=(success_redirect_url)
          @success_redirect_url = success_redirect_url
        end


      end
    end
  end
end
