# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：Amazonpay、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class AmazonpayAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "amazonpay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===課金種別を取得する
        # @return:: 課金種別
        #
        def accounting_type
          @accounting_type = nil unless instance_variable_defined?(:@accounting_type)
          @accounting_type
        end

        #
        # ===課金種別を設定する
        # "0"：都度決済
        # "1"：随時決済
        # ※未指定の場合は、"0"：都度決済となります。
        # @param:: accounting_type 課金種別
        #
        def accounting_type=(accounting_type)
          @accounting_type = accounting_type
        end

        #
        # ===承諾時決済タイプを取得する
        # @return:: 承諾時決済タイプ
        #
        def consent_auth_type
          @consent_auth_type = nil unless instance_variable_defined?(:@consent_auth_type)
          @consent_auth_type
        end

        #
        # ===承諾時決済タイプを設定する
        # "0"：承諾のみ
        # "1"：与信＋承諾
        # ※課金種別が都度決済の場合は 指定できません。
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: consent_auth_type 承諾時決済タイプ
        #
        def consent_auth_type=(consent_auth_type)
          @consent_auth_type = consent_auth_type
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 課金種別が都度決済の場合：1 以上かつ 10000000(8桁) 以下
        # - 課金種別が随時決済の場合：1 以上かつ 100000(6桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # "true"： 与信同時売上
        # "false"： 与信のみ
        # ※指定が無い場合は、与信のみとなります。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===配送先表示抑止フラグを取得する
        # @return:: 配送先表示抑止フラグ
        #
        def suppress_shipping_address_view
          @suppress_shipping_address_view = nil unless instance_variable_defined?(:@suppress_shipping_address_view)
          @suppress_shipping_address_view
        end

        #
        # ===配送先表示抑止フラグを設定する
        # "true"： 配送先非表示
        # "false"： 配送先表示
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: suppress_shipping_address_view 配送先表示抑止フラグ
        #
        def suppress_shipping_address_view=(suppress_shipping_address_view)
          @suppress_shipping_address_view = suppress_shipping_address_view
        end

        #
        # ===プラットフォームIDを取得する
        # @return:: プラットフォームID
        #
        def platform_id
          @platform_id = nil unless instance_variable_defined?(:@platform_id)
          @platform_id
        end

        #
        # ===プラットフォームIDを設定する
        # Amazonから指定のあった場合のみ設定する予定の項目
        # - 最大:21byte
        # @param:: platform_id プラットフォームID
        #
        def platform_id=(platform_id)
          @platform_id = platform_id
        end

        #
        # ===注文説明を取得する
        # @return:: 注文説明
        #
        def note_to_buyer
          @note_to_buyer = nil unless instance_variable_defined?(:@note_to_buyer)
          @note_to_buyer
        end

        #
        # ===注文説明を設定する
        # 購入者のメールに表示される注文の説明
        # - 最大:255文字
        # @param:: note_to_buyer 注文説明
        #
        def note_to_buyer=(note_to_buyer)
          @note_to_buyer = note_to_buyer
        end

        #
        # ===完了時URLを取得する
        # @return:: 完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===完了時URLを設定する
        # 決済申込成功時に、店舗側サイトに画面遷移を戻すためのURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: success_url 完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===キャンセル時URLを取得する
        # @return:: キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===キャンセル時URLを設定する
        # 決済申込を消費者がキャンセルした時に、店舗側サイトに画面遷移を戻すためのURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: cancel_url キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===エラー時URLを取得する
        # @return:: エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===エラー時URLを設定する
        # 決済申込エラー時に、店舗側サイトに画面遷移を戻すためのURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: error_url エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===与信時プッシュ先URLを取得する
        # @return:: 与信時プッシュ先URL
        #
        def authorize_push_url
          @authorize_push_url = nil unless instance_variable_defined?(:@authorize_push_url)
          @authorize_push_url
        end

        #
        # ===与信時プッシュ先URLを設定する
        # 決済申込、再与信要求および与信変更要求が成立（成功または失敗）した時に、結果通知電文をプッシュする先のURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: authorize_push_url 与信時プッシュ先URL
        #
        def authorize_push_url=(authorize_push_url)
          @authorize_push_url = authorize_push_url
        end

        #
        # ===売上時プッシュ先URLを取得する
        # @return:: 売上時プッシュ先URL
        #
        def capture_push_url
          @capture_push_url = nil unless instance_variable_defined?(:@capture_push_url)
          @capture_push_url
        end

        #
        # ===売上時プッシュ先URLを設定する
        # 売上要求の処理結果が確定（成功または失敗）した時に、結果通知電文をプッシュする先のURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: capture_push_url 売上時プッシュ先URL
        #
        def capture_push_url=(capture_push_url)
          @capture_push_url = capture_push_url
        end

        #
        # ===キャンセル時プッシュ先URLを取得する
        # @return:: キャンセル時プッシュ先URL
        #
        def cancel_push_url
          @cancel_push_url = nil unless instance_variable_defined?(:@cancel_push_url)
          @cancel_push_url
        end

        #
        # ===キャンセル時プッシュ先URLを設定する
        # キャンセル要求、返金要求および解約要求の処理結果が確定（成功または失敗）した時に、結果通知電文をプッシュする先のURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: cancel_push_url キャンセル時プッシュ先URL
        #
        def cancel_push_url=(cancel_push_url)
          @cancel_push_url = cancel_push_url
        end

        #
        # ===頻度（単位）を取得する
        # @return:: 頻度（単位）
        #
        def frequency_unit
          @frequency_unit = nil unless instance_variable_defined?(:@frequency_unit)
          @frequency_unit
        end

        #
        # ===頻度（単位）を設定する
        # 随時決済の頻度の単位（例：2週間毎であれば、単位はWeek、値は2）
        # "Year"：年
        # "Month"：月
        # "Week"：週
        # "Day"：日
        # ※課金種別が都度決済の場合は 指定できません。
        # ※課金種別が随時決済の場合は指定必須 。
        # @param:: frequency_unit 頻度（単位）
        #
        def frequency_unit=(frequency_unit)
          @frequency_unit = frequency_unit
        end

        #
        # ===頻度（値）を取得する
        # @return:: 頻度（値）
        #
        def frequency_value
          @frequency_value = nil unless instance_variable_defined?(:@frequency_value)
          @frequency_value
        end

        #
        # ===頻度（値）を設定する
        # 随時決済の頻度の値（例：2週間毎であれば、単位はWeek、値は2）
        # - 頻度（単位）毎に設定できる範囲が異なります。
        # "Year"：1のみ
        # "Month"：1～12
        # "Week"：1～52
        # "Day"：1～365
        # ※課金種別が都度決済の場合は指定できません。
        # ※課金種別が随時決済の場合は指定必須 。
        # @param:: frequency_value 頻度（値）
        #
        def frequency_value=(frequency_value)
          @frequency_value = frequency_value
        end

        #
        # ===配送先制限リストを取得する
        # @return:: 配送先制限リスト
        #
        def address_restrictions
          @address_restrictions = nil unless instance_variable_defined?(:@address_restrictions)
          @address_restrictions
        end

        #
        # ===配送先制限リストを設定する
        # 配送先を制限するための許可リストまたは禁止リスト。
        # - リストには下記内容をJSON形式で指定する必要があります。
        # {"type": "【Allowed】", "restrictions": {
        #  "【countryCode】": {"statesOrRegions": ["【AA】"],"zipCodes": ["【99999】", "【99999】"]},
        #  "【countryCode】": {"statesOrRegions": ["【AA】"],"zipCodes": ["【999-9999】"]}, ...
        # }
        # ※【】で括られた部分は下記に従い適切な値を設定
        # "type"："Allowed"(許可)
        #            "NotAllowed"(禁止)
        # "countryCode"： 国名コード(日本：JP,アメリカ：US等のISO3166準拠コード)
        # "statesOrRegions"：都道府県等の地域名、アメリカは2桁の州略号(WA, CA, IL...)
        # "zipCodes"： 郵便番号、日本の場合は【999-9999】
        # @param:: address_restrictions 配送先制限リスト
        #
        def address_restrictions=(address_restrictions)
          @address_restrictions = address_restrictions
        end

        #
        # ===決済確認画面種別を取得する
        # @return:: 決済確認画面種別
        #
        def pay_confirm_screen_type
          @pay_confirm_screen_type = nil unless instance_variable_defined?(:@pay_confirm_screen_type)
          @pay_confirm_screen_type
        end

        #
        # ===決済確認画面種別を設定する
        # 加盟店用の決済確認画面を利用するかの種別。
        # "0"：DGFT決済確認画面利用
        # "1"：加盟店決済確認画面利用
        # ※未指定の場合は、"0"：DGFT決済確認画面利用となります。
        # @param:: pay_confirm_screen_type 決済確認画面種別
        #
        def pay_confirm_screen_type=(pay_confirm_screen_type)
          @pay_confirm_screen_type = pay_confirm_screen_type
        end

        #
        # ===決済確認画面URLを取得する
        # @return:: 決済確認画面URL
        #
        def pay_confirm_screen_url
          @pay_confirm_screen_url = nil unless instance_variable_defined?(:@pay_confirm_screen_url)
          @pay_confirm_screen_url
        end

        #
        # ===決済確認画面URLを設定する
        # 決済確認画面へ遷移するためのURL
        # ※決済確認画面種別が"1"かつ決済確認画面URLが未指定の場合は、エラーとする。
        # - 最大:256byte
        # @param:: pay_confirm_screen_url 決済確認画面URL
        #
        def pay_confirm_screen_url=(pay_confirm_screen_url)
          @pay_confirm_screen_url = pay_confirm_screen_url
        end

        #
        # ===与信期限延長フラグを取得する
        # @return:: 与信期限延長フラグ
        #
        def extend_expiration
          @extend_expiration = nil unless instance_variable_defined?(:@extend_expiration)
          @extend_expiration
        end

        #
        # ===与信期限延長フラグを設定する
        # "true"： 延長する
        # "false"： 延長しない
        # ※指定が無い場合は、延長しないとなります。
        # ※課金種別が都度決済の場合のみ、指定可能。
        # @param:: extend_expiration 与信期限延長フラグ
        #
        def extend_expiration=(extend_expiration)
          @extend_expiration = extend_expiration
        end


      end
    end
  end
end
