# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：Amazonpay、コマンド名：再与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class AmazonpayReAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "amazonpay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "ReAuthorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===元取引IDを取得する
        # @return:: 元取引ID
        #
        def original_order_id
          @original_order_id = nil unless instance_variable_defined?(:@original_order_id)
          @original_order_id
        end

        #
        # ===元取引IDを設定する
        # - 随時決済を申し込んだ際の取引IDを指定します。
        # @param:: original_order_id 元取引ID
        #
        def original_order_id=(original_order_id)
          @original_order_id = original_order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 100000(6桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # "true"： 与信同時売上
        # "false"： 与信のみ
        # ※指定が無い場合は、与信のみとなります。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===プラットフォームIDを取得する
        # @return:: プラットフォームID
        #
        def platform_id
          @platform_id = nil unless instance_variable_defined?(:@platform_id)
          @platform_id
        end

        #
        # ===プラットフォームIDを設定する
        # Amazonから指定のあった場合のみ設定する予定の項目
        # - 最大:21byte
        # @param:: platform_id プラットフォームID
        #
        def platform_id=(platform_id)
          @platform_id = platform_id
        end

        #
        # ===注文説明を取得する
        # @return:: 注文説明
        #
        def note_to_buyer
          @note_to_buyer = nil unless instance_variable_defined?(:@note_to_buyer)
          @note_to_buyer
        end

        #
        # ===注文説明を設定する
        # 購入者のメールに表示される注文の説明
        # ※指定が無い場合は、元取引の注文説明がメールに表示されます。
        # - 最大:255文字
        # @param:: note_to_buyer 注文説明
        #
        def note_to_buyer=(note_to_buyer)
          @note_to_buyer = note_to_buyer
        end

        #
        # ===与信時プッシュ先URLを取得する
        # @return:: 与信時プッシュ先URL
        #
        def authorize_push_url
          @authorize_push_url = nil unless instance_variable_defined?(:@authorize_push_url)
          @authorize_push_url
        end

        #
        # ===与信時プッシュ先URLを設定する
        # 再与信要求が成立（成功または失敗）した時に、結果通知電文をプッシュする先のURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、元取引の与信時プッシュ先URLを使用。元取引側も未指定の場合はMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: authorize_push_url 与信時プッシュ先URL
        #
        def authorize_push_url=(authorize_push_url)
          @authorize_push_url = authorize_push_url
        end

        #
        # ===売上時プッシュ先URLを取得する
        # @return:: 売上時プッシュ先URL
        #
        def capture_push_url
          @capture_push_url = nil unless instance_variable_defined?(:@capture_push_url)
          @capture_push_url
        end

        #
        # ===売上時プッシュ先URLを設定する
        # 売上要求の処理結果が確定（成功または失敗）した時に、結果通知電文をプッシュする先のURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、元取引の売上時プッシュ先URLを使用。元取引側も未指定の場合はMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: capture_push_url 売上時プッシュ先URL
        #
        def capture_push_url=(capture_push_url)
          @capture_push_url = capture_push_url
        end

        #
        # ===キャンセル時プッシュ先URLを取得する
        # @return:: キャンセル時プッシュ先URL
        #
        def cancel_push_url
          @cancel_push_url = nil unless instance_variable_defined?(:@cancel_push_url)
          @cancel_push_url
        end

        #
        # ===キャンセル時プッシュ先URLを設定する
        # キャンセル要求、返金要求の処理結果が確定（成功または失敗）した時に、結果通知電文をプッシュする先のURLを指定（クエリパラメータ指定可）
        # ※未指定の場合は、元取引のキャンセル時プッシュ先URLを使用。元取引側も未指定の場合はMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # - 最大:256byte
        # @param:: cancel_push_url キャンセル時プッシュ先URL
        #
        def cancel_push_url=(cancel_push_url)
          @cancel_push_url = cancel_push_url
        end


      end
    end
  end
end
