# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：銀行決済、コマンド名：決済の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class BankAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end

        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "bank"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===決済サービスオプションを取得する
        # @return:: 決済サービスオプション
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===決済サービスオプションを設定する
        # - "atm"：ATM決済(番号通知方式)
        # - "netbank-pc"：ネットバンク決済(銀行リンク方式：PC)
        # - "netbank-docomo"：ネットバンク決済(銀行リンク方式：docomo)
        # - "netbank-softbank"：ネットバンク決済(銀行リンク方式：SoftBank)
        # - "netbank-au"：ネットバンク決済(銀行リンク方式：au)
        # @param:: service_option_type 決済サービスオプション
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===顧客名１を取得する
        # @return:: 顧客名１
        #
        def name1
          @name1 = nil unless instance_variable_defined?(:@name1)
          @name1
        end

        #
        # ===顧客名１を設定する
        # @param:: name1 顧客名１
        #
        def name1=(name1)
          @name1 = name1
        end

        #
        # ===顧客名２を取得する
        # @return:: 顧客名２
        #
        def name2
          @name2 = nil unless instance_variable_defined?(:@name2)
          @name2
        end

        #
        # ===顧客名２を設定する
        # @param:: name2 顧客名２
        #
        def name2=(name2)
          @name2 = name2
        end

        #
        # ===顧客名カナ１を取得する
        # @return:: 顧客名カナ１
        #
        def kana1
          @kana1 = nil unless instance_variable_defined?(:@kana1)
          @kana1
        end

        #
        # ===顧客名カナ１を設定する
        # - 全角英数カナのみ　※最大20Byte
        # @param:: kana1 顧客名カナ１
        #
        def kana1=(kana1)
          @kana1 = kana1
        end

        #
        # ===顧客名カナ２を取得する
        # @return:: 顧客名カナ２
        #
        def kana2
          @kana2 = nil unless instance_variable_defined?(:@kana2)
          @kana2
        end

        #
        # ===顧客名カナ２を設定する
        # - 全角英数カナのみ　※最大20Byte
        # @param:: kana2 顧客名カナ２
        #
        def kana2=(kana2)
          @kana2 = kana2
        end

        #
        # ===郵便番号１を取得する
        # @return:: 郵便番号１
        #
        def post1
          @post1 = nil unless instance_variable_defined?(:@post1)
          @post1
        end

        #
        # ===郵便番号１を設定する
        # - 郵便番号上３桁
        # @param:: post1 郵便番号１
        #
        def post1=(post1)
          @post1 = post1
        end

        #
        # ===郵便番号２を取得する
        # @return:: 郵便番号２
        #
        def post2
          @post2 = nil unless instance_variable_defined?(:@post2)
          @post2
        end

        #
        # ===郵便番号２を設定する
        # - 郵便番号下４桁
        # @param:: post2 郵便番号２
        #
        def post2=(post2)
          @post2 = post2
        end

        #
        # ===住所１を取得する
        # @return:: 住所１
        #
        def address1
          @address1 = nil unless instance_variable_defined?(:@address1)
          @address1
        end

        #
        # ===住所１を設定する
        # - ※最大50Byte
        # @param:: address1 住所１
        #
        def address1=(address1)
          @address1 = address1
        end

        #
        # ===住所２を取得する
        # @return:: 住所２
        #
        def address2
          @address2 = nil unless instance_variable_defined?(:@address2)
          @address2
        end

        #
        # ===住所２を設定する
        # - ※最大50Byte
        # @param:: address2 住所２
        #
        def address2=(address2)
          @address2 = address2
        end

        #
        # ===住所３を取得する
        # @return:: 住所３
        #
        def address3
          @address3 = nil unless instance_variable_defined?(:@address3)
          @address3
        end

        #
        # ===住所３を設定する
        # - ※最大100Byte
        # @param:: address3 住所３
        #
        def address3=(address3)
          @address3 = address3
        end

        #
        # ===電話番号を取得する
        # @return:: 電話番号
        #
        def tel_no
          @tel_no = nil unless instance_variable_defined?(:@tel_no)
          @tel_no
        end

        #
        # ===電話番号を設定する
        # - ハイフンなし、９桁～１１桁
        # @param:: tel_no 電話番号
        #
        def tel_no=(tel_no)
          @tel_no = tel_no
        end

        #
        # ===支払期限を取得する
        # @return:: 支払期限
        #
        def pay_limit
          @pay_limit = nil unless instance_variable_defined?(:@pay_limit)
          @pay_limit
        end

        #
        # ===支払期限を設定する
        # - YYYYMMDD
        # @param:: pay_limit 支払期限
        #
        def pay_limit=(pay_limit)
          @pay_limit = pay_limit
        end

        #
        # ===成約日を取得する
        # @return:: 成約日
        #
        def agreement_date
          @agreement_date = nil unless instance_variable_defined?(:@agreement_date)
          @agreement_date
        end

        #
        # ===成約日を設定する
        # - YYYYMMDD
        # @param:: agreement_date 成約日
        #
        def agreement_date=(agreement_date)
          @agreement_date = agreement_date
        end

        #
        # ===請求内容（漢字）を取得する
        # @return:: 請求内容（漢字）
        #
        def contents
          @contents = nil unless instance_variable_defined?(:@contents)
          @contents
        end

        #
        # ===請求内容（漢字）を設定する
        # - インフォメーションとしてＡＴＭ等に表示　※最大24Byte
        # @param:: contents 請求内容（漢字）
        #
        def contents=(contents)
          @contents = contents
        end

        #
        # ===請求内容（カナ）を取得する
        # @return:: 請求内容（カナ）
        #
        def contents_kana
          @contents_kana = nil unless instance_variable_defined?(:@contents_kana)
          @contents_kana
        end

        #
        # ===請求内容（カナ）を設定する
        # - インフォメーションとしてＡＴＭ等に表示　※最大48Byte
        # @param:: contents_kana 請求内容（カナ）
        #
        def contents_kana=(contents_kana)
          @contents_kana = contents_kana
        end

        #
        # ===決済機関コードを取得する
        # @return:: 決済機関コード
        #
        def pay_csv
          @pay_csv = nil unless instance_variable_defined?(:@pay_csv)
          @pay_csv
        end

        #
        # ===決済機関コードを設定する
        # - ※「画面言語」を設定した場合は、当項目を設定することはできない。
        # @param:: pay_csv 決済機関コード
        #
        def pay_csv=(pay_csv)
          @pay_csv = pay_csv
        end

        #
        # ===画面言語を取得する
        # @return:: 画面言語
        #
        def view_locale
          @view_locale = nil unless instance_variable_defined?(:@view_locale)
          @view_locale
        end

        #
        # ===画面言語を設定する
        # - ※「決済機関コード」を設定した場合は、当項目を設定することはできない。
        # @param:: view_locale 画面言語
        #
        def view_locale=(view_locale)
          @view_locale = view_locale
        end

        #
        # ===決済結果戻り先URLを取得する
        # @return:: 決済結果戻り先URL
        #
        def term_url
          @term_url = nil unless instance_variable_defined?(:@term_url)
          @term_url
        end

        #
        # ===決済結果戻り先URLを設定する
        # - ※決済完了後に店舗側サイトへ遷移を戻すためのURL
        # - ※URLに使用可能な半角文字
        # - ※ネットバンク決済(銀行リンク方式：PC)を指定した場合のみ設定可能。
        # ただし、決済機関コードを設定した場合はネットバンク決済(銀行リンク方式：PC)を設定した場合でも設定不可となる。
        # @param:: term_url 決済結果戻り先URL
        #
        def term_url=(term_url)
          @term_url = term_url
        end

        #
        # ===プッシュURLを取得する
        # @return:: プッシュURL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュURLを設定する
        # - プッシュURLを指定します。
        # - ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: push_url プッシュURL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

        #
        # ===プッシュパラメータ追加フラグを取得する
        # @return:: プッシュパラメータ追加フラグ
        #
        def push_expantion_flag
          @push_expantion_flag = nil unless instance_variable_defined?(:@push_expantion_flag)
          @push_expantion_flag
        end

        #
        # ===プッシュパラメータ追加フラグを設定する
        # - 半角数字(最大1文字)
        # - "1"： プッシュに追加のパラメータを設定する。
        # - "0"： プッシュに追加のパラメータを設定しない。
        # - ※ 未指定の場合は、マスタに登録された値を使用します。
        # @param:: push_expantion_flag プッシュパラメータ追加フラグ
        #
        def push_expantion_flag=(push_expantion_flag)
          @push_expantion_flag = push_expantion_flag
        end

      end
    end
  end
end
