# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/response_base_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：bankpay、コマンド名：口座登録の応答Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class BankpayAccountAddResponseDto < Veritrans::Tercerog::Mdk::ResponseBaseDto

        #
        # ===決済サービスタイプを取得する
        # 決済サービスの区分を返却します。
        # "bankpay"： BankPay
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスタイプを設定する
        # @param:: service_type 決済サービスタイプ
        #
        def service_type=(service_type)
          @service_type = service_type
        end

        #
        # ===処理結果コードを取得する
        # 決済請求処理後、応答電文に含まれる値を返却します。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # @return:: 処理結果コード
        #
        def mstatus
          @mstatus = nil unless instance_variable_defined?(:@mstatus)
          @mstatus
        end

        #
        # ===処理結果コードを設定する
        # @param:: mstatus 処理結果コード
        #
        def mstatus=(mstatus)
          @mstatus = mstatus
        end

        #
        # ===詳細結果コードを取得する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @return:: 詳細結果コード
        #
        def v_result_code
          @v_result_code = nil unless instance_variable_defined?(:@v_result_code)
          @v_result_code
        end

        #
        # ===詳細結果コードを設定する
        # @param:: v_result_code 詳細結果コード
        #
        def v_result_code=(v_result_code)
          @v_result_code = v_result_code
        end

        #
        # ===エラーメッセージを取得する
        # 処理結果に対するメッセージを返却します。
        # @return:: エラーメッセージ
        #
        def merr_msg
          @merr_msg = nil unless instance_variable_defined?(:@merr_msg)
          @merr_msg
        end

        #
        # ===エラーメッセージを設定する
        # @param:: merr_msg エラーメッセージ
        #
        def merr_msg=(merr_msg)
          @merr_msg = merr_msg
        end

        #
        # ===処理通番を取得する
        # 決済サーバにて採番する処理通番
        # @return:: 処理通番
        #
        def process_id
          @process_id = nil unless instance_variable_defined?(:@process_id)
          @process_id
        end

        #
        # ===処理通番を設定する
        # @param:: process_id 処理通番
        #
        def process_id=(process_id)
          @process_id = process_id
        end

        #
        # ===口座入力情報取得の処理通番を取得する
        # 口座入力情報取得時に決済サーバーにて付与されるprocessId。
        # @return:: 口座入力情報取得の処理通番
        #
        def prepared_process_id
          @prepared_process_id = nil unless instance_variable_defined?(:@prepared_process_id)
          @prepared_process_id
        end

        #
        # ===口座入力情報取得の処理通番を設定する
        # @param:: prepared_process_id 口座入力情報取得の処理通番
        #
        def prepared_process_id=(prepared_process_id)
          @prepared_process_id = prepared_process_id
        end

        #
        # ===MDKバージョンを取得する
        # 電文のバージョン番号を返却します。
        # @return:: MDKバージョン
        #
        def txn_version
          @txn_version = nil unless instance_variable_defined?(:@txn_version)
          @txn_version
        end

        #
        # ===MDKバージョンを設定する
        # @param:: txn_version MDKバージョン
        #
        def txn_version=(txn_version)
          @txn_version = txn_version
        end

        #
        # ===会員IDを取得する
        # @return:: 会員ID
        #
        def member_id
          @member_id = nil unless instance_variable_defined?(:@member_id)
          @member_id
        end

        #
        # ===会員IDを設定する
        # @param:: member_id 会員ID
        #
        def member_id=(member_id)
          @member_id = member_id
        end

        #
        # ===口座IDを取得する
        # @return:: 口座ID
        #
        def account_id
          @account_id = nil unless instance_variable_defined?(:@account_id)
          @account_id
        end

        #
        # ===口座IDを設定する
        # @param:: account_id 口座ID
        #
        def account_id=(account_id)
          @account_id = account_id
        end

        #
        # ===BankPay口座登録URLを取得する
        # BankPay への遷移に必要な項目。
        # BankPayに遷移するために使用してください。
        # @return:: BankPay口座登録URL
        #
        def bankpay_accounts_register_url
          @bankpay_accounts_register_url = nil unless instance_variable_defined?(:@bankpay_accounts_register_url)
          @bankpay_accounts_register_url
        end

        #
        # ===BankPay口座登録URLを設定する
        # @param:: bankpay_accounts_register_url BankPay口座登録URL
        #
        def bankpay_accounts_register_url=(bankpay_accounts_register_url)
          @bankpay_accounts_register_url = bankpay_accounts_register_url
        end

        #
        # ===口座ラベルを取得する
        # 登録対象の口座の別名を返却します。
        # - BankPayへの遷移に必要な項目になります。
        # @return:: 口座ラベル
        #
        def account_label
          @account_label = nil unless instance_variable_defined?(:@account_label)
          @account_label
        end

        #
        # ===口座ラベルを設定する
        # @param:: account_label 口座ラベル
        #
        def account_label=(account_label)
          @account_label = account_label
        end

        #
        # ===戻り先URLを取得する
        # 戻り先URLを返却します。
        # - BankPayへの遷移に必要な項目になります。
        # @return:: 戻り先URL
        #
        def back_url
          @back_url = nil unless instance_variable_defined?(:@back_url)
          @back_url
        end

        #
        # ===戻り先URLを設定する
        # @param:: back_url 戻り先URL
        #
        def back_url=(back_url)
          @back_url = back_url
        end

        #
        # ===会員用アクセストークンを取得する
        # 会員用アクセストークンを返却します。
        # - BankPayへの遷移に必要な項目になります。
        # @return:: 会員用アクセストークン
        #
        def customer_access_token
          @customer_access_token = nil unless instance_variable_defined?(:@customer_access_token)
          @customer_access_token
        end

        #
        # ===会員用アクセストークンを設定する
        # @param:: customer_access_token 会員用アクセストークン
        #
        def customer_access_token=(customer_access_token)
          @customer_access_token = customer_access_token
        end

        #
        # ===Pay事業者認証鍵世代番号を取得する
        # 認証鍵の世代番号を返却します。
        # - BankPayへの遷移に必要な項目になります。
        # @return:: Pay事業者認証鍵世代番号
        #
        def processor_authentication_key_index
          @processor_authentication_key_index = nil unless instance_variable_defined?(:@processor_authentication_key_index)
          @processor_authentication_key_index
        end

        #
        # ===Pay事業者認証鍵世代番号を設定する
        # @param:: processor_authentication_key_index Pay事業者認証鍵世代番号
        #
        def processor_authentication_key_index=(processor_authentication_key_index)
          @processor_authentication_key_index = processor_authentication_key_index
        end

        #
        # ===メッセージ認証コードを取得する
        # メッセージ認証コードを返却します。
        # - BankPayへの遷移に必要な項目になります。
        # @return:: メッセージ認証コード
        #
        def mac
          @mac = nil unless instance_variable_defined?(:@mac)
          @mac
        end

        #
        # ===メッセージ認証コードを設定する
        # @param:: mac メッセージ認証コード
        #
        def mac=(mac)
          @mac = mac
        end


        #
        # ===PayNowIDオブジェクトを取得する
        # @return:: PayNowIDオブジェクト
        #
        def pay_now_id_response
          @pay_now_id_response = nil unless instance_variable_defined?(:@pay_now_id_response)
          @pay_now_id_response
        end

        #
        # ===PayNowIDオブジェクトを設定する
        # @param:: pay_now_id_response PayNowIDオブジェクト
        #
        def pay_now_id_response=(pay_now_id_response)
          @pay_now_id_response = pay_now_id_response
        end



      end
    end
  end
end
