# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：bankpay、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class BankpayAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "bankpay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "online":オンライン決済
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 9999999(7桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===会員IDを取得する
        # @return:: 会員ID
        #
        def member_id
          @member_id = nil unless instance_variable_defined?(:@member_id)
          @member_id
        end

        #
        # ===会員IDを設定する
        # 決済申込対象の会員IDを指定します。
        # @param:: member_id 会員ID
        #
        def member_id=(member_id)
          @member_id = member_id
        end

        #
        # ===口座IDを取得する
        # @return:: 口座ID
        #
        def account_id
          @account_id = nil unless instance_variable_defined?(:@account_id)
          @account_id
        end

        #
        # ===口座IDを設定する
        # 決済申込対象の口座IDを指定します。
        # @param:: account_id 口座ID
        #
        def account_id=(account_id)
          @account_id = account_id
        end

        #
        # ===課金種別を取得する
        # @return:: 課金種別
        #
        def accounting_type
          @accounting_type = nil unless instance_variable_defined?(:@accounting_type)
          @accounting_type
        end

        #
        # ===課金種別を設定する
        # "0"：都度決済
        # "1"：継続課金
        # "2"：チャージ（オープン）
        # "3"：チャージ（ハウス）
        # "4"：チャージ（資金移動）
        # @param:: accounting_type 課金種別
        #
        def accounting_type=(accounting_type)
          @accounting_type = accounting_type
        end

        #
        # ===端末機識別番号を取得する
        # @return:: 端末機識別番号
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===端末機識別番号を設定する
        # 端末機識別番号を入力します。
        # 店舗POSなどの決済端末を識別する値を指定
        # チャージのみの利用の場合は、一意な値を設定。
        # 流通決済事業者コードを設定可能な場合は先頭5桁の設定を推奨。
        # @param:: terminal_id 端末機識別番号
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗IDを指定します。
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗名を取得する
        # @return:: 店舗名
        #
        def store_name
          @store_name = nil unless instance_variable_defined?(:@store_name)
          @store_name
        end

        #
        # ===店舗名を設定する
        # 店舗名を指定します。
        # @param:: store_name 店舗名
        #
        def store_name=(store_name)
          @store_name = store_name
        end


      end
    end
  end
end
