# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_credit_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：カード、コマンド名：決済取消の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CardCancelRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentCreditRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end

        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "card"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Cancel"

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===元取引IDを取得する
        # @return:: 元取引ID
        #
        def original_order_id
          @original_order_id = nil unless instance_variable_defined?(:@original_order_id)
          @original_order_id
        end

        #
        # ===元取引IDを設定する
        # - マーチャントで過去の取引を表す注文管理IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: original_order_id 元取引ID
        #
        def original_order_id=(original_order_id)
          @original_order_id = original_order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # - 決済金額を指定します。
        # - 指定なしの場合：全額取消となります。
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===カード番号を取得する
        # @return:: カード番号
        #
        def card_number
          @card_number = nil unless instance_variable_defined?(:@card_number)
          @card_number
        end

        #
        # ===カード番号を設定する
        # - クレジットカード番号を指定します。
        # - 例） クレジットカード番号は19桁まで処理が可能。
        # - （ハイフンを含んでも含まなくても同様に処理が可能）
        # - 戻り値としては､上2桁/下4桁の計6桁が返ります。
        # @param:: card_number カード番号
        #
        def card_number=(card_number)
          @card_number = card_number
        end

        #
        # ===カード有効期限を取得する
        # @return:: カード有効期限
        #
        def card_expire
          @card_expire = nil unless instance_variable_defined?(:@card_expire)
          @card_expire
        end

        #
        # ===カード有効期限を設定する
        # - クレジットカードの有効期限を指定します。
        # - MM/YY （月 + "/" + 年）の形式
        # - 例） "11/09"
        # @param:: card_expire カード有効期限
        #
        def card_expire=(card_expire)
          @card_expire = card_expire
        end

        #
        # ===カード保有者名を取得する
        # @return:: カード保有者名
        #
        def cardholder_name
          @cardholder_name = nil unless instance_variable_defined?(:@cardholder_name)
          @cardholder_name
        end

        #
        # ===カード保有者名を設定する
        # - クレジットカードに印字されている保有者名を指定します。
        # @param:: cardholder_name カード保有者名
        #
        def cardholder_name=(cardholder_name)
          @cardholder_name = cardholder_name
        end

        #
        # ===カードオプションタイプを取得する
        # @return:: カードオプションタイプ
        #
        def card_option_type
          @card_option_type = nil unless instance_variable_defined?(:@card_option_type)
          @card_option_type
        end

        #
        # ===カードオプションタイプを設定する
        # - カードオプションタイプを指定します。
        # - "mpi"： 指定できません
        # - "house"：
        # - "elio"： 指定できません
        # - ※ 指定が無い場合は、デフォルトのカードオプション
        # @param:: card_option_type カードオプションタイプ
        #
        def card_option_type=(card_option_type)
          @card_option_type = card_option_type
        end

        #
        # ===カード接続センターを取得する
        # @return:: カード接続センター
        #
        def card_center
          @card_center = nil unless instance_variable_defined?(:@card_center)
          @card_center
        end

        #
        # ===カード接続センターを設定する
        # - カード接続センターを指定します。（任意指定）
        # - "sln"： Sln接続"
        # - "jcn""： Jcn接続
        # - ※ 指定が無い場合は、デフォルトの接続センターを検証
        # @param:: card_center カード接続センター
        #
        def card_center=(card_center)
          @card_center = card_center
        end

        #
        # ===仕向け先コードを取得する
        # @return:: 仕向け先コード
        #
        def acquirer_code
          @acquirer_code = nil unless instance_variable_defined?(:@acquirer_code)
          @acquirer_code
        end

        #
        # ===仕向け先コードを設定する
        # - 仕向け先カード会社コードを指定します。
        # - （店舗が加盟店契約をしているカード会社）
        # - ※ 最終的に決済を行うカード発行会社ではなく、決済要求電文が最初に仕向けられる加盟店管理会社となります。
        # - 01 シティカードジャパン株式会社（ダイナースカード）
        # - 02 株式会社 ジェーシービー
        # - 03 三菱UFJニコス株式会社（旧DCカード）
        # - 04 三井住友カード株式会社（りそなカード株式会社などVISAジャパングループ）
        # - 05 三菱UFJニコス株式会社（旧UFJカード）
        # - 06 ユーシーカード株式会社
        # - 07 アメリカン・エキスプレス・インターナショナル
        # - 08 株式会社 ジャックス
        # - 09 三菱UFJニコス株式会社（旧日本信販）
        # - 10 株式会社 オリエントコーポレーション
        # - 11 株式会社 セントラルファイナンス
        # - 12 株式会社 アプラス
        # - 13 株式会社 ライフ
        # - 14 楽天KC株式会社
        # - 17 三菱UFJニコス株式会社（旧協同クレジット）
        # - 20 GEコンシューマー・ファイナンス株式会社（ジーシーカード）
        # - 21 株式会社 クレディセゾン
        # - 22 ポケットカード 株式会社
        # - 23 株式会社オーエムシーカード
        # - 24 イオンクレジットサービス株式会社
        # - 28 株式会社 バンクカードサービス
        # - 31 トヨタファイナンス 株式会社
        # - 32 株式会社 JALカード
        # - 36 株式会社クオーク
        # - 37 GEコンシューマー・ファイナンス株式会社（GEカード）
        # - 38 東急カード株式会社（TOPカード）
        # - 40 （株）UCS
        # - 47 （株）ほくせん
        # - 48 （株）ソニーファイナンスインターナショナル
        # - 49 ヤフー（株）
        # - 50 （株）ゆめカード
        # - 51 （株）オークス
        # - 52 東日本旅客鉄道（株）（ビューカード）
        # @param:: acquirer_code 仕向け先コード
        #
        def acquirer_code=(acquirer_code)
          @acquirer_code = acquirer_code
        end

        #
        # ===新規フラグを取得する
        # @return:: 新規フラグ
        #
        def with_new
          @with_new = nil unless instance_variable_defined?(:@with_new)
          @with_new
        end

        #
        # ===新規フラグを設定する
        # - 新規フラグを指定します。（任意指定）
        # - "true"： 新規返品
        # - "false"： 取消・返品
        # - ※ 指定が無い場合は、false
        # @param:: with_new 新規フラグ
        #
        def with_new=(with_new)
          @with_new = with_new
        end

        #
        # ===直接返品フラグを取得する
        # @return:: 直接返品フラグ
        #
        def with_direct
          @with_direct = nil unless instance_variable_defined?(:@with_direct)
          @with_direct
        end

        #
        # ===直接返品フラグを設定する
        # - 直接返品フラグを指定します。（任意指定）
        # - "true"： 直接返品
        # - "false"： 取消・返品
        # - ※ 指定が無い場合は、false
        # @param:: with_direct 直接返品フラグ
        #
        def with_direct=(with_direct)
          @with_direct = with_direct
        end

        #
        # ===取消日を取得する
        # @return:: 取消日
        #
        def cancel_day
          @cancel_day = nil unless instance_variable_defined?(:@cancel_day)
          @cancel_day
        end

        #
        # ===取消日を設定する
        # - 取消日を指定します。
        # - YYYYMMDD の形式
        # - 例） "20090905"
        # @param:: cancel_day 取消日
        #
        def cancel_day=(cancel_day)
          @cancel_day = cancel_day
        end

        #
        # ===商品コードを取得する
        # @return:: 商品コード
        #
        def item_code
          @item_code = nil unless instance_variable_defined?(:@item_code)
          @item_code
        end

        #
        # ===商品コードを設定する
        # - 商品コードを指定します。
        # - ※ 指定が無い場合は、デフォルトの商品コード
        # @param:: item_code 商品コード
        #
        def item_code=(item_code)
          @item_code = item_code
        end

        #
        # ===通貨単位を取得する
        # @return:: 通貨単位
        #
        def currency_unit
          @currency_unit = nil unless instance_variable_defined?(:@currency_unit)
          @currency_unit
        end

        #
        # ===通貨単位を設定する
        # - 通貨単位を設定します。サポートは"jpy"のみです。
        # - 新規返品フラグがfalseの場合は設定されているとエラーになります
        # @param:: currency_unit 通貨単位
        #
        def currency_unit=(currency_unit)
          @currency_unit = currency_unit
        end

        #
        # ===売上日を取得する
        # @return:: 売上日
        #
        def sales_day
          @sales_day = nil unless instance_variable_defined?(:@sales_day)
          @sales_day
        end

        #
        # ===売上日を設定する
        # - 売上日を指定します。（任意指定）
        # - YYYYMMDD の形式
        # - 例） "20090905"
        # - 売上フラグ（No.11)がfalseの場合は利用できません。
        # @param:: sales_day 売上日
        #
        def sales_day=(sales_day)
          @sales_day = sales_day
        end

        #
        # ===PINを取得する
        # @return:: PIN
        #
        def pin
          @pin = nil unless instance_variable_defined?(:@pin)
          @pin
        end

        #
        # ===PINを設定する
        # - PINを指定します。（任意指定）
        # @param:: pin PIN
        #
        def pin=(pin)
          @pin = pin
        end

        #
        # ===支払タイプを取得する
        # @return:: 支払タイプ
        #
        def payment_type
          @payment_type = nil unless instance_variable_defined?(:@payment_type)
          @payment_type
        end

        #
        # ===支払タイプを設定する
        # - 支払タイプを指定します。（任意指定）
        # @param:: payment_type 支払タイプ
        #
        def payment_type=(payment_type)
          @payment_type = payment_type
        end

        #
        # ===JIS Ⅰ第2トラック情報を取得する
        # @return:: JIS Ⅰ第2トラック情報
        #
        def jis1_second_track
          @jis1_second_track = nil unless instance_variable_defined?(:@jis1_second_track)
          @jis1_second_track
        end

        #
        # ===JIS Ⅰ第2トラック情報を設定する
        # - JIS Ⅰ第2トラック情報を指定します。（任意指定）
        # @param:: jis1_second_track JIS Ⅰ第2トラック情報
        #
        def jis1_second_track=(jis1_second_track)
          @jis1_second_track = jis1_second_track
        end

        #
        # ===JIS Ⅱトラック情報を取得する
        # @return:: JIS Ⅱトラック情報
        #
        def jis2_track
          @jis2_track = nil unless instance_variable_defined?(:@jis2_track)
          @jis2_track
        end

        #
        # ===JIS Ⅱトラック情報を設定する
        # - JIS Ⅱトラック情報を指定します。（任意指定）
        # @param:: jis2_track JIS Ⅱトラック情報
        #
        def jis2_track=(jis2_track)
          @jis2_track = jis2_track
        end

        #
        # ===元取引利用フラグを取得する
        # @return:: 元取引利用フラグ
        #
        def use_original_order
          @use_original_order = nil unless instance_variable_defined?(:@use_original_order)
          @use_original_order
        end

        #
        # ===元取引利用フラグを設定する
        # - 元取引利用フラグを指定します。（任意指定）
        # - 新規フラグがtrueの場合に限り有効です。
        # - "true"： 元取引を利用する
        # - "false"： 元取引を利用しない
        # - ※ 指定が無い場合は、false
        # @param:: use_original_order 元取引利用フラグ
        #
        def use_original_order=(use_original_order)
          @use_original_order = use_original_order
        end

        #
        # ===JPOを取得する
        # @return:: JPO
        #
        def jpo
          @jpo = nil unless instance_variable_defined?(:@jpo)
          @jpo
        end

        #
        # ===JPOを設定する
        # - JPOを指定します。（任意指定）
        # @param:: jpo JPO
        #
        def jpo=(jpo)
          @jpo = jpo
        end

        #
        # ===初回請求年月を取得する
        # @return:: 初回請求年月
        #
        def first_payment
          @first_payment = nil unless instance_variable_defined?(:@first_payment)
          @first_payment
        end

        #
        # ===初回請求年月を設定する
        # - 初回請求年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1310"
        # @param:: first_payment 初回請求年月
        #
        def first_payment=(first_payment)
          @first_payment = first_payment
        end

        #
        # ===ボーナス初回年月を取得する
        # @return:: ボーナス初回年月
        #
        def bonus_first_payment
          @bonus_first_payment = nil unless instance_variable_defined?(:@bonus_first_payment)
          @bonus_first_payment
        end

        #
        # ===ボーナス初回年月を設定する
        # - ボーナス初回年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1312"
        # @param:: bonus_first_payment ボーナス初回年月
        #
        def bonus_first_payment=(bonus_first_payment)
          @bonus_first_payment = bonus_first_payment
        end

        #
        # ===失敗時直接取引実施フラグを取得する
        # @return:: 失敗時直接取引実施フラグ
        #
        def with_direct_on_failure
          @with_direct_on_failure = nil unless instance_variable_defined?(:@with_direct_on_failure)
          @with_direct_on_failure
        end

        #
        # ===失敗時直接取引実施フラグを設定する
        # - 失敗時直接取引実施フラグを指定します。（任意指定）
        # - 新規フラグがtrueの場合に限りtrueを指定できます。
        # - "true"：取引失敗時、直接取引を実施します。
        # - "false"：取引失敗時、何もしません。
        # - ※ 指定が無い場合は、false
        # @param:: with_direct_on_failure 失敗時直接取引実施フラグ
        #
        def with_direct_on_failure=(with_direct_on_failure)
          @with_direct_on_failure = with_direct_on_failure
        end

        #
        # ===決済金額（多通貨）を取得する
        # @return:: 決済金額（多通貨）
        #
        def mc_amount
          @mc_amount = nil unless instance_variable_defined?(:@mc_amount)
          @mc_amount
        end

        #
        # ===決済金額（多通貨）を設定する
        # - 決済金額（多通貨）を指定します。
        # - 指定なしの場合：全額取消となります。
        # @param:: mc_amount 決済金額（多通貨）
        #
        def mc_amount=(mc_amount)
          @mc_amount = mc_amount
        end

        #
        # ===POSデータコードを取得する
        # @return:: POSデータコード
        #
        def pos_data_code
          @pos_data_code = nil unless instance_variable_defined?(:@pos_data_code)
          @pos_data_code
        end

        #
        # ===POSデータコードを設定する
        # - POSデータコードを指定します。
        # @param:: pos_data_code POSデータコード
        #
        def pos_data_code=(pos_data_code)
          @pos_data_code = pos_data_code
        end

        #
        # ===端末識別番号を取得する
        # @return:: 端末識別番号
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===端末識別番号を設定する
        # - 端末識別番号を指定します。
        # @param:: terminal_id 端末識別番号
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===チップコンディションコードを取得する
        # @return:: チップコンディションコード
        #
        def chip_condition_code
          @chip_condition_code = nil unless instance_variable_defined?(:@chip_condition_code)
          @chip_condition_code
        end

        #
        # ===チップコンディションコードを設定する
        # - チップコンディションコードを指定します。（任意指定）
        # - "0"： IC対応端末における磁気ストライプ取引
        # - " "： 上記以外
        # - paymentType=jis1またはjis2の場合で、
        # - IC端末で磁気ストライプ取引を行った場合に指定します。
        # @param:: chip_condition_code チップコンディションコード
        #
        def chip_condition_code=(chip_condition_code)
          @chip_condition_code = chip_condition_code
        end

        #
        # ===拡張伝票情報を取得する
        # @return:: 拡張伝票情報
        #
        def ex_slip_info
          @ex_slip_info = nil unless instance_variable_defined?(:@ex_slip_info)
          @ex_slip_info
        end

        #
        # ===拡張伝票情報を設定する
        # - 半角英数字
        # - 25桁
        # - 拡張伝票情報を指定します。（任意指定）
        #
        # @param:: ex_slip_info 拡張伝票情報
        #
        def ex_slip_info=(ex_slip_info)
          @ex_slip_info = ex_slip_info
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

      end
    end
  end
end
