# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_credit_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：カード、コマンド名：売上の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class CardCaptureRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentCreditRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end

        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "card"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Capture"

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # - 決済金額を指定します。
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===カード番号を取得する
        # @return:: カード番号
        #
        def card_number
          @card_number = nil unless instance_variable_defined?(:@card_number)
          @card_number
        end

        #
        # ===カード番号を設定する
        # - クレジットカード番号を指定します。
        # - 例） クレジットカード番号は19桁まで処理が可能。
        # - （ハイフンを含んでも含まなくても同様に処理が可能）
        # - 戻り値としては､上2桁/下4桁の計6桁が返ります。
        # - ※ MPIカード、eLIOは、指定できません。
        # @param:: card_number カード番号
        #
        def card_number=(card_number)
          @card_number = card_number
        end

        #
        # ===カード有効期限を取得する
        # @return:: カード有効期限
        #
        def card_expire
          @card_expire = nil unless instance_variable_defined?(:@card_expire)
          @card_expire
        end

        #
        # ===カード有効期限を設定する
        # - クレジットカードの有効期限を指定します。
        # - MM/YY （月 + "/" + 年）の形式
        # - 例） "11/09"
        # @param:: card_expire カード有効期限
        #
        def card_expire=(card_expire)
          @card_expire = card_expire
        end

        #
        # ===カード保有者名を取得する
        # @return:: カード保有者名
        #
        def cardholder_name
          @cardholder_name = nil unless instance_variable_defined?(:@cardholder_name)
          @cardholder_name
        end

        #
        # ===カード保有者名を設定する
        # - クレジットカードに印字されている保有者名を指定します。
        # @param:: cardholder_name カード保有者名
        #
        def cardholder_name=(cardholder_name)
          @cardholder_name = cardholder_name
        end

        #
        # ===カードオプションタイプを取得する
        # @return:: カードオプションタイプ
        #
        def card_option_type
          @card_option_type = nil unless instance_variable_defined?(:@card_option_type)
          @card_option_type
        end

        #
        # ===カードオプションタイプを設定する
        # - カードオプションタイプを指定します。
        # - "mpi"： 指定できません
        # - "house"：
        # - "elio"： 指定できません
        # - ※ 指定が無い場合は、デフォルトのカードオプション
        # @param:: card_option_type カードオプションタイプ
        #
        def card_option_type=(card_option_type)
          @card_option_type = card_option_type
        end

        #
        # ===仕向け先コードを取得する
        # @return:: 仕向け先コード
        #
        def acquirer_code
          @acquirer_code = nil unless instance_variable_defined?(:@acquirer_code)
          @acquirer_code
        end

        #
        # ===仕向け先コードを設定する
        # - 仕向け先カード会社コードを指定します。
        # - （店舗が加盟店契約をしているカード会社）
        # - ※ 最終的に決済を行うカード発行会社ではなく、決済要求電文が最初に仕向けられる加盟店管理会社となります。
        # - 01 シティカードジャパン株式会社（ダイナースカード）
        # - 02 株式会社 ジェーシービー
        # - 03 三菱UFJニコス株式会社（旧DCカード）
        # - 04 三井住友カード株式会社（りそなカード株式会社などVISAジャパングループ）
        # - 05 三菱UFJニコス株式会社（旧UFJカード）
        # - 06 ユーシーカード株式会社
        # - 07 アメリカン・エキスプレス・インターナショナル
        # - 08 株式会社 ジャックス
        # - 09 三菱UFJニコス株式会社（旧日本信販）
        # - 10 株式会社 オリエントコーポレーション
        # - 11 株式会社 セントラルファイナンス
        # - 12 株式会社 アプラス
        # - 13 株式会社 ライフ
        # - 14 楽天KC株式会社
        # - 17 三菱UFJニコス株式会社（旧協同クレジット）
        # - 20 GEコンシューマー・ファイナンス株式会社（ジーシーカード）
        # - 21 株式会社 クレディセゾン
        # - 22 ポケットカード 株式会社
        # - 23 株式会社オーエムシーカード
        # - 24 イオンクレジットサービス株式会社
        # - 28 株式会社 バンクカードサービス
        # - 31 トヨタファイナンス 株式会社
        # - 32 株式会社 JALカード
        # - 36 株式会社クオーク
        # - 37 GEコンシューマー・ファイナンス株式会社（GEカード）
        # - 38 東急カード株式会社（TOPカード）
        # - 40 （株）UCS
        # - 47 （株）ほくせん
        # - 48 （株）ソニーファイナンスインターナショナル
        # - 49 ヤフー（株）
        # - 50 （株）ゆめカード
        # - 51 （株）オークス
        # - 52 東日本旅客鉄道（株）（ビューカード）
        # - 直接売上フラグ（No.11)がtrueの場合のみ利用可能です。
        # @param:: acquirer_code 仕向け先コード
        #
        def acquirer_code=(acquirer_code)
          @acquirer_code = acquirer_code
        end

        #
        # ===売上日を取得する
        # @return:: 売上日
        #
        def sales_day
          @sales_day = nil unless instance_variable_defined?(:@sales_day)
          @sales_day
        end

        #
        # ===売上日を設定する
        # - 売上日を指定します。（任意指定）
        # - YYYYMMDD の形式
        # - 例） "20090905"
        # @param:: sales_day 売上日
        #
        def sales_day=(sales_day)
          @sales_day = sales_day
        end

        #
        # ===商品コードを取得する
        # @return:: 商品コード
        #
        def item_code
          @item_code = nil unless instance_variable_defined?(:@item_code)
          @item_code
        end

        #
        # ===商品コードを設定する
        # - 商品コードを指定します。（任意指定）
        # - ※ 指定が無い場合は、デフォルトの商品コード
        # @param:: item_code 商品コード
        #
        def item_code=(item_code)
          @item_code = item_code
        end

        #
        # ===直接売上フラグを取得する
        # @return:: 直接売上フラグ
        #
        def with_direct
          @with_direct = nil unless instance_variable_defined?(:@with_direct)
          @with_direct
        end

        #
        # ===直接売上フラグを設定する
        # - 直接売上フラグを指定します。（任意指定）
        # - "true"： 与信・売上
        # - "false"： 与信のみ
        # - ※ 指定が無い場合は、false
        # @param:: with_direct 直接売上フラグ
        #
        def with_direct=(with_direct)
          @with_direct = with_direct
        end

        #
        # ===承認番号を取得する
        # @return:: 承認番号
        #
        def auth_code
          @auth_code = nil unless instance_variable_defined?(:@auth_code)
          @auth_code
        end

        #
        # ===承認番号を設定する
        # - カード会社から返る承認番号を指定します。
        # @param:: auth_code 承認番号
        #
        def auth_code=(auth_code)
          @auth_code = auth_code
        end

        #
        # ===決済通貨単位を取得する
        # @return:: 決済通貨単位
        #
        def currency_unit
          @currency_unit = nil unless instance_variable_defined?(:@currency_unit)
          @currency_unit
        end

        #
        # ===決済通貨単位を設定する
        # - 通貨単位を設定します。サポートは"jpy"のみです。
        # - 直接売上フラグがfalseの場合は設定されているとエラーになります
        # @param:: currency_unit 決済通貨単位
        #
        def currency_unit=(currency_unit)
          @currency_unit = currency_unit
        end

        #
        # ===JPOを取得する
        # @return:: JPO
        #
        def jpo
          @jpo = nil unless instance_variable_defined?(:@jpo)
          @jpo
        end

        #
        # ===JPOを設定する
        # - JPOを指定します。（任意指定）
        # @param:: jpo JPO
        #
        def jpo=(jpo)
          @jpo = jpo
        end

        #
        # ===初回請求年月を取得する
        # @return:: 初回請求年月
        #
        def first_payment
          @first_payment = nil unless instance_variable_defined?(:@first_payment)
          @first_payment
        end

        #
        # ===初回請求年月を設定する
        # - 初回請求年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1310"
        # @param:: first_payment 初回請求年月
        #
        def first_payment=(first_payment)
          @first_payment = first_payment
        end

        #
        # ===ボーナス初回年月を取得する
        # @return:: ボーナス初回年月
        #
        def bonus_first_payment
          @bonus_first_payment = nil unless instance_variable_defined?(:@bonus_first_payment)
          @bonus_first_payment
        end

        #
        # ===ボーナス初回年月を設定する
        # - ボーナス初回年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1312"
        # @param:: bonus_first_payment ボーナス初回年月
        #
        def bonus_first_payment=(bonus_first_payment)
          @bonus_first_payment = bonus_first_payment
        end

        #
        # ===決済金額（多通貨）を取得する
        # @return:: 決済金額（多通貨）
        #
        def mc_amount
          @mc_amount = nil unless instance_variable_defined?(:@mc_amount)
          @mc_amount
        end

        #
        # ===決済金額（多通貨）を設定する
        # - 決済金額（多通貨）を指定します。
        # @param:: mc_amount 決済金額（多通貨）
        #
        def mc_amount=(mc_amount)
          @mc_amount = mc_amount
        end

        #
        # ===端末識別番号を取得する
        # @return:: 端末識別番号
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===端末識別番号を設定する
        # - 端末識別番号を指定します。
        # @param:: terminal_id 端末識別番号
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===拡張伝票情報を取得する
        # @return:: 拡張伝票情報
        #
        def ex_slip_info
          @ex_slip_info = nil unless instance_variable_defined?(:@ex_slip_info)
          @ex_slip_info
        end

        #
        # ===拡張伝票情報を設定する
        # - 半角英数字
        # - 25桁
        # - 拡張伝票情報を指定します。（任意指定）
        #
        # @param:: ex_slip_info 拡張伝票情報
        #
        def ex_slip_info=(ex_slip_info)
          @ex_slip_info = ex_slip_info
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

      end
    end
  end
end
