# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_credit_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：カード、コマンド名：申込の要求Dtoクラス（EMV用）
      #
      # @author:: VeriTrans Inc.
      #
      class CardEmvAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentCreditRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end

        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "card"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # - 決済金額を指定します。
        # - 1 以上かつ 99999999 以下である必要があります。
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===カード番号を取得する
        # @return:: カード番号
        #
        def card_number
          @card_number = nil unless instance_variable_defined?(:@card_number)
          @card_number
        end

        #
        # ===カード番号を設定する
        # - クレジットカード番号を指定します。
        # - 例） クレジットカード番号は19桁まで処理が可能。
        # - （ハイフンを含んでも含まなくても同様に処理が可能）
        # - 戻り値としては､上2桁/下4桁の計6桁が返ります。
        # @param:: card_number カード番号
        #
        def card_number=(card_number)
          @card_number = card_number
        end

        #
        # ===カード有効期限を取得する
        # @return:: カード有効期限
        #
        def card_expire
          @card_expire = nil unless instance_variable_defined?(:@card_expire)
          @card_expire
        end

        #
        # ===カード有効期限を設定する
        # - クレジットカードの有効期限を指定します。
        # - MM/YY （月 + "/" + 年）の形式
        # - 例） "11/09"
        # @param:: card_expire カード有効期限
        #
        def card_expire=(card_expire)
          @card_expire = card_expire
        end

        #
        # ===カードオプションタイプを取得する
        # @return:: カードオプションタイプ
        #
        def card_option_type
          @card_option_type = nil unless instance_variable_defined?(:@card_option_type)
          @card_option_type
        end

        #
        # ===カードオプションタイプを設定する
        # - カードオプションタイプを指定します。
        # - "mpi"：
        # - "house"：
        # - "elio"：
        # - ※ 指定が無い場合は、デフォルトのカードオプション
        # - カードオプションタイプ毎の必須項目については
        # - 「（別紙）パラメータ組み合わせ」を参照ください
        # @param:: card_option_type カードオプションタイプ
        #
        def card_option_type=(card_option_type)
          @card_option_type = card_option_type
        end

        #
        # ===カード接続センターを取得する
        # @return:: カード接続センター
        #
        def card_center
          @card_center = nil unless instance_variable_defined?(:@card_center)
          @card_center
        end

        #
        # ===カード接続センターを設定する
        # - カード接続センターを指定します。（任意指定）
        # - "sln"： Sln接続"
        # - "jcn"： Jcn接続
        # - ※ 指定が無い場合は、デフォルトの接続センターを検証
        # @param:: card_center カード接続センター
        #
        def card_center=(card_center)
          @card_center = card_center
        end

        #
        # ===仕向け先コードを取得する
        # @return:: 仕向け先コード
        #
        def acquirer_code
          @acquirer_code = nil unless instance_variable_defined?(:@acquirer_code)
          @acquirer_code
        end

        #
        # ===仕向け先コードを設定する
        # - 仕向け先カード会社コードを指定します。
        # - （店舗が加盟店契約をしているカード会社）
        # - ※ 最終的に決済を行うカード発行会社ではなく、決済要求電文が最初に仕向けられる加盟店管理会社となります。
        # - 01 シティカードジャパン株式会社（ダイナースカード）
        # - 02 株式会社 ジェーシービー
        # - 03 三菱UFJニコス株式会社（旧DCカード）
        # - 04 三井住友カード株式会社（りそなカード株式会社などVISAジャパングループ）
        # - 05 三菱UFJニコス株式会社（旧UFJカード）
        # - 06 ユーシーカード株式会社
        # - 07 アメリカン・エキスプレス・インターナショナル
        # - 08 株式会社 ジャックス
        # - 09 三菱UFJニコス株式会社（旧日本信販）
        # - 10 株式会社 オリエントコーポレーション
        # - 11 株式会社 セントラルファイナンス
        # - 12 株式会社　アプラス
        # - 13 株式会社 ライフ
        # - 14 楽天KC株式会社
        # - 17 三菱UFJニコス株式会社（旧協同クレジット）
        # - 20 GEコンシューマー・ファイナンス株式会社（ジーシーカード）
        # - 21 株式会社 クレディセゾン
        # - 22 ポケットカード 株式会社
        # - 23 株式会社オーエムシーカード
        # - 24 イオンクレジットサービス株式会社
        # - 28 株式会社 バンクカードサービス
        # - 31 トヨタファイナンス 株式会社
        # - 32 株式会社　JALカード
        # - 36 株式会社クオーク
        # - 37 GEコンシューマー・ファイナンス株式会社（GEカード）
        # - 38 東急カード株式会社（TOPカード）
        # - 40 （株）UCS
        # - 47 （株）ほくせん
        # - 48 （株）ソニーファイナンスインターナショナル
        # - 49 ヤフー（株）
        # - 50 （株）ゆめカード
        # - 51 （株）オークス
        # - 52 東日本旅客鉄道（株）（ビューカード）
        # @param:: acquirer_code 仕向け先コード
        #
        def acquirer_code=(acquirer_code)
          @acquirer_code = acquirer_code
        end

        #
        # ===JPOを取得する
        # @return:: JPO
        #
        def jpo
          @jpo = nil unless instance_variable_defined?(:@jpo)
          @jpo
        end

        #
        # ===JPOを設定する
        # - JPOを指定します。（任意指定）
        # @param:: jpo JPO
        #
        def jpo=(jpo)
          @jpo = jpo
        end

        #
        # ===売上フラグを取得する
        # @return:: 売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===売上フラグを設定する
        # - 売上フラグを指定します。（任意指定）
        # - "true"： 与信・売上
        # - "false"： 与信のみ
        # - ※ 指定が無い場合は、false
        # @param:: with_capture 売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===売上日を取得する
        # @return:: 売上日
        #
        def sales_day
          @sales_day = nil unless instance_variable_defined?(:@sales_day)
          @sales_day
        end

        #
        # ===売上日を設定する
        # - 売上日を指定します。（任意指定）
        # - YYYYMMDD の形式
        # - 例） "20090905"
        # - 売上フラグ（No.11)がfalseの場合は利用できません。
        # @param:: sales_day 売上日
        #
        def sales_day=(sales_day)
          @sales_day = sales_day
        end

        #
        # ===商品コードを取得する
        # @return:: 商品コード
        #
        def item_code
          @item_code = nil unless instance_variable_defined?(:@item_code)
          @item_code
        end

        #
        # ===商品コードを設定する
        # - 商品コードを指定します。（任意指定）
        # - ※ 指定が無い場合は、デフォルトの商品コード
        # @param:: item_code 商品コード
        #
        def item_code=(item_code)
          @item_code = item_code
        end

        #
        # ===セキュリティコードを取得する
        # @return:: セキュリティコード
        #
        def security_code
          @security_code = nil unless instance_variable_defined?(:@security_code)
          @security_code
        end

        #
        # ===セキュリティコードを設定する
        # - セキュリティコードを指定します。
        # @param:: security_code セキュリティコード
        #
        def security_code=(security_code)
          @security_code = security_code
        end

        #
        # ===認証コード（eLIO）を取得する
        # @return:: 認証コード（eLIO）
        #
        def auth_flag
          @auth_flag = nil unless instance_variable_defined?(:@auth_flag)
          @auth_flag
        end

        #
        # ===認証コード（eLIO）を設定する
        # - SLN認証アシストサービス用パラメータ[ 認証コード（eLIO） ]
        # - eLIO決済時に採番されるeLIO認証子を設定します。
        # - カード接続センター(No.7)がjcnと設定しているときは利用できません。
        # - カードオプションタイプ（No.6)がelio以外の場合は利用できません。
        # @param:: auth_flag 認証コード（eLIO）
        #
        def auth_flag=(auth_flag)
          @auth_flag = auth_flag
        end

        #
        # ===通貨単位を取得する
        # @return:: 通貨単位
        #
        def currency_unit
          @currency_unit = nil unless instance_variable_defined?(:@currency_unit)
          @currency_unit
        end

        #
        # ===通貨単位を設定する
        # - "jpy"のみ
        # @param:: currency_unit 通貨単位
        #
        def currency_unit=(currency_unit)
          @currency_unit = currency_unit
        end

        #
        # ===PINを取得する
        # @return:: PIN
        #
        def pin
          @pin = nil unless instance_variable_defined?(:@pin)
          @pin
        end

        #
        # ===PINを設定する
        # - PINを指定します。（任意指定）
        # @param:: pin PIN
        #
        def pin=(pin)
          @pin = pin
        end

        #
        # ===支払タイプを取得する
        # @return:: 支払タイプ
        #
        def payment_type
          @payment_type = nil unless instance_variable_defined?(:@payment_type)
          @payment_type
        end

        #
        # ===支払タイプを設定する
        # - 支払タイプを指定します。（任意指定）
        # @param:: payment_type 支払タイプ
        #
        def payment_type=(payment_type)
          @payment_type = payment_type
        end

        #
        # ===JIS Ⅰ第2トラック情報を取得する
        # @return:: JIS Ⅰ第2トラック情報
        #
        def jis1_second_track
          @jis1_second_track = nil unless instance_variable_defined?(:@jis1_second_track)
          @jis1_second_track
        end

        #
        # ===JIS Ⅰ第2トラック情報を設定する
        # - JIS Ⅰ第2トラック情報を指定します。（任意指定）
        # @param:: jis1_second_track JIS Ⅰ第2トラック情報
        #
        def jis1_second_track=(jis1_second_track)
          @jis1_second_track = jis1_second_track
        end

        #
        # ===JIS Ⅱトラック情報を取得する
        # @return:: JIS Ⅱトラック情報
        #
        def jis2_track
          @jis2_track = nil unless instance_variable_defined?(:@jis2_track)
          @jis2_track
        end

        #
        # ===JIS Ⅱトラック情報を設定する
        # - JIS Ⅱトラック情報を指定します。（任意指定）
        # @param:: jis2_track JIS Ⅱトラック情報
        #
        def jis2_track=(jis2_track)
          @jis2_track = jis2_track
        end

        #
        # ===初回請求年月を取得する
        # @return:: 初回請求年月
        #
        def first_payment
          @first_payment = nil unless instance_variable_defined?(:@first_payment)
          @first_payment
        end

        #
        # ===初回請求年月を設定する
        # - 初回請求年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1310"
        # @param:: first_payment 初回請求年月
        #
        def first_payment=(first_payment)
          @first_payment = first_payment
        end

        #
        # ===ボーナス初回年月を取得する
        # @return:: ボーナス初回年月
        #
        def bonus_first_payment
          @bonus_first_payment = nil unless instance_variable_defined?(:@bonus_first_payment)
          @bonus_first_payment
        end

        #
        # ===ボーナス初回年月を設定する
        # - ボーナス初回年月を指定します。
        # - YYMM （年月）の形式
        # - 例） "1312"
        # @param:: bonus_first_payment ボーナス初回年月
        #
        def bonus_first_payment=(bonus_first_payment)
          @bonus_first_payment = bonus_first_payment
        end

        #
        # ===決済金額（多通貨）を取得する
        # @return:: 決済金額（多通貨）
        #
        def mc_amount
          @mc_amount = nil unless instance_variable_defined?(:@mc_amount)
          @mc_amount
        end

        #
        # ===決済金額（多通貨）を設定する
        # - 決済金額（多通貨）を指定します。
        # - 0 より大きくかつ 99999999 以下である必要があります。
        # @param:: mc_amount 決済金額（多通貨）
        #
        def mc_amount=(mc_amount)
          @mc_amount = mc_amount
        end

        #
        # ===ICカードデータを取得する
        # @return:: ICカードデータ
        #
        def emv_data
          @emv_data = nil unless instance_variable_defined?(:@emv_data)
          @emv_data
        end

        #
        # ===ICカードデータを設定する
        # - ICカードデータを指定します。
        # - 最大255桁のバイナリをBase64にて変換した値を指定します。
        # - paymentType=emvj1またはemvj2の場合に指定します。
        # @param:: emv_data ICカードデータ
        #
        def emv_data=(emv_data)
          @emv_data = emv_data
        end

        #
        # ===オフライン取引指定を取得する
        # @return:: オフライン取引指定
        #
        def is_offline
          @is_offline = nil unless instance_variable_defined?(:@is_offline)
          @is_offline
        end

        #
        # ===オフライン取引指定を設定する
        # - オフライン取引指定を指定します。（任意指定）
        # - "true"： オフライン取引
        # - "false"： オンライン取引
        # - paymentType=emvj1またはemvj2の場合に指定します。
        # - ※ 指定が無い場合は、false
        # @param:: is_offline オフライン取引指定
        #
        def is_offline=(is_offline)
          @is_offline = is_offline
        end

        #
        # ===アドバイス取引指定を取得する
        # @return:: アドバイス取引指定
        #
        def is_advice
          @is_advice = nil unless instance_variable_defined?(:@is_advice)
          @is_advice
        end

        #
        # ===アドバイス取引指定を設定する
        # - アドバイス取引指定を指定します。
        # - "true"： アドバイス取引
        # - "false"： 通常取引
        # - paymentType=emvj1またはemvj2の場合に指定します。
        # - オフライン取引指定がtrueの場合、必ずtrueを指定します。
        # - ※ 指定が無い場合は、false
        # @param:: is_advice アドバイス取引指定
        #
        def is_advice=(is_advice)
          @is_advice = is_advice
        end

        #
        # ===与信日時を取得する
        # @return:: 与信日時
        #
        def auth_datetime
          @auth_datetime = nil unless instance_variable_defined?(:@auth_datetime)
          @auth_datetime
        end

        #
        # ===与信日時を設定する
        # - 与信日時を指定します。
        # - YYYYMMDDHH24MISS （年月日時分秒）の形式
        # - paymentType=emvj1またはemvj2の場合で、アドバイス取引の場合に指定します。
        # @param:: auth_datetime 与信日時
        #
        def auth_datetime=(auth_datetime)
          @auth_datetime = auth_datetime
        end

        #
        # ===レスポンスコードを取得する
        # @return:: レスポンスコード
        #
        def response_code
          @response_code = nil unless instance_variable_defined?(:@response_code)
          @response_code
        end

        #
        # ===レスポンスコードを設定する
        # - レスポンスコードを指定します。
        # - "   "：取引承認
        # - "G14"：取引拒否
        # - "G15"：取引拒否
        # - "G16"：取引拒否
        # - "G17"：取引拒否
        # - "G18"：取引拒否
        # - "G12"：取引拒否
        # - "G92"：取引拒否
        # - paymentType=emvj1またはemvj2の場合で、アドバイス取引の場合に指定します。
        # @param:: response_code レスポンスコード
        #
        def response_code=(response_code)
          @response_code = response_code
        end

        #
        # ===チップコンディションコードを取得する
        # @return:: チップコンディションコード
        #
        def chip_condition_code
          @chip_condition_code = nil unless instance_variable_defined?(:@chip_condition_code)
          @chip_condition_code
        end

        #
        # ===チップコンディションコードを設定する
        # - チップコンディションコードを指定します。
        # - "0"：IC対応端末における磁気ストライプ取引
        # - "1"：最新のIC読取に成功したが磁気ストライプにフォールバックした取引
        # - "2"：最新のIC読取に失敗し、磁気ストライプにフォールバックした取引
        # - " "：上記以外
        # - paymentType=jis1またはjis2の場合で、
        # - IC端末で磁気ストライプ取引を行った場合に指定します。
        # @param:: chip_condition_code チップコンディションコード
        #
        def chip_condition_code=(chip_condition_code)
          @chip_condition_code = chip_condition_code
        end

        #
        # ===強制オンラインを取得する
        # @return:: 強制オンライン
        #
        def forced_online
          @forced_online = nil unless instance_variable_defined?(:@forced_online)
          @forced_online
        end

        #
        # ===強制オンラインを設定する
        # - 強制オンラインを指定します。
        # - "0"：未実施
        # - "1"：強制オンラインによる取引
        # - paymentType=emvj1またはemvj2の場合で、アドバイス取引の場合に指定します。
        # @param:: forced_online 強制オンライン
        #
        def forced_online=(forced_online)
          @forced_online = forced_online
        end

        #
        # ===強制承認を取得する
        # @return:: 強制承認
        #
        def forced_approval
          @forced_approval = nil unless instance_variable_defined?(:@forced_approval)
          @forced_approval
        end

        #
        # ===強制承認を設定する
        # - 強制承認を指定します。
        # - "0"：未実施
        # - "1"：強制承認による取引
        # - paymentType=emvj1またはemvj2の場合で、アドバイス取引の場合に指定します。
        # @param:: forced_approval 強制承認
        #
        def forced_approval=(forced_approval)
          @forced_approval = forced_approval
        end

        #
        # ===オフライン区分を取得する
        # @return:: オフライン区分
        #
        def offline_type
          @offline_type = nil unless instance_variable_defined?(:@offline_type)
          @offline_type
        end

        #
        # ===オフライン区分を設定する
        # - オフライン区分を指定します。
        # - "0"：Tag8Aが「オフライン承認」「オフライン拒否」
        # - "1"：Tag8Aが「オンライン処理不可時のオフライン承認」「オンライン処理不可時のオフライン拒否」
        # - paymentType=emvj1またはemvj2の場合で、オフライン取引の場合に指定します。
        # @param:: offline_type オフライン区分
        #
        def offline_type=(offline_type)
          @offline_type = offline_type
        end

        #
        # ===非接触取引指定を取得する
        # @return:: 非接触取引指定
        #
        def is_contactless
          @is_contactless = nil unless instance_variable_defined?(:@is_contactless)
          @is_contactless
        end

        #
        # ===非接触取引指定を設定する
        # - 非接触取引指定を指定します。
        # - "true"： 非接触取引
        # - "false"： 通常取引
        # - paymentType=emvj1またはemvj2の場合に指定します。
        # - ※ 指定が無い場合は、false
        # @param:: is_contactless 非接触取引指定
        #
        def is_contactless=(is_contactless)
          @is_contactless = is_contactless
        end

        #
        # ===非接触区分を取得する
        # @return:: 非接触区分
        #
        def contactless_type
          @contactless_type = nil unless instance_variable_defined?(:@contactless_type)
          @contactless_type
        end

        #
        # ===非接触区分を設定する
        # - 非接触区分を指定します。
        # - "1"：非接触IC EMV相当
        # - "2"：非接触IC MS相当
        # - paymentType=emvj1またはemvj2の場合で、非接触取引の場合に指定します。
        # @param:: contactless_type 非接触取引指定
        #
        def contactless_type=(contactless_type)
          @contactless_type = contactless_type
        end

        #
        # ===拡張伝票情報を取得する
        # @return:: 拡張伝票情報
        #
        def ex_slip_info
          @ex_slip_info = nil unless instance_variable_defined?(:@ex_slip_info)
          @ex_slip_info
        end

        #
        # ===拡張伝票情報を設定する
        # - 半角英数字
        # - 25桁
        # - 拡張伝票情報を指定します。（任意指定）
        #
        # @param:: ex_slip_info 拡張伝票情報
        #
        def ex_slip_info=(ex_slip_info)
          @ex_slip_info = ex_slip_info
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

      end
    end
  end
end
