# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：電子マネー、コマンド名：決済の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class EmAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end

        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "em"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"

        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===決済サービスオプションを取得する
        # @return:: 決済サービスオプション
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===決済サービスオプションを設定する
        # - 決済サービスのオプションを指定します
        # - 例）
        # * モバイルEdy： "edy-mobile"
        # * パソリ(PC)： "edy-pc"
        # * モバイルEdyダイレクト： "edy-direct"
        # * Suicaモバイル(メール)： "suica-mobile-mail"
        # * モバイルSuicaアプリ： "suica-mobile-app"
        # * Suicaメール決済(PC)： "suica-pc-mail"
        # * Suica PCアプリ： "suica-pc-app"
        # * モバイルWaonアプリ決済：waon-mobile
        # * パソリ(PC)：waon-pc
        # * nanaco決済：tcc-redirect
        # * BitCash決済：bitcash-api
        #
        # @param:: service_option_type 決済サービスオプション
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # - ※Suicaに限り40桁を上限とする。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # - 支払金額となります。
        # - 例）2100
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===決済期限を取得する
        # @return:: 決済期限
        #
        def settlement_limit
          @settlement_limit = nil unless instance_variable_defined?(:@settlement_limit)
          @settlement_limit
        end

        #
        # ===決済期限を設定する
        # - 支払の期限となります。
        # - 支払期限を過ぎた決済については、消費者はアプリ上から確認できます。
        # - YYYYMMDDhhmmss の形式
        # - 例）20060901235959
        # @param:: settlement_limit 決済期限
        #
        def settlement_limit=(settlement_limit)
          @settlement_limit = settlement_limit
        end

        #
        # ===メールアドレスを取得する
        # @return:: メールアドレス
        #
        def mail_addr
          @mail_addr = nil unless instance_variable_defined?(:@mail_addr)
          @mail_addr
        end

        #
        # ===メールアドレスを設定する
        # - 決済依頼メールを送信する消費者の携帯電話メールアドレスとなります。
        # @param:: mail_addr メールアドレス
        #
        def mail_addr=(mail_addr)
          @mail_addr = mail_addr
        end

        #
        # ===転送メール送信要否を取得する
        # @return:: 転送メール送信要否
        #
        def forward_mail_flag
          @forward_mail_flag = nil unless instance_variable_defined?(:@forward_mail_flag)
          @forward_mail_flag
        end

        #
        # ===転送メール送信要否を設定する
        # - 決済依頼メール、決済完了メールのコピーメール又はBCCメールをマーチャントメールアドレス（merchant_mail_addr）に送信するか否かを設定します。
        # - 0： 送信不要
        # - 1： 送信要
        # @param:: forward_mail_flag 転送メール送信要否
        #
        def forward_mail_flag=(forward_mail_flag)
          @forward_mail_flag = forward_mail_flag
        end

        #
        # ===マーチャントメールアドレスを取得する
        # @return:: マーチャントメールアドレス
        #
        def merchant_mail_addr
          @merchant_mail_addr = nil unless instance_variable_defined?(:@merchant_mail_addr)
          @merchant_mail_addr
        end

        #
        # ===マーチャントメールアドレスを設定する
        # - 決済依頼メール、決済完了メールのコピーメール又はBCC メール先マーチャントメールアドレス。
        # - 以下の文字も使用できます。
        # - “.”(ドット)、“-”(ハイフン)、“_”(アンダースコア)、“@”(アットマーク) ||= nil
        # @param:: merchant_mail_addr マーチャントメールアドレス
        #
        def merchant_mail_addr=(merchant_mail_addr)
          @merchant_mail_addr = merchant_mail_addr
        end

        #
        # ===依頼メール付加情報を取得する
        # @return:: 依頼メール付加情報
        #
        def request_mail_add_info
          @request_mail_add_info = nil unless instance_variable_defined?(:@request_mail_add_info)
          @request_mail_add_info
        end

        #
        # ===依頼メール付加情報を設定する
        # - 支払依頼メールに追加される文字列（商品情報等）です。
        # @param:: request_mail_add_info 依頼メール付加情報
        #
        def request_mail_add_info=(request_mail_add_info)
          @request_mail_add_info = request_mail_add_info
        end

        #
        # ===完了メール付加情報を取得する
        # @return:: 完了メール付加情報
        #
        def complete_mail_add_info
          @complete_mail_add_info = nil unless instance_variable_defined?(:@complete_mail_add_info)
          @complete_mail_add_info
        end

        #
        # ===完了メール付加情報を設定する
        # - 決済完了メールに追加される文字列（遷移先URL 等）
        # @param:: complete_mail_add_info 完了メール付加情報
        #
        def complete_mail_add_info=(complete_mail_add_info)
          @complete_mail_add_info = complete_mail_add_info
        end

        #
        # ===ショップ名を取得する
        # @return:: ショップ名
        #
        def shop_name
          @shop_name = nil unless instance_variable_defined?(:@shop_name)
          @shop_name
        end

        #
        # ===ショップ名を設定する
        # - Edy で使用する店舗名
        # @param:: shop_name ショップ名
        #
        def shop_name=(shop_name)
          @shop_name = shop_name
        end

        #
        # ===完了メール送信要否を取得する
        # @return:: 完了メール送信要否
        #
        def complete_mail_flag
          @complete_mail_flag = nil unless instance_variable_defined?(:@complete_mail_flag)
          @complete_mail_flag
        end

        #
        # ===完了メール送信要否を設定する
        # - 決済完了時にメールを送信するか否かを設定します。
        # - 0： 送信不要　1： 送信要
        # @param:: complete_mail_flag 完了メール送信要否
        #
        def complete_mail_flag=(complete_mail_flag)
          @complete_mail_flag = complete_mail_flag
        end

        #
        # ===内容確認画面付加情報を取得する
        # @return:: 内容確認画面付加情報
        #
        def confirm_screen_add_info
          @confirm_screen_add_info = nil unless instance_variable_defined?(:@confirm_screen_add_info)
          @confirm_screen_add_info
        end

        #
        # ===内容確認画面付加情報を設定する
        # - 内容確認画面に表示する付加情報を設定します。
        # - モバイルSuica で決済内容確認画面に表示される文字列
        # @param:: confirm_screen_add_info 内容確認画面付加情報
        #
        def confirm_screen_add_info=(confirm_screen_add_info)
          @confirm_screen_add_info = confirm_screen_add_info
        end

        #
        # ===完了画面付加情報を取得する
        # @return:: 完了画面付加情報
        #
        def complete_screen_add_info
          @complete_screen_add_info = nil unless instance_variable_defined?(:@complete_screen_add_info)
          @complete_screen_add_info
        end

        #
        # ===完了画面付加情報を設定する
        # - 決済完了画面に表示する付加情報を設定します。
        # - モバイルSuica で決済完了画面に表示される文字列
        # @param:: complete_screen_add_info 完了画面付加情報
        #
        def complete_screen_add_info=(complete_screen_add_info)
          @complete_screen_add_info = complete_screen_add_info
        end

        #
        # ===画面タイトルを取得する
        # @return:: 画面タイトル
        #
        def screen_title
          @screen_title = nil unless instance_variable_defined?(:@screen_title)
          @screen_title
        end

        #
        # ===画面タイトルを設定する
        # - モバイルSuica で決済完了画面・決済確認画面等で「商品・サービス名」に表示されます。
        # @param:: screen_title 画面タイトル
        #
        def screen_title=(screen_title)
          @screen_title = screen_title
        end

        #
        # ===決済完了戻り先種別を取得する
        # @return:: 決済完了戻り先種別
        #
        def complete_return_kind
          @complete_return_kind = nil unless instance_variable_defined?(:@complete_return_kind)
          @complete_return_kind
        end

        #
        # ===決済完了戻り先種別を設定する
        # - モバイルSuica でアプリ終了時に遷移する先の種別
        # - 1： ローカルメニュー
        # - 2： モバイルSuica アプリを終了し「決済完了戻り先URL」へ遷移
        # @param:: complete_return_kind 決済完了戻り先種別
        #
        def complete_return_kind=(complete_return_kind)
          @complete_return_kind = complete_return_kind
        end

        #
        # ===決済完了戻り先URLを取得する
        # @return:: 決済完了戻り先URL
        #
        def complete_return_url
          @complete_return_url = nil unless instance_variable_defined?(:@complete_return_url)
          @complete_return_url
        end

        #
        # ===決済完了戻り先URLを設定する
        # - モバイルSuicaでアプリ終了時に遷移する先のURL
        # @param:: complete_return_url 決済完了戻り先URL
        #
        def complete_return_url=(complete_return_url)
          @complete_return_url = complete_return_url
        end

        #
        # ===決済完了通知URLを取得する
        # @return:: 決済完了通知URL
        #
        def complete_notice_url
          @complete_notice_url = nil unless instance_variable_defined?(:@complete_notice_url)
          @complete_notice_url
        end

        #
        # ===決済完了通知URLを設定する
        # - Edy Viewer にて支払いを完了した後に遷移するURL
        # @param:: complete_notice_url 決済完了通知URL
        #
        def complete_notice_url=(complete_notice_url)
          @complete_notice_url = complete_notice_url
        end

        #
        # ===販売区分を取得する
        # @return:: 販売区分
        #
        def sales_type
          @sales_type = nil unless instance_variable_defined?(:@sales_type)
          @sales_type
        end

        #
        # ===販売区分を設定する
        # - Edy で任意に登録する販売区分
        # - 　1：物販、　2：デジタル
        # @param:: sales_type 販売区分
        #
        def sales_type=(sales_type)
          @sales_type = sales_type
        end

        #
        # ===備考を取得する
        # @return:: 備考
        #
        def free
          @free = nil unless instance_variable_defined?(:@free)
          @free
        end

        #
        # ===備考を設定する
        # - 備考(商品詳細など)
        # @param:: free 備考
        #
        def free=(free)
          @free = free
        end

        #
        # ===成功時URLを取得する
        # @return:: 成功時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===成功時URLを設定する
        # - PaSoRi決済時、決済が成功した場合に遷移されるURL
        # @param:: success_url 成功時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===失敗時URLを取得する
        # @return:: 失敗時URL
        #
        def failure_url
          @failure_url = nil unless instance_variable_defined?(:@failure_url)
          @failure_url
        end

        #
        # ===失敗時URLを設定する
        # - PaSoRi決済時、決済が失敗した場合に遷移されるURL
        # @param:: failure_url 失敗時URL
        #
        def failure_url=(failure_url)
          @failure_url = failure_url
        end

        #
        # ===キャンセルURLを取得する
        # @return:: キャンセルURL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===キャンセルURLを設定する
        # - PaSoRi決済時、確認画面等でキャンセルボタンが押された場合に遷移されるURL
        # @param:: cancel_url キャンセルURL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===加盟店決済受付時刻を取得する
        # @return:: 加盟店決済受付時刻
        #
        def member_store_settle_entry_time
          @member_store_settle_entry_time = nil unless instance_variable_defined?(:@member_store_settle_entry_time)
          @member_store_settle_entry_time
        end

        #
        # ===加盟店決済受付時刻を設定する
        # - 加盟店側で当該決済を受付た時刻
        # - YYYYMMDDhhmmss の形式
        # - 例）20060901235959
        # @param:: member_store_settle_entry_time 加盟店決済受付時刻
        #
        def member_store_settle_entry_time=(member_store_settle_entry_time)
          @member_store_settle_entry_time = member_store_settle_entry_time
        end

        #
        # ===支払取消期限を取得する
        # @return:: 支払取消期限
        #
        def cancel_limit
          @cancel_limit = nil unless instance_variable_defined?(:@cancel_limit)
          @cancel_limit
        end

        #
        # ===支払取消期限を設定する
        # - 決済後、該当の支払を返金（取消）することができる期限。
        # - YYYYMMDDhhmmss の形式
        # - 例）20060901235959
        # @param:: cancel_limit 支払取消期限
        #
        def cancel_limit=(cancel_limit)
          @cancel_limit = cancel_limit
        end

        #
        # ===取引種別を取得する
        # @return:: 取引種別
        #
        def transaction_kind
          @cancel_transaction_kindlimit = nil unless instance_variable_defined?(:@cancel_transaction_kindlimit)
          @cancel_transaction_kindlimit
        end

        #
        # ===取引種別を設定する
        # - nanaco決済における取引の種別を指定します。
        # - "02"：電子マネー決済
        # @param:: transaction_kind 取引種別
        #
        def transaction_kind=(transaction_kind)
          @transaction_kind = transaction_kind
        end

        #
        # ===ユーザIDを取得する
        # @return:: ユーザID
        #
        def user_id
          @user_id = nil unless instance_variable_defined?(:@user_id)
          @user_id
        end

        #
        # ===ユーザIDを設定する
        # - 取引対象利用者を一意に特定可能なIDを指定します。
        # - RFC2822に準拠する。
        # @param:: user_id ユーザID
        #
        def user_id=(user_id)
          @user_id = user_id
        end

        #
        # ===ひらがなIDを取得する
        # @return:: ひらがなID
        #
        def hiragana_id
          @hiragana_id = nil unless instance_variable_defined?(:@hiragana_id)
          @hiragana_id
        end

        #
        # ===ひらがなIDを設定する
        # - ユーザが入力したひらがなID
        # - BitCash決済のみ使用
        # @param:: hiragana_id ひらがなID
        #
        def hiragana_id=(hiragana_id)
          @hiragana_id = hiragana_id
        end

        #
        # ===商品レイティングを取得する
        # @return:: 商品レイティング
        #
        def rating
          @rating = nil unless instance_variable_defined?(:@rating)
          @rating
        end

        #
        # ===商品レイティングを設定する
        # - 商品レイティングによって以下の値を指定
        # - STの場合：19 EXの場合：99
        # - BitCash決済のみ使用
        # @param:: rating 商品レイティング
        #
        def rating=(rating)
          @rating = rating
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

      end
    end
  end
end
