# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：MasterPass、コマンド名：与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class MasterpassAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "masterpass"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===支払い種別を取得する
        # @return:: 支払い種別
        #
        def jpo
          @jpo = nil unless instance_variable_defined?(:@jpo)
          @jpo
        end

        #
        # ===支払い種別を設定する
        # "10"　（一括払い）
        # "21"　（ボーナス一括）
        # "61Cxx"　（分割払い、xxに分割回数指定）
        # "80"　（リボルビング払い）
        # ※指定が無い場合は、"10"（一括払い）が適用されます。
        # @param:: jpo 支払い種別
        #
        def jpo=(jpo)
          @jpo = jpo
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # - false: 与信のみ
        # ※ 未指定の場合は、false:与信のみ。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===初回請求年月を取得する
        # @return:: 初回請求年月
        #
        def first_payment
          @first_payment = nil unless instance_variable_defined?(:@first_payment)
          @first_payment
        end

        #
        # ===初回請求年月を設定する
        # JPOが31,34,61で与信同時売上フラグ=trueの場合に初回請求月をYYMM形式で指定します。JPOが上記以外、または与信同時売上フラグがfalseの場合は設定されているとエラーになります。
        # 指定がない場合には初回請求年月を指定せずに売上を行います（JPOパラメータ内の数値で補完されません）。
        # 
        # @param:: first_payment 初回請求年月
        #
        def first_payment=(first_payment)
          @first_payment = first_payment
        end

        #
        # ===ボーナス初回年月を取得する
        # @return:: ボーナス初回年月
        #
        def bonus_first_payment
          @bonus_first_payment = nil unless instance_variable_defined?(:@bonus_first_payment)
          @bonus_first_payment
        end

        #
        # ===ボーナス初回年月を設定する
        # JPOが24,34で与信同時売上フラグ=trueの場合にボーナス初回月をYYMM形式で指定します。JPOが上記以外、または与信同時売上フラグがfalseの場合は設定されているとエラーになります。
        # 指定がない場合にはボーナス初回月を指定せずに売上を行います（JPOパラメータ内の数値で補完されません）。
        # 
        # @param:: bonus_first_payment ボーナス初回年月
        #
        def bonus_first_payment=(bonus_first_payment)
          @bonus_first_payment = bonus_first_payment
        end


      end
    end
  end
end
