# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：MasterPass、コマンド名：認証の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class MasterpassLoginRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "masterpass"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Login"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===合計金額を取得する
        # @return:: 合計金額
        #
        def item_amount
          @item_amount = nil unless instance_variable_defined?(:@item_amount)
          @item_amount
        end

        #
        # ===合計金額を設定する
        # 各商品金額の合計
        # - 1 以上かつ 99999999(8桁) 以下
        # @param:: item_amount 合計金額
        #
        def item_amount=(item_amount)
          @item_amount = item_amount
        end

        #
        # ===商品番号を取得する
        # @return:: 商品番号
        #
        def item_id
          @item_id = nil unless instance_variable_defined?(:@item_id)
          @item_id
        end

        #
        # ===商品番号を設定する
        # マーチャントシステム内で商品やサービスを特定するID
        # @param:: item_id 商品番号
        #
        def item_id=(item_id)
          @item_id = item_id
        end

        #
        # ===表示用商品説明1を取得する
        # @return:: 表示用商品説明1
        #
        def description1
          @description1 = nil unless instance_variable_defined?(:@description1)
          @description1
        end

        #
        # ===表示用商品説明1を設定する
        # 表示用商品説明1
        # - 100文字以内
        # @param:: description1 表示用商品説明1
        #
        def description1=(description1)
          @description1 = description1
        end

        #
        # ===表示用商品金額1を取得する
        # @return:: 表示用商品金額1
        #
        def value1
          @value1 = nil unless instance_variable_defined?(:@value1)
          @value1
        end

        #
        # ===表示用商品金額1を設定する
        # 表示用商品金額1を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # @param:: value1 表示用商品金額1
        #
        def value1=(value1)
          @value1 = value1
        end

        #
        # ===表示用商品数量1を取得する
        # @return:: 表示用商品数量1
        #
        def quantity1
          @quantity1 = nil unless instance_variable_defined?(:@quantity1)
          @quantity1
        end

        #
        # ===表示用商品数量1を設定する
        # 表示用商品数量1を指定します。
        # 1以上
        # @param:: quantity1 表示用商品数量1
        #
        def quantity1=(quantity1)
          @quantity1 = quantity1
        end

        #
        # ===表示用商品イメージURL1を取得する
        # @return:: 表示用商品イメージURL1
        #
        def image_url1
          @image_url1 = nil unless instance_variable_defined?(:@image_url1)
          @image_url1
        end

        #
        # ===表示用商品イメージURL1を設定する
        # 表示用商品のイメージ画像のURL1
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url1 表示用商品イメージURL1
        #
        def image_url1=(image_url1)
          @image_url1 = image_url1
        end

        #
        # ===表示用商品説明2を取得する
        # @return:: 表示用商品説明2
        #
        def description2
          @description2 = nil unless instance_variable_defined?(:@description2)
          @description2
        end

        #
        # ===表示用商品説明2を設定する
        # 表示用商品説明2
        # - 100文字以内
        # 表示用商品金額2、表示用商品数量2、表示用商品イメージURL2のいずれかが指定されている場合、必須
        # @param:: description2 表示用商品説明2
        #
        def description2=(description2)
          @description2 = description2
        end

        #
        # ===表示用商品金額2を取得する
        # @return:: 表示用商品金額2
        #
        def value2
          @value2 = nil unless instance_variable_defined?(:@value2)
          @value2
        end

        #
        # ===表示用商品金額2を設定する
        # 表示用商品金額2を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明2、表示用商品数量2、表示用商品イメージURL2のいずれかが指定されている場合、必須
        # @param:: value2 表示用商品金額2
        #
        def value2=(value2)
          @value2 = value2
        end

        #
        # ===表示用商品数量2を取得する
        # @return:: 表示用商品数量2
        #
        def quantity2
          @quantity2 = nil unless instance_variable_defined?(:@quantity2)
          @quantity2
        end

        #
        # ===表示用商品数量2を設定する
        # 表示用商品数量2を指定します。
        # 1以上
        # 表示用商品説明2、表示用商品金額2、表示用商品イメージURL2のいずれかが指定されている場合、必須
        # @param:: quantity2 表示用商品数量2
        #
        def quantity2=(quantity2)
          @quantity2 = quantity2
        end

        #
        # ===表示用商品イメージURL2を取得する
        # @return:: 表示用商品イメージURL2
        #
        def image_url2
          @image_url2 = nil unless instance_variable_defined?(:@image_url2)
          @image_url2
        end

        #
        # ===表示用商品イメージURL2を設定する
        # 表示用商品のイメージ画像のURL2
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url2 表示用商品イメージURL2
        #
        def image_url2=(image_url2)
          @image_url2 = image_url2
        end

        #
        # ===表示用商品説明3を取得する
        # @return:: 表示用商品説明3
        #
        def description3
          @description3 = nil unless instance_variable_defined?(:@description3)
          @description3
        end

        #
        # ===表示用商品説明3を設定する
        # 表示用商品説明3
        # - 100文字以内
        # 表示用商品金額3、表示用商品数量3、表示用商品イメージURL3のいずれかが指定されている場合、必須
        # @param:: description3 表示用商品説明3
        #
        def description3=(description3)
          @description3 = description3
        end

        #
        # ===表示用商品金額3を取得する
        # @return:: 表示用商品金額3
        #
        def value3
          @value3 = nil unless instance_variable_defined?(:@value3)
          @value3
        end

        #
        # ===表示用商品金額3を設定する
        # 表示用商品金額3を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明3、表示用商品数量3、表示用商品イメージURL3のいずれかが指定されている場合、必須
        # @param:: value3 表示用商品金額3
        #
        def value3=(value3)
          @value3 = value3
        end

        #
        # ===表示用商品数量3を取得する
        # @return:: 表示用商品数量3
        #
        def quantity3
          @quantity3 = nil unless instance_variable_defined?(:@quantity3)
          @quantity3
        end

        #
        # ===表示用商品数量3を設定する
        # 表示用商品数量3を指定します。
        # 1以上
        # 表示用商品説明3、表示用商品金額3、表示用商品イメージURL3のいずれかが指定されている場合、必須
        # @param:: quantity3 表示用商品数量3
        #
        def quantity3=(quantity3)
          @quantity3 = quantity3
        end

        #
        # ===表示用商品イメージURL3を取得する
        # @return:: 表示用商品イメージURL3
        #
        def image_url3
          @image_url3 = nil unless instance_variable_defined?(:@image_url3)
          @image_url3
        end

        #
        # ===表示用商品イメージURL3を設定する
        # 表示用商品のイメージ画像のURL3
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url3 表示用商品イメージURL3
        #
        def image_url3=(image_url3)
          @image_url3 = image_url3
        end

        #
        # ===表示用商品説明4を取得する
        # @return:: 表示用商品説明4
        #
        def description4
          @description4 = nil unless instance_variable_defined?(:@description4)
          @description4
        end

        #
        # ===表示用商品説明4を設定する
        # 表示用商品説明4
        # - 100文字以内
        # 表示用商品金額4、表示用商品数量4、表示用商品イメージURL4のいずれかが指定されている場合、必須
        # @param:: description4 表示用商品説明4
        #
        def description4=(description4)
          @description4 = description4
        end

        #
        # ===表示用商品金額4を取得する
        # @return:: 表示用商品金額4
        #
        def value4
          @value4 = nil unless instance_variable_defined?(:@value4)
          @value4
        end

        #
        # ===表示用商品金額4を設定する
        # 表示用商品金額4を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明4、表示用商品数量4、表示用商品イメージURL4のいずれかが指定されている場合、必須
        # @param:: value4 表示用商品金額4
        #
        def value4=(value4)
          @value4 = value4
        end

        #
        # ===表示用商品数量4を取得する
        # @return:: 表示用商品数量4
        #
        def quantity4
          @quantity4 = nil unless instance_variable_defined?(:@quantity4)
          @quantity4
        end

        #
        # ===表示用商品数量4を設定する
        # 表示用商品数量4を指定します。
        # 1以上
        # 表示用商品説明4、表示用商品金額4、表示用商品イメージURL4のいずれかが指定されている場合、必須
        # @param:: quantity4 表示用商品数量4
        #
        def quantity4=(quantity4)
          @quantity4 = quantity4
        end

        #
        # ===表示用商品イメージURL4を取得する
        # @return:: 表示用商品イメージURL4
        #
        def image_url4
          @image_url4 = nil unless instance_variable_defined?(:@image_url4)
          @image_url4
        end

        #
        # ===表示用商品イメージURL4を設定する
        # 表示用商品のイメージ画像のURL4
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url4 表示用商品イメージURL4
        #
        def image_url4=(image_url4)
          @image_url4 = image_url4
        end

        #
        # ===表示用商品説明5を取得する
        # @return:: 表示用商品説明5
        #
        def description5
          @description5 = nil unless instance_variable_defined?(:@description5)
          @description5
        end

        #
        # ===表示用商品説明5を設定する
        # 表示用商品説明5
        # - 100文字以内
        # 表示用商品金額5、表示用商品数量5、表示用商品イメージURL5のいずれかが指定されている場合、必須
        # @param:: description5 表示用商品説明5
        #
        def description5=(description5)
          @description5 = description5
        end

        #
        # ===表示用商品金額5を取得する
        # @return:: 表示用商品金額5
        #
        def value5
          @value5 = nil unless instance_variable_defined?(:@value5)
          @value5
        end

        #
        # ===表示用商品金額5を設定する
        # 表示用商品金額5を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明5、表示用商品数量5、表示用商品イメージURL5のいずれかが指定されている場合、必須
        # @param:: value5 表示用商品金額5
        #
        def value5=(value5)
          @value5 = value5
        end

        #
        # ===表示用商品数量5を取得する
        # @return:: 表示用商品数量5
        #
        def quantity5
          @quantity5 = nil unless instance_variable_defined?(:@quantity5)
          @quantity5
        end

        #
        # ===表示用商品数量5を設定する
        # 表示用商品数量5を指定します。
        # 1以上
        # 表示用商品説明5、表示用商品金額5、表示用商品イメージURL5のいずれかが指定されている場合、必須
        # @param:: quantity5 表示用商品数量5
        #
        def quantity5=(quantity5)
          @quantity5 = quantity5
        end

        #
        # ===表示用商品イメージURL5を取得する
        # @return:: 表示用商品イメージURL5
        #
        def image_url5
          @image_url5 = nil unless instance_variable_defined?(:@image_url5)
          @image_url5
        end

        #
        # ===表示用商品イメージURL5を設定する
        # 表示用商品のイメージ画像のURL5
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url5 表示用商品イメージURL5
        #
        def image_url5=(image_url5)
          @image_url5 = image_url5
        end

        #
        # ===表示用商品説明6を取得する
        # @return:: 表示用商品説明6
        #
        def description6
          @description6 = nil unless instance_variable_defined?(:@description6)
          @description6
        end

        #
        # ===表示用商品説明6を設定する
        # 表示用商品説明6
        # - 100文字以内
        # 表示用商品金額6、表示用商品数量6、表示用商品イメージURL6のいずれかが指定されている場合、必須
        # @param:: description6 表示用商品説明6
        #
        def description6=(description6)
          @description6 = description6
        end

        #
        # ===表示用商品金額6を取得する
        # @return:: 表示用商品金額6
        #
        def value6
          @value6 = nil unless instance_variable_defined?(:@value6)
          @value6
        end

        #
        # ===表示用商品金額6を設定する
        # 表示用商品金額6を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明6、表示用商品数量6、表示用商品イメージURL6のいずれかが指定されている場合、必須
        # @param:: value6 表示用商品金額6
        #
        def value6=(value6)
          @value6 = value6
        end

        #
        # ===表示用商品数量6を取得する
        # @return:: 表示用商品数量6
        #
        def quantity6
          @quantity6 = nil unless instance_variable_defined?(:@quantity6)
          @quantity6
        end

        #
        # ===表示用商品数量6を設定する
        # 表示用商品数量6を指定します。
        # 1以上
        # 表示用商品説明6、表示用商品金額6、表示用商品イメージURL6のいずれかが指定されている場合、必須
        # @param:: quantity6 表示用商品数量6
        #
        def quantity6=(quantity6)
          @quantity6 = quantity6
        end

        #
        # ===表示用商品イメージURL6を取得する
        # @return:: 表示用商品イメージURL6
        #
        def image_url6
          @image_url6 = nil unless instance_variable_defined?(:@image_url6)
          @image_url6
        end

        #
        # ===表示用商品イメージURL6を設定する
        # 表示用商品のイメージ画像のURL6
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url6 表示用商品イメージURL6
        #
        def image_url6=(image_url6)
          @image_url6 = image_url6
        end

        #
        # ===表示用商品説明7を取得する
        # @return:: 表示用商品説明7
        #
        def description7
          @description7 = nil unless instance_variable_defined?(:@description7)
          @description7
        end

        #
        # ===表示用商品説明7を設定する
        # 表示用商品説明7
        # - 100文字以内
        # 表示用商品金額7、表示用商品数量7、表示用商品イメージURL7のいずれかが指定されている場合、必須
        # @param:: description7 表示用商品説明7
        #
        def description7=(description7)
          @description7 = description7
        end

        #
        # ===表示用商品金額7を取得する
        # @return:: 表示用商品金額7
        #
        def value7
          @value7 = nil unless instance_variable_defined?(:@value7)
          @value7
        end

        #
        # ===表示用商品金額7を設定する
        # 表示用商品金額7を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明7、表示用商品数量7、表示用商品イメージURL7のいずれかが指定されている場合、必須
        # @param:: value7 表示用商品金額7
        #
        def value7=(value7)
          @value7 = value7
        end

        #
        # ===表示用商品数量7を取得する
        # @return:: 表示用商品数量7
        #
        def quantity7
          @quantity7 = nil unless instance_variable_defined?(:@quantity7)
          @quantity7
        end

        #
        # ===表示用商品数量7を設定する
        # 表示用商品数量7を指定します。
        # 1以上
        # 表示用商品説明7、表示用商品金額7、表示用商品イメージURL7のいずれかが指定されている場合、必須
        # @param:: quantity7 表示用商品数量7
        #
        def quantity7=(quantity7)
          @quantity7 = quantity7
        end

        #
        # ===表示用商品イメージURL7を取得する
        # @return:: 表示用商品イメージURL7
        #
        def image_url7
          @image_url7 = nil unless instance_variable_defined?(:@image_url7)
          @image_url7
        end

        #
        # ===表示用商品イメージURL7を設定する
        # 表示用商品のイメージ画像のURL7
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url7 表示用商品イメージURL7
        #
        def image_url7=(image_url7)
          @image_url7 = image_url7
        end

        #
        # ===表示用商品説明8を取得する
        # @return:: 表示用商品説明8
        #
        def description8
          @description8 = nil unless instance_variable_defined?(:@description8)
          @description8
        end

        #
        # ===表示用商品説明8を設定する
        # 表示用商品説明8
        # - 100文字以内
        # 表示用商品金額8、表示用商品数量8、表示用商品イメージURL8のいずれかが指定されている場合、必須
        # @param:: description8 表示用商品説明8
        #
        def description8=(description8)
          @description8 = description8
        end

        #
        # ===表示用商品金額8を取得する
        # @return:: 表示用商品金額8
        #
        def value8
          @value8 = nil unless instance_variable_defined?(:@value8)
          @value8
        end

        #
        # ===表示用商品金額8を設定する
        # 表示用商品金額8を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明8、表示用商品数量8、表示用商品イメージURL8のいずれかが指定されている場合、必須
        # @param:: value8 表示用商品金額8
        #
        def value8=(value8)
          @value8 = value8
        end

        #
        # ===表示用商品数量8を取得する
        # @return:: 表示用商品数量8
        #
        def quantity8
          @quantity8 = nil unless instance_variable_defined?(:@quantity8)
          @quantity8
        end

        #
        # ===表示用商品数量8を設定する
        # 表示用商品数量8を指定します。
        # 1以上
        # 表示用商品説明8、表示用商品金額8、表示用商品イメージURL8のいずれかが指定されている場合、必須
        # @param:: quantity8 表示用商品数量8
        #
        def quantity8=(quantity8)
          @quantity8 = quantity8
        end

        #
        # ===表示用商品イメージURL8を取得する
        # @return:: 表示用商品イメージURL8
        #
        def image_url8
          @image_url8 = nil unless instance_variable_defined?(:@image_url8)
          @image_url8
        end

        #
        # ===表示用商品イメージURL8を設定する
        # 表示用商品のイメージ画像のURL8
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url8 表示用商品イメージURL8
        #
        def image_url8=(image_url8)
          @image_url8 = image_url8
        end

        #
        # ===表示用商品説明9を取得する
        # @return:: 表示用商品説明9
        #
        def description9
          @description9 = nil unless instance_variable_defined?(:@description9)
          @description9
        end

        #
        # ===表示用商品説明9を設定する
        # 表示用商品説明9
        # - 100文字以内
        # 表示用商品金額9、表示用商品数量9、表示用商品イメージURL9のいずれかが指定されている場合、必須
        # @param:: description9 表示用商品説明9
        #
        def description9=(description9)
          @description9 = description9
        end

        #
        # ===表示用商品金額9を取得する
        # @return:: 表示用商品金額9
        #
        def value9
          @value9 = nil unless instance_variable_defined?(:@value9)
          @value9
        end

        #
        # ===表示用商品金額9を設定する
        # 表示用商品金額9を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明9、表示用商品数量9、表示用商品イメージURL9のいずれかが指定されている場合、必須
        # @param:: value9 表示用商品金額9
        #
        def value9=(value9)
          @value9 = value9
        end

        #
        # ===表示用商品数量9を取得する
        # @return:: 表示用商品数量9
        #
        def quantity9
          @quantity9 = nil unless instance_variable_defined?(:@quantity9)
          @quantity9
        end

        #
        # ===表示用商品数量9を設定する
        # 表示用商品数量9を指定します。
        # 1以上
        # 表示用商品説明9、表示用商品金額9、表示用商品イメージURL9のいずれかが指定されている場合、必須
        # @param:: quantity9 表示用商品数量9
        #
        def quantity9=(quantity9)
          @quantity9 = quantity9
        end

        #
        # ===表示用商品イメージURL9を取得する
        # @return:: 表示用商品イメージURL9
        #
        def image_url9
          @image_url9 = nil unless instance_variable_defined?(:@image_url9)
          @image_url9
        end

        #
        # ===表示用商品イメージURL9を設定する
        # 表示用商品のイメージ画像のURL9
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url9 表示用商品イメージURL9
        #
        def image_url9=(image_url9)
          @image_url9 = image_url9
        end

        #
        # ===表示用商品説明10を取得する
        # @return:: 表示用商品説明10
        #
        def description10
          @description10 = nil unless instance_variable_defined?(:@description10)
          @description10
        end

        #
        # ===表示用商品説明10を設定する
        # 表示用商品説明10
        # - 100文字以内
        # 表示用商品金額10、表示用商品数量10、表示用商品イメージURL10のいずれかが指定されている場合、必須
        # @param:: description10 表示用商品説明10
        #
        def description10=(description10)
          @description10 = description10
        end

        #
        # ===表示用商品金額10を取得する
        # @return:: 表示用商品金額10
        #
        def value10
          @value10 = nil unless instance_variable_defined?(:@value10)
          @value10
        end

        #
        # ===表示用商品金額10を設定する
        # 表示用商品金額10を指定します。
        # - 1 以上かつ 99999999(8桁) 以下
        # 表示用商品説明10、表示用商品数量10、表示用商品イメージURL10のいずれかが指定されている場合、必須
        # @param:: value10 表示用商品金額10
        #
        def value10=(value10)
          @value10 = value10
        end

        #
        # ===表示用商品数量10を取得する
        # @return:: 表示用商品数量10
        #
        def quantity10
          @quantity10 = nil unless instance_variable_defined?(:@quantity10)
          @quantity10
        end

        #
        # ===表示用商品数量10を設定する
        # 表示用商品数量10を指定します。
        # 1以上
        # 表示用商品説明10、表示用商品金額10、表示用商品イメージURL10のいずれかが指定されている場合、必須
        # @param:: quantity10 表示用商品数量10
        #
        def quantity10=(quantity10)
          @quantity10 = quantity10
        end

        #
        # ===表示用商品イメージURL10を取得する
        # @return:: 表示用商品イメージURL10
        #
        def image_url10
          @image_url10 = nil unless instance_variable_defined?(:@image_url10)
          @image_url10
        end

        #
        # ===表示用商品イメージURL10を設定する
        # 表示用商品のイメージ画像のURL10
        # ※MasterPassでユーザ認証時に表示されます
        # @param:: image_url10 表示用商品イメージURL10
        #
        def image_url10=(image_url10)
          @image_url10 = image_url10
        end

        #
        # ===配送先抑止フラグを取得する
        # @return:: 配送先抑止フラグ
        #
        def suppress_shipping_address
          @suppress_shipping_address = nil unless instance_variable_defined?(:@suppress_shipping_address)
          @suppress_shipping_address
        end

        #
        # ===配送先抑止フラグを設定する
        # - true : 配送先表示抑止
        # - false: 配送先表示
        # ※ 未指定の場合は、false:配送先表示。
        # @param:: suppress_shipping_address 配送先抑止フラグ
        #
        def suppress_shipping_address=(suppress_shipping_address)
          @suppress_shipping_address = suppress_shipping_address
        end

        #
        # ===配送先許可エリアを取得する
        # @return:: 配送先許可エリア
        #
        def shipping_location_profile
          @shipping_location_profile = nil unless instance_variable_defined?(:@shipping_location_profile)
          @shipping_location_profile
        end

        #
        # ===配送先許可エリアを設定する
        # 配送先を許可する国名をカンマ区切りで指定します。
        # - 半角256文字以内
        # 例） "USA,JPN" など
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: shipping_location_profile 配送先許可エリア
        #
        def shipping_location_profile=(shipping_location_profile)
          @shipping_location_profile = shipping_location_profile
        end

        #
        # ===3Dセキュアを取得する
        # @return:: 3Dセキュア
        #
        def d3_flag
          @d3_flag = nil unless instance_variable_defined?(:@d3_flag)
          @d3_flag
        end

        #
        # ===3Dセキュアを設定する
        # - true : 3Dセキュア
        # - false: 3Dセキュアなし
        # ※ 未指定の場合は、false:3Dセキュアなし。
        # @param:: d3_flag 3Dセキュア
        #
        def d3_flag=(d3_flag)
          @d3_flag = d3_flag
        end

        #
        # ===認証完了時URLを取得する
        # @return:: 認証完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===認証完了時URLを設定する
        # ユーザ認証完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: success_url 認証完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===認証キャンセル時URLを取得する
        # @return:: 認証キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===認証キャンセル時URLを設定する
        # ユーザ認証キャンセル後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: cancel_url 認証キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===認証エラー時URLを取得する
        # @return:: 認証エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===認証エラー時URLを設定する
        # ユーザ認証エラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角256文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: error_url 認証エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end


      end
    end
  end
end
