# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：merpay、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class MerpayAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "merpay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "barcode":バーコード決済
        # - "online":オンライン決済
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - バーコード決済：1以上かつ 1000000(7桁) 以下
        # - オンライン決済：1以上かつ 1000000(7桁) 以下　※
        # 
        # ※accountingTypeが"1:随時" かつconsentAuthTypeが"0:承諾のみ"の場合は、0または未設定のみ許容する。
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===課金種別を取得する
        # @return:: 課金種別
        #
        def accounting_type
          @accounting_type = nil unless instance_variable_defined?(:@accounting_type)
          @accounting_type
        end

        #
        # ===課金種別を設定する
        # - 0:都度
        # - 1:随時
        # 
        # serviceOptionType="barcode"（バーコード決済） ： 指定できません
        # serviceOptionType="online"（オンライン決済）    ： 指定任意※
        # 
        # ※オンライン決済で未指定の場合、"0"都度決済になります。
        # @param:: accounting_type 課金種別
        #
        def accounting_type=(accounting_type)
          @accounting_type = accounting_type
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # - false : 与信のみ("バーコード決済では指定不可")
        # ※バーコード決済で未指定の場合は、true:与信同時売上。  
        # ※オンライン決済で未指定の場合は、false:与信のみ。
        # ※accountingTypeが"1:随時"かつconsentAuthTypeが"0:承諾のみ"の場合、当項目は指定不可とする。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗IDを指定します。
        # - 最大文字数:32byte
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗端末IDを取得する
        # @return:: 店舗端末ID
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===店舗端末IDを設定する
        # 店舗端末IDを指定します。
        # - 最大文字数:32byte
        # @param:: terminal_id 店舗端末ID
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===従業員IDを取得する
        # @return:: 従業員ID
        #
        def operator_id
          @operator_id = nil unless instance_variable_defined?(:@operator_id)
          @operator_id
        end

        #
        # ===従業員IDを設定する
        # 従業員IDを指定します。
        # - 最大文字数:128byte
        # @param:: operator_id 従業員ID
        #
        def operator_id=(operator_id)
          @operator_id = operator_id
        end

        #
        # ===伝票コードを取得する
        # @return:: 伝票コード
        #
        def slip_code
          @slip_code = nil unless instance_variable_defined?(:@slip_code)
          @slip_code
        end

        #
        # ===伝票コードを設定する
        # 伝票コードを指定します。
        # - 最大文字数:128byte
        # @param:: slip_code 伝票コード
        #
        def slip_code=(slip_code)
          @slip_code = slip_code
        end

        #
        # ===決済成功URLを取得する
        # @return:: 決済成功URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済成功URLを設定する
        # 決済成功時の戻り先となるURL
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: success_url 決済成功URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済キャンセルURLを取得する
        # @return:: 決済キャンセルURL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===決済キャンセルURLを設定する
        # 決済キャンセル時の戻り先となるURL
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: cancel_url 決済キャンセルURL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===PUSH通知URLを取得する
        # @return:: PUSH通知URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===PUSH通知URLを設定する
        # 決済結果を応答するPush通知先URL
        # ※未指定の場合は、MAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: push_url PUSH通知URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===ワンタイムコードを取得する
        # @return:: ワンタイムコード
        #
        def one_time_code
          @one_time_code = nil unless instance_variable_defined?(:@one_time_code)
          @one_time_code
        end

        #
        # ===ワンタイムコードを設定する
        # バーコード決済を利用する際のQRコード、バーコードの値を指定します。
        # 記号は、"+"(プラス)、"/"(スラッシュ)、"="(イコール)が使用可能です。
        # @param:: one_time_code ワンタイムコード
        #
        def one_time_code=(one_time_code)
          @one_time_code = one_time_code
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def name
          @name = nil unless instance_variable_defined?(:@name)
          @name
        end

        #
        # ===商品名を設定する
        # ※かんたん出品連携利用時は必須
        # @param:: name 商品名
        #
        def name=(name)
          @name = name
        end

        #
        # ===商品説明を取得する
        # @return:: 商品説明
        #
        def description
          @description = nil unless instance_variable_defined?(:@description)
          @description
        end

        #
        # ===商品説明を設定する
        # ※かんたん出品連携利用時は必須
        # @param:: description 商品説明
        #
        def description=(description)
          @description = description
        end

        #
        # ===商品画像URL1を取得する
        # @return:: 商品画像URL1
        #
        def image_url1
          @image_url1 = nil unless instance_variable_defined?(:@image_url1)
          @image_url1
        end

        #
        # ===商品画像URL1を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url1 商品画像URL1
        #
        def image_url1=(image_url1)
          @image_url1 = image_url1
        end

        #
        # ===商品画像URL2を取得する
        # @return:: 商品画像URL2
        #
        def image_url2
          @image_url2 = nil unless instance_variable_defined?(:@image_url2)
          @image_url2
        end

        #
        # ===商品画像URL2を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url2 商品画像URL2
        #
        def image_url2=(image_url2)
          @image_url2 = image_url2
        end

        #
        # ===商品画像URL3を取得する
        # @return:: 商品画像URL3
        #
        def image_url3
          @image_url3 = nil unless instance_variable_defined?(:@image_url3)
          @image_url3
        end

        #
        # ===商品画像URL3を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url3 商品画像URL3
        #
        def image_url3=(image_url3)
          @image_url3 = image_url3
        end

        #
        # ===商品画像URL4を取得する
        # @return:: 商品画像URL4
        #
        def image_url4
          @image_url4 = nil unless instance_variable_defined?(:@image_url4)
          @image_url4
        end

        #
        # ===商品画像URL4を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url4 商品画像URL4
        #
        def image_url4=(image_url4)
          @image_url4 = image_url4
        end

        #
        # ===商品画像URL5を取得する
        # @return:: 商品画像URL5
        #
        def image_url5
          @image_url5 = nil unless instance_variable_defined?(:@image_url5)
          @image_url5
        end

        #
        # ===商品画像URL5を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url5 商品画像URL5
        #
        def image_url5=(image_url5)
          @image_url5 = image_url5
        end

        #
        # ===商品画像URL6を取得する
        # @return:: 商品画像URL6
        #
        def image_url6
          @image_url6 = nil unless instance_variable_defined?(:@image_url6)
          @image_url6
        end

        #
        # ===商品画像URL6を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url6 商品画像URL6
        #
        def image_url6=(image_url6)
          @image_url6 = image_url6
        end

        #
        # ===商品画像URL7を取得する
        # @return:: 商品画像URL7
        #
        def image_url7
          @image_url7 = nil unless instance_variable_defined?(:@image_url7)
          @image_url7
        end

        #
        # ===商品画像URL7を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url7 商品画像URL7
        #
        def image_url7=(image_url7)
          @image_url7 = image_url7
        end

        #
        # ===商品画像URL8を取得する
        # @return:: 商品画像URL8
        #
        def image_url8
          @image_url8 = nil unless instance_variable_defined?(:@image_url8)
          @image_url8
        end

        #
        # ===商品画像URL8を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url8 商品画像URL8
        #
        def image_url8=(image_url8)
          @image_url8 = image_url8
        end

        #
        # ===商品画像URL9を取得する
        # @return:: 商品画像URL9
        #
        def image_url9
          @image_url9 = nil unless instance_variable_defined?(:@image_url9)
          @image_url9
        end

        #
        # ===商品画像URL9を設定する
        # ※かんたん出品連携利用時は必須
        # - ただし、やむを得ない場合のみ、メルペイ営業担当と相談の上、
        #    かんたん出品連携の利用が可能になる場合あり
        # @param:: image_url9 商品画像URL9
        #
        def image_url9=(image_url9)
          @image_url9 = image_url9
        end

        #
        # ===カテゴリ名を取得する
        # @return:: カテゴリ名
        #
        def category
          @category = nil unless instance_variable_defined?(:@category)
          @category
        end

        #
        # ===カテゴリ名を設定する
        # @param:: category カテゴリ名
        #
        def category=(category)
          @category = category
        end

        #
        # ===サイズを取得する
        # @return:: サイズ
        #
        def size
          @size = nil unless instance_variable_defined?(:@size)
          @size
        end

        #
        # ===サイズを設定する
        # @param:: size サイズ
        #
        def size=(size)
          @size = size
        end

        #
        # ===ブランド名を取得する
        # @return:: ブランド名
        #
        def brand
          @brand = nil unless instance_variable_defined?(:@brand)
          @brand
        end

        #
        # ===ブランド名を設定する
        # @param:: brand ブランド名
        #
        def brand=(brand)
          @brand = brand
        end

        #
        # ===色を取得する
        # @return:: 色
        #
        def color
          @color = nil unless instance_variable_defined?(:@color)
          @color
        end

        #
        # ===色を設定する
        # @param:: color 色
        #
        def color=(color)
          @color = color
        end

        #
        # ===定価を取得する
        # @return:: 定価
        #
        def list_price
          @list_price = nil unless instance_variable_defined?(:@list_price)
          @list_price
        end

        #
        # ===定価を設定する
        # - 1 以上かつ 1000000(7桁) 以下
        # @param:: list_price 定価
        #
        def list_price=(list_price)
          @list_price = list_price
        end

        #
        # ===購入時価格を取得する
        # @return:: 購入時価格
        #
        def unit_price
          @unit_price = nil unless instance_variable_defined?(:@unit_price)
          @unit_price
        end

        #
        # ===購入時価格を設定する
        # - 1 以上かつ 1000000(7桁) 以下
        # ※かんたん出品連携利用時は必須
        # @param:: unit_price 購入時価格
        #
        def unit_price=(unit_price)
          @unit_price = unit_price
        end

        #
        # ===購入数を取得する
        # @return:: 購入数
        #
        def quantity
          @quantity = nil unless instance_variable_defined?(:@quantity)
          @quantity
        end

        #
        # ===購入数を設定する
        # ※かんたん出品連携利用時は必須
        # @param:: quantity 購入数
        #
        def quantity=(quantity)
          @quantity = quantity
        end

        #
        # ===製品管理コード(SKU)を取得する
        # @return:: 製品管理コード(SKU)
        #
        def item_code
          @item_code = nil unless instance_variable_defined?(:@item_code)
          @item_code
        end

        #
        # ===製品管理コード(SKU)を設定する
        # ※かんたん出品連携利用時は必須
        # @param:: item_code 製品管理コード(SKU)
        #
        def item_code=(item_code)
          @item_code = item_code
        end

        #
        # ===JANコードを取得する
        # @return:: JANコード
        #
        def jan_code
          @jan_code = nil unless instance_variable_defined?(:@jan_code)
          @jan_code
        end

        #
        # ===JANコードを設定する
        # @param:: jan_code JANコード
        #
        def jan_code=(jan_code)
          @jan_code = jan_code
        end

        #
        # ===商品カテゴリIDを取得する
        # @return:: 商品カテゴリID
        #
        def category_id
          @category_id = nil unless instance_variable_defined?(:@category_id)
          @category_id
        end

        #
        # ===商品カテゴリIDを設定する
        # @param:: category_id 商品カテゴリID
        #
        def category_id=(category_id)
          @category_id = category_id
        end

        #
        # ===配送先情報フラグを取得する
        # @return:: 配送先情報フラグ
        #
        def use_delivery_address
          @use_delivery_address = nil unless instance_variable_defined?(:@use_delivery_address)
          @use_delivery_address
        end

        #
        # ===配送先情報フラグを設定する
        # - true : merpayより配送先情報必要
        # - false : merpayより配送先情報不要
        # ※未指定の場合は、falseとする
        # @param:: use_delivery_address 配送先情報フラグ
        #
        def use_delivery_address=(use_delivery_address)
          @use_delivery_address = use_delivery_address
        end

        #
        # ===購入者情報フラグを取得する
        # @return:: 購入者情報フラグ
        #
        def use_buyer_info
          @use_buyer_info = nil unless instance_variable_defined?(:@use_buyer_info)
          @use_buyer_info
        end

        #
        # ===購入者情報フラグを設定する
        # - true : merpayより購入者情報必要
        # - false : merpayより購入者情報不要
        # ※未指定の場合は、falseとする
        # @param:: use_buyer_info 購入者情報フラグ
        #
        def use_buyer_info=(use_buyer_info)
          @use_buyer_info = use_buyer_info
        end

        #
        # ===提供サービス名を取得する
        # @return:: 提供サービス名
        #
        def preapproved_service_name
          @preapproved_service_name = nil unless instance_variable_defined?(:@preapproved_service_name)
          @preapproved_service_name
        end

        #
        # ===提供サービス名を設定する
        # 随時決済の場合のみ設定
        # @param:: preapproved_service_name 提供サービス名
        #
        def preapproved_service_name=(preapproved_service_name)
          @preapproved_service_name = preapproved_service_name
        end

        #
        # ===提供サービス説明を取得する
        # @return:: 提供サービス説明
        #
        def preapproved_service_description
          @preapproved_service_description = nil unless instance_variable_defined?(:@preapproved_service_description)
          @preapproved_service_description
        end

        #
        # ===提供サービス説明を設定する
        # 随時決済の場合のみ設定
        # @param:: preapproved_service_description 提供サービス説明
        #
        def preapproved_service_description=(preapproved_service_description)
          @preapproved_service_description = preapproved_service_description
        end

        #
        # ===ユーザエージェントを取得する
        # @return:: ユーザエージェント
        #
        def user_agent
          @user_agent = nil unless instance_variable_defined?(:@user_agent)
          @user_agent
        end

        #
        # ===ユーザエージェントを設定する
        # @param:: user_agent ユーザエージェント
        #
        def user_agent=(user_agent)
          @user_agent = user_agent
        end

        #
        # ===承諾時決済タイプを取得する
        # @return:: 承諾時決済タイプ
        #
        def consent_auth_type
          @consent_auth_type = nil unless instance_variable_defined?(:@consent_auth_type)
          @consent_auth_type
        end

        #
        # ===承諾時決済タイプを設定する
        # - 0 : 承諾のみ
        # - 1 : 承諾同時決済
        # 
        # ※accountingTypeが"1:随時"の場合に限り、当項目は指定可能とする
        # ※未設定の場合は"0:承諾のみ"となります。
        # @param:: consent_auth_type 承諾時決済タイプ
        #
        def consent_auth_type=(consent_auth_type)
          @consent_auth_type = consent_auth_type
        end


      end
    end
  end
end
