# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_credit_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：MPI、コマンド名：再取引の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class MpiReAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentCreditRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "mpi"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "ReAuthorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # "mpi-none" ： MPI 単体サービス
        # "mpi-complete" ： 完全認証
        # "mpi-company" ： 通常認証（カード会社リスク負担）
        # "mpi-merchant" ： 通常認証（カード会社、加盟店リスク負担）
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===元取引IDを取得する
        # @return:: 元取引ID
        #
        def original_order_id
          @original_order_id = nil unless instance_variable_defined?(:@original_order_id)
          @original_order_id
        end

        #
        # ===元取引IDを設定する
        # マーチャントで過去の取引を表す注文管理IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: original_order_id 元取引ID
        #
        def original_order_id=(original_order_id)
          @original_order_id = original_order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # 1 以上かつ 99999999 以下である必要があります。
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===カード番号を取得する
        # @return:: カード番号
        #
        def card_number
          @card_number = nil unless instance_variable_defined?(:@card_number)
          @card_number
        end

        #
        # ===カード番号を設定する
        # クレジットカード番号を指定します。
        # 記号はハイフン、ブランク、ピリオドが使用可能
        #  （ハイフンを含んでも含まなくても同様に処理が可能）
        # @param:: card_number カード番号
        #
        def card_number=(card_number)
          @card_number = card_number
        end

        #
        # ===カード有効期限を取得する
        # @return:: カード有効期限
        #
        def card_expire
          @card_expire = nil unless instance_variable_defined?(:@card_expire)
          @card_expire
        end

        #
        # ===カード有効期限を設定する
        # クレジットカードの有効期限を指定します。
        # MM/YY （月 + "/" + 年）の形式
        # @param:: card_expire カード有効期限
        #
        def card_expire=(card_expire)
          @card_expire = card_expire
        end

        #
        # ===カード接続センターを取得する
        # @return:: カード接続センター
        #
        def card_center
          @card_center = nil unless instance_variable_defined?(:@card_center)
          @card_center
        end

        #
        # ===カード接続センターを設定する
        # カード接続センターを指定します。
        # "jcn"： Jcn接続
        # "cafis"： CAFIS接続
        # ※ 未指定の場合は、デフォルトの接続センターを検証
        # @param:: card_center カード接続センター
        #
        def card_center=(card_center)
          @card_center = card_center
        end

        #
        # ===仕向け先コードを取得する
        # @return:: 仕向け先コード
        #
        def acquirer_code
          @acquirer_code = nil unless instance_variable_defined?(:@acquirer_code)
          @acquirer_code
        end

        #
        # ===仕向け先コードを設定する
        # 仕向け先カード会社コードを指定します。
        # （店舗が加盟店契約をしているカード会社）
        # ※ 最終的に決済を行うカード発行会社ではなく、決済要求電文が最初に仕向けられる加盟店管理会社となります。
        # @param:: acquirer_code 仕向け先コード
        #
        def acquirer_code=(acquirer_code)
          @acquirer_code = acquirer_code
        end

        #
        # ===支払種別を取得する
        # @return:: 支払種別
        #
        def jpo
          @jpo = nil unless instance_variable_defined?(:@jpo)
          @jpo
        end

        #
        # ===支払種別を設定する
        # JPOを指定します。
        # "10"
        # "21"+"支払詳細"
        # "22"+"支払詳細"
        # "23"+"支払詳細"
        # "24"+"支払詳細"
        # "25"+"支払詳細"
        # "31"+"支払詳細"
        # "32"+"支払詳細"
        # "33"+"支払詳細"
        # "34"+"支払詳細"
        # "61"+"支払詳細"
        # "62"+"支払詳細"
        # "63"+"支払詳細"
        # "69"+"支払詳細"
        # ※ 未指定の場合は、10（一括払い）
        # @param:: jpo 支払種別
        #
        def jpo=(jpo)
          @jpo = jpo
        end

        #
        # ===売上フラグを取得する
        # @return:: 売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===売上フラグを設定する
        # 売上フラグを指定します。（任意指定）
        # "true"： 与信・売上
        # "false"： 与信のみ
        # ※ 未指定の場合は、false:与信のみ
        # @param:: with_capture 売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===売上日を取得する
        # @return:: 売上日
        #
        def sales_day
          @sales_day = nil unless instance_variable_defined?(:@sales_day)
          @sales_day
        end

        #
        # ===売上日を設定する
        # 売上日を指定します。
        # YYYYMMDD形式
        # @param:: sales_day 売上日
        #
        def sales_day=(sales_day)
          @sales_day = sales_day
        end

        #
        # ===商品コードを取得する
        # @return:: 商品コード
        #
        def item_code
          @item_code = nil unless instance_variable_defined?(:@item_code)
          @item_code
        end

        #
        # ===商品コードを設定する
        # 商品コードを指定します。
        # @param:: item_code 商品コード
        #
        def item_code=(item_code)
          @item_code = item_code
        end

        #
        # ===セキュリティコードを取得する
        # @return:: セキュリティコード
        #
        def security_code
          @security_code = nil unless instance_variable_defined?(:@security_code)
          @security_code
        end

        #
        # ===セキュリティコードを設定する
        # セキュリティコードを指定します。
        # @param:: security_code セキュリティコード
        #
        def security_code=(security_code)
          @security_code = security_code
        end

        #
        # ===誕生日を取得する
        # @return:: 誕生日
        #
        def birthday
          @birthday = nil unless instance_variable_defined?(:@birthday)
          @birthday
        end

        #
        # ===誕生日を設定する
        # 誕生日を指定します。
        # カード接続センターがsln以外の場合は利用できません。
        # @param:: birthday 誕生日
        #
        def birthday=(birthday)
          @birthday = birthday
        end

        #
        # ===電話番号を取得する
        # @return:: 電話番号
        #
        def tel
          @tel = nil unless instance_variable_defined?(:@tel)
          @tel
        end

        #
        # ===電話番号を設定する
        # 電話番号を指定します。
        # カード接続センターがsln以外の場合は利用できません。
        # @param:: tel 電話番号
        #
        def tel=(tel)
          @tel = tel
        end

        #
        # ===名前（名）カナを取得する
        # @return:: 名前（名）カナ
        #
        def first_kana_name
          @first_kana_name = nil unless instance_variable_defined?(:@first_kana_name)
          @first_kana_name
        end

        #
        # ===名前（名）カナを設定する
        # 名前（名）カナ を指定します。
        # 半角カナ（ｱ～ﾝ）、半濁点が使用できます。
        # カード接続センターがsln以外の場合は利用できません。
        # @param:: first_kana_name 名前（名）カナ
        #
        def first_kana_name=(first_kana_name)
          @first_kana_name = first_kana_name
        end

        #
        # ===名前（姓）カナを取得する
        # @return:: 名前（姓）カナ
        #
        def last_kana_name
          @last_kana_name = nil unless instance_variable_defined?(:@last_kana_name)
          @last_kana_name
        end

        #
        # ===名前（姓）カナを設定する
        # 名前（姓）カナ を指定します。
        # 半角カナ（ｱ～ﾝ）、半濁点が使用できます。
        # カード接続センターがsln以外の場合は利用できません。
        # @param:: last_kana_name 名前（姓）カナ
        #
        def last_kana_name=(last_kana_name)
          @last_kana_name = last_kana_name
        end

        #
        # ===通貨単位を取得する
        # @return:: 通貨単位
        #
        def currency_unit
          @currency_unit = nil unless instance_variable_defined?(:@currency_unit)
          @currency_unit
        end

        #
        # ===通貨単位を設定する
        # 通貨単位を指定します。
        # @param:: currency_unit 通貨単位
        #
        def currency_unit=(currency_unit)
          @currency_unit = currency_unit
        end

        #
        # ===リダイレクションURIを取得する
        # @return:: リダイレクションURI
        #
        def redirection_uri
          @redirection_uri = nil unless instance_variable_defined?(:@redirection_uri)
          @redirection_uri
        end

        #
        # ===リダイレクションURIを設定する
        # 検証結果を返すURIを指定します。
        # 指定がない場合にはマスタに登録されたURIを用います。
        # @param:: redirection_uri リダイレクションURI
        #
        def redirection_uri=(redirection_uri)
          @redirection_uri = redirection_uri
        end

        #
        # ===HTTPアクセプトを取得する
        # @return:: HTTPアクセプト
        #
        def http_accept
          @http_accept = nil unless instance_variable_defined?(:@http_accept)
          @http_accept
        end

        #
        # ===HTTPアクセプトを設定する
        # コンシューマのブラウザ情報でアプリケーションサーバから取得して設定します。
        # @param:: http_accept HTTPアクセプト
        #
        def http_accept=(http_accept)
          @http_accept = http_accept
        end

        #
        # ===HTTPユーザエージェントを取得する
        # @return:: HTTPユーザエージェント
        #
        def http_user_agent
          @http_user_agent = nil unless instance_variable_defined?(:@http_user_agent)
          @http_user_agent
        end

        #
        # ===HTTPユーザエージェントを設定する
        # コンシューマのブラウザ情報でアプリケーションサーバから取得して設定します。
        # @param:: http_user_agent HTTPユーザエージェント
        #
        def http_user_agent=(http_user_agent)
          @http_user_agent = http_user_agent
        end

        #
        # ===初回請求年月を取得する
        # @return:: 初回請求年月
        #
        def first_payment
          @first_payment = nil unless instance_variable_defined?(:@first_payment)
          @first_payment
        end

        #
        # ===初回請求年月を設定する
        # 初回請求年月を指定します。
        # YYMM（年月）の形式
        # @param:: first_payment 初回請求年月
        #
        def first_payment=(first_payment)
          @first_payment = first_payment
        end

        #
        # ===ボーナス初回年月を取得する
        # @return:: ボーナス初回年月
        #
        def bonus_first_payment
          @bonus_first_payment = nil unless instance_variable_defined?(:@bonus_first_payment)
          @bonus_first_payment
        end

        #
        # ===ボーナス初回年月を設定する
        # ボーナス初回年月を指定します。
        # YYMM（年月）の形式
        # @param:: bonus_first_payment ボーナス初回年月
        #
        def bonus_first_payment=(bonus_first_payment)
          @bonus_first_payment = bonus_first_payment
        end

        #
        # ===決済金額（多通貨）を取得する
        # @return:: 決済金額（多通貨）
        #
        def mc_amount
          @mc_amount = nil unless instance_variable_defined?(:@mc_amount)
          @mc_amount
        end

        #
        # ===決済金額（多通貨）を設定する
        # 決済金額（多通貨）を指定します。
        # 1 以上かつ 99999999 以下である必要があります。
        # @param:: mc_amount 決済金額（多通貨）
        #
        def mc_amount=(mc_amount)
          @mc_amount = mc_amount
        end

        #
        # ===プッシュURLを取得する
        # @return:: プッシュURL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュURLを設定する
        # プッシュURLを指定します。
        # ※ 未指定の場合は、マスタに登録された値を使用します。
        # @param:: push_url プッシュURL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===端末種別を取得する
        # @return:: 端末種別
        #
        def browser_device_category
          @browser_device_category = nil unless instance_variable_defined?(:@browser_device_category)
          @browser_device_category
        end

        #
        # ===端末種別を設定する
        #  0:PC
        #  1:mobile
        # ※ 未指定の場合は、0:PC
        # @param:: browser_device_category 端末種別
        #
        def browser_device_category=(browser_device_category)
          @browser_device_category = browser_device_category
        end

        #
        # ===詳細パラメータ連携フラグを取得する
        # @return:: 詳細パラメータ連携フラグ
        #
        def verify_result_link
          @verify_result_link = nil unless instance_variable_defined?(:@verify_result_link)
          @verify_result_link
        end

        #
        # ===詳細パラメータ連携フラグを設定する
        #  0:パラメータ連携しない
        #  1:パラメータ連携する
        #  2:パラメータ連携しない(GET)
        # ※ 未指定の場合は、マスタに登録された値を使用します。
        # @param:: verify_result_link 詳細パラメータ連携フラグ
        #
        def verify_result_link=(verify_result_link)
          @verify_result_link = verify_result_link
        end

        #
        # ===不正検知評価取引情報を取得する
        # @return:: 不正検知評価取引情報
        #
        def fraud_detection_request
          @fraud_detection_request = nil unless instance_variable_defined?(:@fraud_detection_request)
          @fraud_detection_request
        end

        #
        # ===不正検知評価取引情報を設定する
        # 不正検知取引情報
        # @param:: fraud_detection_request 不正検知評価取引情報
        #
        def fraud_detection_request=(fraud_detection_request)
          @fraud_detection_request = fraud_detection_request
        end

        #
        # ===不正検知V2評価取引情報を取得する
        # @return:: 不正検知V2評価取引情報
        #
        def fraud_detection_v2_request
          @fraud_detection_v2_request = nil unless instance_variable_defined?(:@fraud_detection_v2_request)
          @fraud_detection_v2_request
        end

        #
        # ===不正検知V2評価取引情報を設定する
        # - 不正検知V2評価取引情報を指定します。
        # @param:: fraud_detection_v2_request 不正検知V2評価取引情報
        #
        def fraud_detection_v2_request=(fraud_detection_v2_request)
          @fraud_detection_v2_request = fraud_detection_v2_request
        end

        #
        # ===不正検知実施フラグを取得する
        # @return:: 不正検知実施フラグ
        #
        def with_fraud_detection
          @with_fraud_detection = nil unless instance_variable_defined?(:@with_fraud_detection)
          @with_fraud_detection
        end

        #
        # ===不正検知実施フラグを設定する
        # 不正検知実施フラグを指定します。
        # "true"： 実施する
        # "false"： 実施しない
        # @param:: with_fraud_detection 不正検知実施フラグ
        #
        def with_fraud_detection=(with_fraud_detection)
          @with_fraud_detection = with_fraud_detection
        end

        #
        # ===本人認証有効期限を取得する
        # @return:: 本人認証有効期限
        #
        def verify_timeout
          @verify_timeout = nil unless instance_variable_defined?(:@verify_timeout)
          @verify_timeout
        end

        #
        # ===本人認証有効期限を設定する
        # 消費者が本人認証処理を完了するまでの有効期限（分単位）を指定します。
        # 1 以上かつ 999 以下である必要があります。
        # ※ 未指定の場合は、有効期限のチェックを行いません。
        # @param:: verify_timeout 本人認証有効期限
        #
        def verify_timeout=(verify_timeout)
          @verify_timeout = verify_timeout
        end

        #
        # ===デバイスチャネルを取得する
        # @return:: デバイスチャネル
        #
        def device_channel
          @device_channel = nil unless instance_variable_defined?(:@device_channel)
          @device_channel
        end

        #
        # ===デバイスチャネルを設定する
        # デバイスチャネルを指定します。
        #  01:アプリベース
        #  02:ブラウザベース
        #  03:3DSリクエスター（3RI）
        # ※ 未指定の場合は、マスタに登録された値を使用します。
        #     マスタにも値が設定されていない場合は、3Dセキュア 1.0.2として扱います。
        # @param:: device_channel デバイスチャネル
        #
        def device_channel=(device_channel)
          @device_channel = device_channel
        end

        #
        # ===アカウントタイプを取得する
        # @return:: アカウントタイプ
        #
        def account_type
          @account_type = nil unless instance_variable_defined?(:@account_type)
          @account_type
        end

        #
        # ===アカウントタイプを設定する
        # アカウントの種類を指定します。
        #  01:該当なし
        #  02:クレジット
        #  03:デビット
        # @param:: account_type アカウントタイプ
        #
        def account_type=(account_type)
          @account_type = account_type
        end

        #
        # ===認証要求タイプを取得する
        # @return:: 認証要求タイプ
        #
        def authentication_indicator
          @authentication_indicator = nil unless instance_variable_defined?(:@authentication_indicator)
          @authentication_indicator
        end

        #
        # ===認証要求タイプを設定する
        # 認証要求のタイプを指定します。
        #  01:支払い
        #  02:リカーリング
        #  03:分割
        #  04:カード追加
        #  05:有効性確認
        #  06:カード保有者確認
        #  07:請求確認
        # ※ 未指定の場合は、01:支払い
        # @param:: authentication_indicator 認証要求タイプ
        #
        def authentication_indicator=(authentication_indicator)
          @authentication_indicator = authentication_indicator
        end

        #
        # ===メッセージカテゴリを取得する
        # @return:: メッセージカテゴリ
        #
        def message_category
          @message_category = nil unless instance_variable_defined?(:@message_category)
          @message_category
        end

        #
        # ===メッセージカテゴリを設定する
        # メッセージのカテゴリを指定します。
        #  01:PA（支払い認証）
        #  02:NPA（支払い無しの認証）
        # ※ サービスオプションタイプがmpi-complete、mpi-company、mpi-merchantの場合は、"01"のみ指定可能です。
        # @param:: message_category メッセージカテゴリ
        #
        def message_category=(message_category)
          @message_category = message_category
        end

        #
        # ===カード保有者名を取得する
        # @return:: カード保有者名
        #
        def cardholder_name
          @cardholder_name = nil unless instance_variable_defined?(:@cardholder_name)
          @cardholder_name
        end

        #
        # ===カード保有者名を設定する
        # カード保有者名を指定します。2桁以上。
        # ※ 3Dセキュア 2.0の場合は（カード保有者名省略フラグをtrueで設定しない限り）必須です。
        # @param:: cardholder_name カード保有者名
        #
        def cardholder_name=(cardholder_name)
          @cardholder_name = cardholder_name
        end

        #
        # ===カード保有者名省略フラグを取得する
        # @return:: カード保有者名省略フラグ
        #
        def cardholder_name_omit_flag
          @cardholder_name_omit_flag = nil unless instance_variable_defined?(:@cardholder_name_omit_flag)
          @cardholder_name_omit_flag
        end

        #
        # ===カード保有者名省略フラグを設定する
        # "true"： カード保有者名を省略可能
        # "false"： カード保有者名は必須
        # ※未指定の場合は、false： カード保有者名は必須
        # @param:: cardholder_name_omit_flag カード保有者名省略フラグ
        #
        def cardholder_name_omit_flag=(cardholder_name_omit_flag)
          @cardholder_name_omit_flag = cardholder_name_omit_flag
        end

        #
        # ===カード保有者メールアドレスを取得する
        # @return:: カード保有者メールアドレス
        #
        def cardholder_email
          @cardholder_email = nil unless instance_variable_defined?(:@cardholder_email)
          @cardholder_email
        end

        #
        # ===カード保有者メールアドレスを設定する
        # カード保有者メールアドレスを指定します。
        # @param:: cardholder_email カード保有者メールアドレス
        #
        def cardholder_email=(cardholder_email)
          @cardholder_email = cardholder_email
        end

        #
        # ===カード保有者自宅電話番号国コードを取得する
        # @return:: カード保有者自宅電話番号国コード
        #
        def cardholder_home_phone_country
          @cardholder_home_phone_country = nil unless instance_variable_defined?(:@cardholder_home_phone_country)
          @cardholder_home_phone_country
        end

        #
        # ===カード保有者自宅電話番号国コードを設定する
        # カード保有者自宅電話番号の国コードを指定します。
        # @param:: cardholder_home_phone_country カード保有者自宅電話番号国コード
        #
        def cardholder_home_phone_country=(cardholder_home_phone_country)
          @cardholder_home_phone_country = cardholder_home_phone_country
        end

        #
        # ===カード保有者自宅電話番号を取得する
        # @return:: カード保有者自宅電話番号
        #
        def cardholder_home_phone_number
          @cardholder_home_phone_number = nil unless instance_variable_defined?(:@cardholder_home_phone_number)
          @cardholder_home_phone_number
        end

        #
        # ===カード保有者自宅電話番号を設定する
        # カード保有者自宅電話番号を指定します。
        # @param:: cardholder_home_phone_number カード保有者自宅電話番号
        #
        def cardholder_home_phone_number=(cardholder_home_phone_number)
          @cardholder_home_phone_number = cardholder_home_phone_number
        end

        #
        # ===カード保有者携帯電話番号国コードを取得する
        # @return:: カード保有者携帯電話番号国コード
        #
        def cardholder_mobile_phone_country
          @cardholder_mobile_phone_country = nil unless instance_variable_defined?(:@cardholder_mobile_phone_country)
          @cardholder_mobile_phone_country
        end

        #
        # ===カード保有者携帯電話番号国コードを設定する
        # カード保有者携帯電話番号の国コードを指定します。
        # @param:: cardholder_mobile_phone_country カード保有者携帯電話番号国コード
        #
        def cardholder_mobile_phone_country=(cardholder_mobile_phone_country)
          @cardholder_mobile_phone_country = cardholder_mobile_phone_country
        end

        #
        # ===カード保有者携帯電話番号を取得する
        # @return:: カード保有者携帯電話番号
        #
        def cardholder_mobile_phone_number
          @cardholder_mobile_phone_number = nil unless instance_variable_defined?(:@cardholder_mobile_phone_number)
          @cardholder_mobile_phone_number
        end

        #
        # ===カード保有者携帯電話番号を設定する
        # カード保有者携帯電話番号を指定します。
        # @param:: cardholder_mobile_phone_number カード保有者携帯電話番号
        #
        def cardholder_mobile_phone_number=(cardholder_mobile_phone_number)
          @cardholder_mobile_phone_number = cardholder_mobile_phone_number
        end

        #
        # ===カード保有者勤務先電話番号国コードを取得する
        # @return:: カード保有者勤務先電話番号国コード
        #
        def cardholder_work_phone_country
          @cardholder_work_phone_country = nil unless instance_variable_defined?(:@cardholder_work_phone_country)
          @cardholder_work_phone_country
        end

        #
        # ===カード保有者勤務先電話番号国コードを設定する
        # カード保有者勤務先電話番号の国コードを指定します。
        # @param:: cardholder_work_phone_country カード保有者勤務先電話番号国コード
        #
        def cardholder_work_phone_country=(cardholder_work_phone_country)
          @cardholder_work_phone_country = cardholder_work_phone_country
        end

        #
        # ===カード保有者勤務先電話番号を取得する
        # @return:: カード保有者勤務先電話番号
        #
        def cardholder_work_phone_number
          @cardholder_work_phone_number = nil unless instance_variable_defined?(:@cardholder_work_phone_number)
          @cardholder_work_phone_number
        end

        #
        # ===カード保有者勤務先電話番号を設定する
        # カード保有者勤務先電話番号を指定します。
        # @param:: cardholder_work_phone_number カード保有者勤務先電話番号
        #
        def cardholder_work_phone_number=(cardholder_work_phone_number)
          @cardholder_work_phone_number = cardholder_work_phone_number
        end

        #
        # ===請求先住所_市区町村を取得する
        # @return:: 請求先住所_市区町村
        #
        def billing_address_city
          @billing_address_city = nil unless instance_variable_defined?(:@billing_address_city)
          @billing_address_city
        end

        #
        # ===請求先住所_市区町村を設定する
        # 請求先住所の市区町村を指定します。
        # @param:: billing_address_city 請求先住所_市区町村
        #
        def billing_address_city=(billing_address_city)
          @billing_address_city = billing_address_city
        end

        #
        # ===請求先住所_国を取得する
        # @return:: 請求先住所_国
        #
        def billing_address_country
          @billing_address_country = nil unless instance_variable_defined?(:@billing_address_country)
          @billing_address_country
        end

        #
        # ===請求先住所_国を設定する
        # 請求先住所の国を指定します。
        # ISO 3166-1 numericで定義されているコードを設定します。
        # @param:: billing_address_country 請求先住所_国
        #
        def billing_address_country=(billing_address_country)
          @billing_address_country = billing_address_country
        end

        #
        # ===請求先住所1を取得する
        # @return:: 請求先住所1
        #
        def billing_address_line1
          @billing_address_line1 = nil unless instance_variable_defined?(:@billing_address_line1)
          @billing_address_line1
        end

        #
        # ===請求先住所1を設定する
        # 請求先住所1を指定します。
        # @param:: billing_address_line1 請求先住所1
        #
        def billing_address_line1=(billing_address_line1)
          @billing_address_line1 = billing_address_line1
        end

        #
        # ===請求先住所2を取得する
        # @return:: 請求先住所2
        #
        def billing_address_line2
          @billing_address_line2 = nil unless instance_variable_defined?(:@billing_address_line2)
          @billing_address_line2
        end

        #
        # ===請求先住所2を設定する
        # 請求先住所2を指定します。
        # @param:: billing_address_line2 請求先住所2
        #
        def billing_address_line2=(billing_address_line2)
          @billing_address_line2 = billing_address_line2
        end

        #
        # ===請求先住所3を取得する
        # @return:: 請求先住所3
        #
        def billing_address_line3
          @billing_address_line3 = nil unless instance_variable_defined?(:@billing_address_line3)
          @billing_address_line3
        end

        #
        # ===請求先住所3を設定する
        # 請求先住所3を指定します。
        # @param:: billing_address_line3 請求先住所3
        #
        def billing_address_line3=(billing_address_line3)
          @billing_address_line3 = billing_address_line3
        end

        #
        # ===請求先郵便番号を取得する
        # @return:: 請求先郵便番号
        #
        def billing_postal_code
          @billing_postal_code = nil unless instance_variable_defined?(:@billing_postal_code)
          @billing_postal_code
        end

        #
        # ===請求先郵便番号を設定する
        # 請求先郵便番号を指定します。
        # @param:: billing_postal_code 請求先郵便番号
        #
        def billing_postal_code=(billing_postal_code)
          @billing_postal_code = billing_postal_code
        end

        #
        # ===請求先住所_都道府県を取得する
        # @return:: 請求先住所_都道府県
        #
        def billing_address_state
          @billing_address_state = nil unless instance_variable_defined?(:@billing_address_state)
          @billing_address_state
        end

        #
        # ===請求先住所_都道府県を設定する
        # 請求先住所の都道府県を指定します。
        # ISO 3166-2で定義されているコードを設定します。
        # @param:: billing_address_state 請求先住所_都道府県
        #
        def billing_address_state=(billing_address_state)
          @billing_address_state = billing_address_state
        end

        #
        # ===配送先住所_市区町村を取得する
        # @return:: 配送先住所_市区町村
        #
        def shipping_address_city
          @shipping_address_city = nil unless instance_variable_defined?(:@shipping_address_city)
          @shipping_address_city
        end

        #
        # ===配送先住所_市区町村を設定する
        # 配送先住所の市区町村を指定します。
        # @param:: shipping_address_city 配送先住所_市区町村
        #
        def shipping_address_city=(shipping_address_city)
          @shipping_address_city = shipping_address_city
        end

        #
        # ===配送先住所_国を取得する
        # @return:: 配送先住所_国
        #
        def shipping_address_country
          @shipping_address_country = nil unless instance_variable_defined?(:@shipping_address_country)
          @shipping_address_country
        end

        #
        # ===配送先住所_国を設定する
        # 配送先住所の国を指定します。
        # ISO 3166-1 numericで定義されているコードを設定します。
        # @param:: shipping_address_country 配送先住所_国
        #
        def shipping_address_country=(shipping_address_country)
          @shipping_address_country = shipping_address_country
        end

        #
        # ===配送先住所1を取得する
        # @return:: 配送先住所1
        #
        def shipping_address_line1
          @shipping_address_line1 = nil unless instance_variable_defined?(:@shipping_address_line1)
          @shipping_address_line1
        end

        #
        # ===配送先住所1を設定する
        # 配送先住所1を指定します。
        # @param:: shipping_address_line1 配送先住所1
        #
        def shipping_address_line1=(shipping_address_line1)
          @shipping_address_line1 = shipping_address_line1
        end

        #
        # ===配送先住所2を取得する
        # @return:: 配送先住所2
        #
        def shipping_address_line2
          @shipping_address_line2 = nil unless instance_variable_defined?(:@shipping_address_line2)
          @shipping_address_line2
        end

        #
        # ===配送先住所2を設定する
        # 配送先住所2を指定します。
        # @param:: shipping_address_line2 配送先住所2
        #
        def shipping_address_line2=(shipping_address_line2)
          @shipping_address_line2 = shipping_address_line2
        end

        #
        # ===配送先住所3を取得する
        # @return:: 配送先住所3
        #
        def shipping_address_line3
          @shipping_address_line3 = nil unless instance_variable_defined?(:@shipping_address_line3)
          @shipping_address_line3
        end

        #
        # ===配送先住所3を設定する
        # 配送先住所3を指定します。
        # @param:: shipping_address_line3 配送先住所3
        #
        def shipping_address_line3=(shipping_address_line3)
          @shipping_address_line3 = shipping_address_line3
        end

        #
        # ===配送先郵便番号を取得する
        # @return:: 配送先郵便番号
        #
        def shipping_postal_code
          @shipping_postal_code = nil unless instance_variable_defined?(:@shipping_postal_code)
          @shipping_postal_code
        end

        #
        # ===配送先郵便番号を設定する
        # 配送先郵便番号を指定します。
        # @param:: shipping_postal_code 配送先郵便番号
        #
        def shipping_postal_code=(shipping_postal_code)
          @shipping_postal_code = shipping_postal_code
        end

        #
        # ===配送先住所_都道府県を取得する
        # @return:: 配送先住所_都道府県
        #
        def shipping_address_state
          @shipping_address_state = nil unless instance_variable_defined?(:@shipping_address_state)
          @shipping_address_state
        end

        #
        # ===配送先住所_都道府県を設定する
        # 配送先住所の都道府県を指定します。
        # ISO 3166-2で定義されているコードを設定します。
        # @param:: shipping_address_state 配送先住所_都道府県
        #
        def shipping_address_state=(shipping_address_state)
          @shipping_address_state = shipping_address_state
        end

        #
        # ===消費者IPアドレスを取得する
        # @return:: 消費者IPアドレス
        #
        def customer_ip
          @customer_ip = nil unless instance_variable_defined?(:@customer_ip)
          @customer_ip
        end

        #
        # ===消費者IPアドレスを設定する
        # コンシューマのブラウザ情報でアプリケーションサーバから取得して設定します。
        # 半角英数字以外に、".(ドット)"が使用可能です。
        # @param:: customer_ip 消費者IPアドレス
        #
        def customer_ip=(customer_ip)
          @customer_ip = customer_ip
        end

        #
        # ===チャレンジ認証フラグを取得する
        # @return:: チャレンジ認証フラグ
        #
        def with_challenge
          @with_challenge = nil unless instance_variable_defined?(:@with_challenge)
          @with_challenge
        end

        #
        # ===チャレンジ認証フラグを設定する
        # チャレンジ認証を行うかどうかを指定します。（任意指定）
        # "true"： チャレンジ認証を行う
        # "false"： チャレンジ認証を行わない
        # ※ 未指定の場合は、true： チャレンジ認証を行う
        # @param:: with_challenge チャレンジ認証フラグ
        #
        def with_challenge=(with_challenge)
          @with_challenge = with_challenge
        end

        #
        # ===認証データを取得する
        # @return:: 認証データ
        #
        def auth_data
          @auth_data = nil unless instance_variable_defined?(:@auth_data)
          @auth_data
        end

        #
        # ===認証データを設定する
        # プロトコルバージョン2.2.0時点では予約項目のため、設定不要です。
        # @param:: auth_data 認証データ
        #
        def auth_data=(auth_data)
          @auth_data = auth_data
        end

        #
        # ===認証メソッドを取得する
        # @return:: 認証メソッド
        #
        def auth_method
          @auth_method = nil unless instance_variable_defined?(:@auth_method)
          @auth_method
        end

        #
        # ===認証メソッドを設定する
        # カード保有者の加盟店サイトへの認証方式に応じた値を指定します。
        # 下記はプロトコルバージョン2.2.0時点の内容となります。
        #  01：No 3DS Requestor authentication occurred (i.e. cardholder “logged in” as guest)
        #  02：Login to the cardholder account at the 3DS Requestor system using 3DS Requestor’s own credentials
        #  03：Login to the cardholder account at the 3DS Requestor system using federated ID
        #  04：Login to the cardholder account at the 3DS Requestor system using issuer credentials
        #  05：Login to the cardholder account at the 3DS Requestor system using third-party authentication
        #  06：Login to the cardholder account at the 3DS Requestor system using FIDO Authenticator
        #  07：Login to the cardholder account at the 3DS Requestor system using FIDO Authenticator (FIDO assurance data signed) 
        #  08：SRC Assurance Data
        #  09–79：Reserved for EMVCo future use (values invalid until defined by EMVCo)
        #  80–99：Reserved for DS use
        # 
        # @param:: auth_method 認証メソッド
        #
        def auth_method=(auth_method)
          @auth_method = auth_method
        end

        #
        # ===認証タイムスタンプを取得する
        # @return:: 認証タイムスタンプ
        #
        def auth_timestamp
          @auth_timestamp = nil unless instance_variable_defined?(:@auth_timestamp)
          @auth_timestamp
        end

        #
        # ===認証タイムスタンプを設定する
        # カード保有者の加盟店サイトへの認証実施日時を指定します。（JST）
        # YYYYMMDDhhmm形式
        # @param:: auth_timestamp 認証タイムスタンプ
        #
        def auth_timestamp=(auth_timestamp)
          @auth_timestamp = auth_timestamp
        end

        #
        # ===アカウント所持期間インジケーターを取得する
        # @return:: アカウント所持期間インジケーター
        #
        def account_age_indicator
          @account_age_indicator = nil unless instance_variable_defined?(:@account_age_indicator)
          @account_age_indicator
        end

        #
        # ===アカウント所持期間インジケーターを設定する
        # カード所有者が加盟店サイトにアカウントを持っている期間。
        #  01：アカウントなし（ゲストチェックアウト）
        #  02：このトランザクション中に作成された
        #  03：30日未満
        #  04：30〜60日
        #  05：61日以上
        # @param:: account_age_indicator アカウント所持期間インジケーター
        #
        def account_age_indicator=(account_age_indicator)
          @account_age_indicator = account_age_indicator
        end

        #
        # ===アカウント最終変更日を取得する
        # @return:: アカウント最終変更日
        #
        def account_change_date
          @account_change_date = nil unless instance_variable_defined?(:@account_change_date)
          @account_change_date
        end

        #
        # ===アカウント最終変更日を設定する
        # 加盟店サイトのカード保有者のアカウントが最後に変更された日付。
        # YYYYMMDD形式
        # @param:: account_change_date アカウント最終変更日
        #
        def account_change_date=(account_change_date)
          @account_change_date = account_change_date
        end

        #
        # ===アカウント変更インジケーターを取得する
        # @return:: アカウント変更インジケーター
        #
        def account_change_indicator
          @account_change_indicator = nil unless instance_variable_defined?(:@account_change_indicator)
          @account_change_indicator
        end

        #
        # ===アカウント変更インジケーターを設定する
        # 加盟店サイトのカード保有者のアカウント情報が最後に変更されてからの期間。
        #  01：このトランザクション中に変更された
        #  02：30日未満
        #  03：30〜60日
        #  04：61日以上
        # @param:: account_change_indicator アカウント変更インジケーター
        #
        def account_change_indicator=(account_change_indicator)
          @account_change_indicator = account_change_indicator
        end

        #
        # ===アカウント開設日を取得する
        # @return:: アカウント開設日
        #
        def account_date
          @account_date = nil unless instance_variable_defined?(:@account_date)
          @account_date
        end

        #
        # ===アカウント開設日を設定する
        # カード保有者が加盟店サイトにアカウントを開設した日付。
        # YYYYMMDD形式
        # @param:: account_date アカウント開設日
        #
        def account_date=(account_date)
          @account_date = account_date
        end

        #
        # ===アカウントパスワード最終変更日を取得する
        # @return:: アカウントパスワード最終変更日
        #
        def account_password_change_date
          @account_password_change_date = nil unless instance_variable_defined?(:@account_password_change_date)
          @account_password_change_date
        end

        #
        # ===アカウントパスワード最終変更日を設定する
        # カード保有者の加盟店サイトのアカウントがパスワード変更、またはアカウントがリセットされた日付。
        # YYYYMMDD形式
        # @param:: account_password_change_date アカウントパスワード最終変更日
        #
        def account_password_change_date=(account_password_change_date)
          @account_password_change_date = account_password_change_date
        end

        #
        # ===アカウントパスワード変更インジケーターを取得する
        # @return:: アカウントパスワード変更インジケーター
        #
        def account_password_change_indicator
          @account_password_change_indicator = nil unless instance_variable_defined?(:@account_password_change_indicator)
          @account_password_change_indicator
        end

        #
        # ===アカウントパスワード変更インジケーターを設定する
        # カード保有者の加盟店サイトのアカウントで、パスワード変更やアカウントリセットが行われてからの期間。
        #  01：変化なし
        #  02：このトランザクション中に変更された
        #  03：30日未満
        #  04：30〜60日
        #  05：61日以上
        # @param:: account_password_change_indicator アカウントパスワード変更インジケーター
        #
        def account_password_change_indicator=(account_password_change_indicator)
          @account_password_change_indicator = account_password_change_indicator
        end

        #
        # ===アカウント購入数を取得する
        # @return:: アカウント購入数
        #
        def account_purchase_count
          @account_purchase_count = nil unless instance_variable_defined?(:@account_purchase_count)
          @account_purchase_count
        end

        #
        # ===アカウント購入数を設定する
        # 過去6ヶ月間にこのカード保有者アカウントで購入した商品の数。
        # @param:: account_purchase_count アカウント購入数
        #
        def account_purchase_count=(account_purchase_count)
          @account_purchase_count = account_purchase_count
        end

        #
        # ===カード追加試行回数を取得する
        # @return:: カード追加試行回数
        #
        def account_provisioning_attempts
          @account_provisioning_attempts = nil unless instance_variable_defined?(:@account_provisioning_attempts)
          @account_provisioning_attempts
        end

        #
        # ===カード追加試行回数を設定する
        # 過去24時間のこのカード保有者アカウントに対するカード追加の試行回数。
        # @param:: account_provisioning_attempts カード追加試行回数
        #
        def account_provisioning_attempts=(account_provisioning_attempts)
          @account_provisioning_attempts = account_provisioning_attempts
        end

        #
        # ===前日アカウント購入数を取得する
        # @return:: 前日アカウント購入数
        #
        def account_day_transactions
          @account_day_transactions = nil unless instance_variable_defined?(:@account_day_transactions)
          @account_day_transactions
        end

        #
        # ===前日アカウント購入数を設定する
        # 過去24時間に行われた、このカード保有者アカウントとその支払いアカウントすべての、加盟店サイト上の取引数（成功および放棄）。
        # @param:: account_day_transactions 前日アカウント購入数
        #
        def account_day_transactions=(account_day_transactions)
          @account_day_transactions = account_day_transactions
        end

        #
        # ===前年アカウント購入数を取得する
        # @return:: 前年アカウント購入数
        #
        def account_year_transactions
          @account_year_transactions = nil unless instance_variable_defined?(:@account_year_transactions)
          @account_year_transactions
        end

        #
        # ===前年アカウント購入数を設定する
        # 過去1年間に行われた、このカード保有者アカウントとその支払いアカウントすべての、加盟店サイト上の取引数（成功および放棄）。
        # @param:: account_year_transactions 前年アカウント購入数
        #
        def account_year_transactions=(account_year_transactions)
          @account_year_transactions = account_year_transactions
        end

        #
        # ===支払いアカウント登録日を取得する
        # @return:: 支払いアカウント登録日
        #
        def payment_account_age
          @payment_account_age = nil unless instance_variable_defined?(:@payment_account_age)
          @payment_account_age
        end

        #
        # ===支払いアカウント登録日を設定する
        # 支払アカウントが加盟店サイトのカード保有者のアカウントに登録された日付。
        # YYYYMMDD形式
        # @param:: payment_account_age 支払いアカウント登録日
        #
        def payment_account_age=(payment_account_age)
          @payment_account_age = payment_account_age
        end

        #
        # ===支払いアカウント所持期間インジケーターを取得する
        # @return:: 支払いアカウント所持期間インジケーター
        #
        def payment_account_age_indicator
          @payment_account_age_indicator = nil unless instance_variable_defined?(:@payment_account_age_indicator)
          @payment_account_age_indicator
        end

        #
        # ===支払いアカウント所持期間インジケーターを設定する
        # 支払アカウントが加盟店サイトのカード保有者アカウントに登録されていた期間。
        #  01：アカウントなし（ゲストチェックアウト）
        #  02：このトランザクション中に作成された
        #  03：30日未満
        #  04：30〜60日
        #  05：61日以上
        # @param:: payment_account_age_indicator 支払いアカウント所持期間インジケーター
        #
        def payment_account_age_indicator=(payment_account_age_indicator)
          @payment_account_age_indicator = payment_account_age_indicator
        end

        #
        # ===配送先住所初回使用日を取得する
        # @return:: 配送先住所初回使用日
        #
        def ship_address_usage_date
          @ship_address_usage_date = nil unless instance_variable_defined?(:@ship_address_usage_date)
          @ship_address_usage_date
        end

        #
        # ===配送先住所初回使用日を設定する
        # このトランザクションに使用された配送先住所が、加盟店サイトで初めて使用された日付。
        # YYYYMMDD形式
        # @param:: ship_address_usage_date 配送先住所初回使用日
        #
        def ship_address_usage_date=(ship_address_usage_date)
          @ship_address_usage_date = ship_address_usage_date
        end

        #
        # ===配送先住所利用状況インジケーターを取得する
        # @return:: 配送先住所利用状況インジケーター
        #
        def ship_address_usage_indicator
          @ship_address_usage_indicator = nil unless instance_variable_defined?(:@ship_address_usage_indicator)
          @ship_address_usage_indicator
        end

        #
        # ===配送先住所利用状況インジケーターを設定する
        # この取引に使用された配送先住所が、加盟店サイトで初めて使用されてからの期間。
        #  01：このトランザクションが初めて
        #  02：30日未満
        #  03：30〜60日
        #  04：61日以上
        # @param:: ship_address_usage_indicator 配送先住所利用状況インジケーター
        #
        def ship_address_usage_indicator=(ship_address_usage_indicator)
          @ship_address_usage_indicator = ship_address_usage_indicator
        end

        #
        # ===配送先名インジケーターを取得する
        # @return:: 配送先名インジケーター
        #
        def ship_name_indicator
          @ship_name_indicator = nil unless instance_variable_defined?(:@ship_name_indicator)
          @ship_name_indicator
        end

        #
        # ===配送先名インジケーターを設定する
        # アカウントに登録されているカード保有者名が、この取引で使用された配送名と同一であるかどうか。
        #  01：配送名と同じアカウント名
        #  02：配送名とは異なるアカウント名
        # @param:: ship_name_indicator 配送先名インジケーター
        #
        def ship_name_indicator=(ship_name_indicator)
          @ship_name_indicator = ship_name_indicator
        end

        #
        # ===不審アカウントアクティビティを取得する
        # @return:: 不審アカウントアクティビティ
        #
        def suspicious_account_activity
          @suspicious_account_activity = nil unless instance_variable_defined?(:@suspicious_account_activity)
          @suspicious_account_activity
        end

        #
        # ===不審アカウントアクティビティを設定する
        # 加盟店サイトがカード保有者アカウントで疑わしい行為（過去の不正行為を含む）を経験したことがあるかどうか。
        #  01：疑わしい活動は観察されていない
        #  02：不審な活動が観察された
        # @param:: suspicious_account_activity 不審アカウントアクティビティ
        #
        def suspicious_account_activity=(suspicious_account_activity)
          @suspicious_account_activity = suspicious_account_activity
        end

        #
        # ===リクエスターチャレンジインジケーターを取得する
        # @return:: リクエスターチャレンジインジケーター
        #
        def requestor_challenge_indicator
          @requestor_challenge_indicator = nil unless instance_variable_defined?(:@requestor_challenge_indicator)
          @requestor_challenge_indicator
        end

        #
        # ===リクエスターチャレンジインジケーターを設定する
        # リクエスターチャレンジインジケーターを指定します。
        # @param:: requestor_challenge_indicator リクエスターチャレンジインジケーター
        #
        def requestor_challenge_indicator=(requestor_challenge_indicator)
          @requestor_challenge_indicator = requestor_challenge_indicator
        end

        #
        # ===商品お届け先メールアドレスを取得する
        # @return:: 商品お届け先メールアドレス
        #
        def delivery_email_address
          @delivery_email_address = nil unless instance_variable_defined?(:@delivery_email_address)
          @delivery_email_address
        end

        #
        # ===商品お届け先メールアドレスを設定する
        # 商品お届け先メールアドレスを指定します。
        # @param:: delivery_email_address 商品お届け先メールアドレス
        #
        def delivery_email_address=(delivery_email_address)
          @delivery_email_address = delivery_email_address
        end

        #
        # ===プレオーダー購入インジケーターを取得する
        # @return:: プレオーダー購入インジケーター
        #
        def pre_order_purchase_indicator
          @pre_order_purchase_indicator = nil unless instance_variable_defined?(:@pre_order_purchase_indicator)
          @pre_order_purchase_indicator
        end

        #
        # ===プレオーダー購入インジケーターを設定する
        # プレオーダー購入インジケーターを指定します。
        # @param:: pre_order_purchase_indicator プレオーダー購入インジケーター
        #
        def pre_order_purchase_indicator=(pre_order_purchase_indicator)
          @pre_order_purchase_indicator = pre_order_purchase_indicator
        end

        #
        # ===再注文商品インジケーターを取得する
        # @return:: 再注文商品インジケーター
        #
        def reorder_items_indicator
          @reorder_items_indicator = nil unless instance_variable_defined?(:@reorder_items_indicator)
          @reorder_items_indicator
        end

        #
        # ===再注文商品インジケーターを設定する
        # 再注文商品インジケーターを指定します。
        # @param:: reorder_items_indicator 再注文商品インジケーター
        #
        def reorder_items_indicator=(reorder_items_indicator)
          @reorder_items_indicator = reorder_items_indicator
        end

        #
        # ===配送方法インジケーターを取得する
        # @return:: 配送方法インジケーター
        #
        def ship_indicator
          @ship_indicator = nil unless instance_variable_defined?(:@ship_indicator)
          @ship_indicator
        end

        #
        # ===配送方法インジケーターを設定する
        # 配送方法インジケーターを指定します。
        # @param:: ship_indicator 配送方法インジケーター
        #
        def ship_indicator=(ship_indicator)
          @ship_indicator = ship_indicator
        end

        #
        # ===本人認証用仕向け先コードを取得する
        # @return:: 本人認証用仕向け先コード
        #
        def mpi_acquirer_code
          @mpi_acquirer_code = nil unless instance_variable_defined?(:@mpi_acquirer_code)
          @mpi_acquirer_code
        end

        #
        # ===本人認証用仕向け先コードを設定する
        # 本人認証処理のみ仕向け先カード会社を変更したい場合に、仕向け先カード会社コードを指定します。
        # ※mpi-none以外の場合の、クレジットカード決済の仕向け先カード会社には影響しません。
        # @param:: mpi_acquirer_code 本人認証用仕向け先コード
        #
        def mpi_acquirer_code=(mpi_acquirer_code)
          @mpi_acquirer_code = mpi_acquirer_code
        end

        #
        # ===拡張伝票情報を取得する
        # @return:: 拡張伝票情報
        #
        def ex_slip_info
          @ex_slip_info = nil unless instance_variable_defined?(:@ex_slip_info)
          @ex_slip_info
        end

        #
        # ===拡張伝票情報を設定する
        # カード会社に伝送する売上伝送ファイルに設定する拡張伝票情報を指定します。
        # @param:: ex_slip_info 拡張伝票情報
        #
        def ex_slip_info=(ex_slip_info)
          @ex_slip_info = ex_slip_info
        end

        #
        # ===住所一致インジケーターを取得する
        # @return:: 住所一致インジケーター
        #
        def address_match_indicator
          @address_match_indicator = nil unless instance_variable_defined?(:@address_match_indicator)
          @address_match_indicator
        end

        #
        # ===住所一致インジケーターを設定する
        # カード保有者の配送先住所と請求先住所が同じかどうかを指定します。
        #  Y：配送先住所が請求先住所と一致する
        #  N：配送先住所が請求先住所と一致しない
        # 
        # 
        # @param:: address_match_indicator 住所一致インジケーター
        #
        def address_match_indicator=(address_match_indicator)
          @address_match_indicator = address_match_indicator
        end

        #
        # ===拡張パラメータリストを取得する
        # @return:: 拡張パラメータリスト
        #
        def option_params
          @option_params = nil unless instance_variable_defined?(:@option_params)
          @option_params
        end

        #
        # ===拡張パラメータリストを設定する
        # @param:: option_params 拡張パラメータリスト
        #
        def option_params=(option_params)
          @option_params = option_params
        end

      end
    end
  end
end
