# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：paypay、コマンド名：再与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class PaypayReAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "paypay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "ReAuthorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "online":オンライン決済
        # ※オンライン決済のみ指定可
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===元取引IDを取得する
        # @return:: 元取引ID
        #
        def original_order_id
          @original_order_id = nil unless instance_variable_defined?(:@original_order_id)
          @original_order_id
        end

        #
        # ===元取引IDを設定する
        # 随時決済の決済申込で指定した取引IDを指定します。
        # @param:: original_order_id 元取引ID
        #
        def original_order_id=(original_order_id)
          @original_order_id = original_order_id
        end

        #
        # ===金額を取得する
        # @return:: 金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 9999999(7桁) 以下
        # @param:: amount 金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===商品IDを取得する
        # @return:: 商品ID
        #
        def item_id
          @item_id = nil unless instance_variable_defined?(:@item_id)
          @item_id
        end

        #
        # ===商品IDを設定する
        # マーチャントシステム内で商品やサービスを特定するID
        # 
        # serviceOptionType="online"（オンライン決済）    ： 指定任意
        # ※未指定の場合は、決済申込時に入力したitemIdを設定します。
        # @param:: item_id 商品ID
        #
        def item_id=(item_id)
          @item_id = item_id
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def item_name
          @item_name = nil unless instance_variable_defined?(:@item_name)
          @item_name
        end

        #
        # ===商品名を設定する
        # 商品名を指定します。
        # - 最大文字数 40byte
        # serviceOptionType="online"（オンライン決済）    ： 指定任意
        # ※未指定の場合は、決済申込時に入力したitemNameを設定します。決済申込時に未指定の場合は、設定しません。
        # @param:: item_name 商品名
        #
        def item_name=(item_name)
          @item_name = item_name
        end

        #
        # ===支払い要求実行フラグを取得する
        # @return:: 支払い要求実行フラグ
        #
        def nsf_recovery_flag
          @nsf_recovery_flag = nil unless instance_variable_defined?(:@nsf_recovery_flag)
          @nsf_recovery_flag
        end

        #
        # ===支払い要求実行フラグを設定する
        # コマンド処理が消費者の残高不足が原因で失敗した場合に、消費者アプリに支払い要求を送信するかどうかを指定します。
        # - true : 支払い要求を送信する
        # - false : 支払い要求を送信せず、売上処理失敗とする
        # 
        # ※未指定の場合は、"false"を設定します。
        # @param:: nsf_recovery_flag 支払い要求実行フラグ
        #
        def nsf_recovery_flag=(nsf_recovery_flag)
          @nsf_recovery_flag = nsf_recovery_flag
        end

        #
        # ===支払い有効期限を取得する
        # @return:: 支払い有効期限
        #
        def nsf_recovery_expired_datetime
          @nsf_recovery_expired_datetime = nil unless instance_variable_defined?(:@nsf_recovery_expired_datetime)
          @nsf_recovery_expired_datetime
        end

        #
        # ===支払い有効期限を設定する
        # コマンド処理が消費者の残高不足が原因で失敗し消費者アプリに支払い要求を送信した場合の支払い有効期限を指定します。（YYYYMMDDhhmmss形式）
        # リクエスト日時の10分後～48時間後の範囲で指定可能です。
        # 
        # ※nsfRecoveryFlag="true"の場合に指定可能なパラメータです。
        # ※nsfRecoveryFlag="true"で未指定の場合は、リクエスト日時の6時間後を設定します。
        # @param:: nsf_recovery_expired_datetime 支払い有効期限
        #
        def nsf_recovery_expired_datetime=(nsf_recovery_expired_datetime)
          @nsf_recovery_expired_datetime = nsf_recovery_expired_datetime
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # プッシュURLを指定します。
        # 
        # ※nsfRecoveryFlag="true"の場合に指定可能なパラメータです。
        # ※未指定の場合は、Authorize時に指定された値、またはMAP（Merchant Administrator Portal）から登録申請した値を使用。
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end


      end
    end
  end
end
