# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：楽天、コマンド名：与信の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class RakutenAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "rakuten"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 99999999 以下
        # 
        # payType=0（オンライン決済） ： 100 以上かつ 99999999 以下
        # payType=1（バーコード決済（店舗スキャン型）） ： 1 以上かつ 9999999 以下
        # payType=2（オンライン決済（V2））： 2 以上かつ 9999999 以下
        # ※accountingType=1(随時)の場合、指定できません。
        # payType=3（バーコード決済（消費者スキャン型））： 1 以上かつ 9999999 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上
        # - false: 与信のみ
        # 
        # payType=0（オンライン決済）： 未指定の場合は、false:与信のみ。
        # ※マーチャント登録時に商品タイプを「物販」で登録している場合、与信同時売上は使用できません。
        # 
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型）） ：未指定の場合は、true:与信同時売上。
        # ※設定可能な値は"true"のみです。
        # 
        # payType=2（オンライン決済（V2））：未指定の場合は、false:与信のみ。
        # ※accountingType=1(随時)の場合、指定できません。
        # 
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===商品番号を取得する
        # @return:: 商品番号
        #
        def item_id
          @item_id = nil unless instance_variable_defined?(:@item_id)
          @item_id
        end

        #
        # ===商品番号を設定する
        # マーチャントシステム内で商品やサービスを特定するID
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））：指定任意
        # ※accountingType=1(随時)の場合、指定できません。
        # 
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定できません
        # @param:: item_id 商品番号
        #
        def item_id=(item_id)
          @item_id = item_id
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def item_name
          @item_name = nil unless instance_variable_defined?(:@item_name)
          @item_name
        end

        #
        # ===商品名を設定する
        # 商品名
        # 
        # payType=0（オンライン決済）：指定必須（最大文字数：255文字）
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定できません
        # payType=2（オンライン決済（V2)）：accountingType=0(都度)の場合、指定任意(最大文字数：300文字)。1(随時)の場合、指定必須(最大文字数：200文字)。
        # @param:: item_name 商品名
        #
        def item_name=(item_name)
          @item_name = item_name
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 決済完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角1024文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））：指定任意
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定できません
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 決済キャンセルエラー時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # - 半角1024文字以内
        # 
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # 
        # payType=0（オンライン決済）、payType=2（オンライン決済（V2））：指定任意
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定できません
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end

        #
        # ===プッシュ先URLを取得する
        # @return:: プッシュ先URL
        #
        def push_url
          @push_url = nil unless instance_variable_defined?(:@push_url)
          @push_url
        end

        #
        # ===プッシュ先URLを設定する
        # プッシュURLを指定します。
        # - 半角1024文字以内
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））、3（バーコード決済（消費者スキャン型））：指定任意
        # payType=1（バーコード決済（店舗スキャン型））：指定できません
        # @param:: push_url プッシュ先URL
        #
        def push_url=(push_url)
          @push_url = push_url
        end

        #
        # ===決済種別を取得する
        # @return:: 決済種別
        #
        def pay_type
          @pay_type = nil unless instance_variable_defined?(:@pay_type)
          @pay_type
        end

        #
        # ===決済種別を設定する
        # 決済種別を指定します。
        # "0"：オンライン決済（デフォルト値）
        # "1"：バーコード決済（店舗スキャン型）
        # "2"：オンライン決済（V2）
        # "3"：バーコード決済（消費者スキャン型）
        # ※未指定の場合は、0：オンライン決済。
        # @param:: pay_type 決済種別
        #
        def pay_type=(pay_type)
          @pay_type = pay_type
        end

        #
        # ===課金種別を取得する
        # @return:: 課金種別
        #
        def accounting_type
          @accounting_type = nil unless instance_variable_defined?(:@accounting_type)
          @accounting_type
        end

        #
        # ===課金種別を設定する
        # 利用する決済方法の課金種別を指定します。
        # "0"：都度（デフォルト値）
        # "1"：随時
        # ※未指定の場合、0：都度。
        # 
        # payType=2（オンライン決済（V2））：指定任意
        # 上記以外：指定できません
        # @param:: accounting_type 課金種別
        #
        def accounting_type=(accounting_type)
          @accounting_type = accounting_type
        end

        #
        # ===レスポンスタイプを取得する
        # @return:: レスポンスタイプ
        #
        def response_type
          @response_type = nil unless instance_variable_defined?(:@response_type)
          @response_type
        end

        #
        # ===レスポンスタイプを設定する
        # レスポンスのタイプを指定します。
        # "0"：取引確定時にレスポンスを返却する。（デフォルト値）
        # "1"：即時にレスポンスを返却する。（取引確定については、Confirmコマンドを利用する）
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））、3（バーコード決済（消費者スキャン型））：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定任意
        # 
        # ※未指定の場合は、0：取引確定時にレスポンスを返却する。
        # @param:: response_type レスポンスタイプ
        #
        def response_type=(response_type)
          @response_type = response_type
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗番号を指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））：指定できません
        # payType=1（バーコード決済（店舗スキャン型））、3（バーコード決済（消費者スキャン型））：指定任意
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗端末IDを取得する
        # @return:: 店舗端末ID
        #
        def terminal_id
          @terminal_id = nil unless instance_variable_defined?(:@terminal_id)
          @terminal_id
        end

        #
        # ===店舗端末IDを設定する
        # 端末を識別するIDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定必須
        # payType=3（バーコード決済（消費者スキャン型））：指定任意(※指定がない場合は決済センター側で適当な値が設定されます)
        # @param:: terminal_id 店舗端末ID
        #
        def terminal_id=(terminal_id)
          @terminal_id = terminal_id
        end

        #
        # ===レシート番号を取得する
        # @return:: レシート番号
        #
        def receipt_number
          @receipt_number = nil unless instance_variable_defined?(:@receipt_number)
          @receipt_number
        end

        #
        # ===レシート番号を設定する
        # POSのレシート番号（処理番号）を指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））、3（バーコード決済（消費者スキャン型））：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定必須
        # @param:: receipt_number レシート番号
        #
        def receipt_number=(receipt_number)
          @receipt_number = receipt_number
        end

        #
        # ===ワンタイムコードを取得する
        # @return:: ワンタイムコード
        #
        def one_time_code
          @one_time_code = nil unless instance_variable_defined?(:@one_time_code)
          @one_time_code
        end

        #
        # ===ワンタイムコードを設定する
        # バーコード/QRコードの情報を指定します。
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））、3（バーコード決済（消費者スキャン型））：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定必須
        # @param:: one_time_code ワンタイムコード
        #
        def one_time_code=(one_time_code)
          @one_time_code = one_time_code
        end

        #
        # ===商品情報を取得する
        # @return:: 商品情報
        #
        def items
          @items = nil unless instance_variable_defined?(:@items)
          @items
        end

        #
        # ===商品情報を設定する
        # 商品情報を指定します。
        # - 最大文字数：255文字
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））、3（バーコード決済（消費者スキャン型））：指定できません
        # payType=1（バーコード決済（店舗スキャン型））：指定任意
        # @param:: items 商品情報
        #
        def items=(items)
          @items = items
        end

        #
        # ===有効期限を取得する
        # @return:: 有効期限
        #
        def expire_minutes
          @expire_minutes = nil unless instance_variable_defined?(:@expire_minutes)
          @expire_minutes
        end

        #
        # ===有効期限を設定する
        # アプリ起動URL(deeplink)での決済の有効期限(分)を指定します。
        #  - 1 以上かつ 1440 以下
        # 
        # ※未指定の場合は、GW側で「10」を設定します。
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））、1（バーコード決済（店舗スキャン型））：指定できません
        # payType=3（バーコード決済（消費者スキャン型））：指定任意
        # @param:: expire_minutes 有効期限
        #
        def expire_minutes=(expire_minutes)
          @expire_minutes = expire_minutes
        end

        #
        # ===ブラウザ種別を取得する
        # @return:: ブラウザ種別
        #
        def terminal_type
          @terminal_type = nil unless instance_variable_defined?(:@terminal_type)
          @terminal_type
        end

        #
        # ===ブラウザ種別を設定する
        # アプリ起動URL(deeplink)を表示させるブラウザの種別を指定します。
        # "10"：楽天ペイのWebView
        # "20"：端末搭載のブラウザ
        # 
        # payType=0（オンライン決済）、2（オンライン決済（V2））、1（バーコード決済（店舗スキャン型））：指定できません
        # payType=3（バーコード決済（消費者スキャン型））：指定必須
        # @param:: terminal_type ブラウザ種別
        #
        def terminal_type=(terminal_type)
          @terminal_type = terminal_type
        end


      end
    end
  end
end
