# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/response_base_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：楽天、コマンド名：与信の応答Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class RakutenAuthorizeResponseDto < Veritrans::Tercerog::Mdk::ResponseBaseDto

        #
        # ===決済サービスタイプを取得する
        # 決済サービスの区分を返却します。
        # - "rakuten"： 楽天決済
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスタイプを設定する
        # @param:: service_type 決済サービスタイプ
        #
        def service_type=(service_type)
          @service_type = service_type
        end

        #
        # ===処理結果コードを取得する
        # 決済請求処理後、応答電文に含まれる値。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # - pending：保留状態
        # 
        # ※バーコード決済（店舗スキャン型）、オンライン決済（V2）、バーコード決済（消費者スキャン型）の場合、pending（保留状態）は返却しません。
        # @return:: 処理結果コード
        #
        def mstatus
          @mstatus = nil unless instance_variable_defined?(:@mstatus)
          @mstatus
        end

        #
        # ===処理結果コードを設定する
        # @param:: mstatus 処理結果コード
        #
        def mstatus=(mstatus)
          @mstatus = mstatus
        end

        #
        # ===詳細結果コードを取得する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @return:: 詳細結果コード
        #
        def v_result_code
          @v_result_code = nil unless instance_variable_defined?(:@v_result_code)
          @v_result_code
        end

        #
        # ===詳細結果コードを設定する
        # @param:: v_result_code 詳細結果コード
        #
        def v_result_code=(v_result_code)
          @v_result_code = v_result_code
        end

        #
        # ===エラーメッセージを取得する
        # 処理結果に対するメッセージを返却します。
        # @return:: エラーメッセージ
        #
        def merr_msg
          @merr_msg = nil unless instance_variable_defined?(:@merr_msg)
          @merr_msg
        end

        #
        # ===エラーメッセージを設定する
        # @param:: merr_msg エラーメッセージ
        #
        def merr_msg=(merr_msg)
          @merr_msg = merr_msg
        end

        #
        # ===電文IDを取得する
        # @return:: 電文ID
        #
        def march_txn
          @march_txn = nil unless instance_variable_defined?(:@march_txn)
          @march_txn
        end

        #
        # ===電文IDを設定する
        # @param:: march_txn 電文ID
        #
        def march_txn=(march_txn)
          @march_txn = march_txn
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===取引毎に付くIDを取得する
        # @return:: 取引毎に付くID
        #
        def cust_txn
          @cust_txn = nil unless instance_variable_defined?(:@cust_txn)
          @cust_txn
        end

        #
        # ===取引毎に付くIDを設定する
        # @param:: cust_txn 取引毎に付くID
        #
        def cust_txn=(cust_txn)
          @cust_txn = cust_txn
        end

        #
        # ===MDKバージョンを取得する
        # 電文のバージョン番号を返却します。
        # @return:: MDKバージョン
        #
        def txn_version
          @txn_version = nil unless instance_variable_defined?(:@txn_version)
          @txn_version
        end

        #
        # ===MDKバージョンを設定する
        # @param:: txn_version MDKバージョン
        #
        def txn_version=(txn_version)
          @txn_version = txn_version
        end

        #
        # ===レスポンスコンテンツを取得する
        # マーチャント側でコンシューマに対して応答するHTMLコンテンツです。自動でキャリアの画面に遷移するためのJavaScriptを含みます。
        # 
        # ※オンライン決済、オンライン決済（V2）で返却します。
        # @return:: レスポンスコンテンツ
        #
        def response_contents
          @response_contents = nil unless instance_variable_defined?(:@response_contents)
          @response_contents
        end

        #
        # ===レスポンスコンテンツを設定する
        # @param:: response_contents レスポンスコンテンツ
        #
        def response_contents=(response_contents)
          @response_contents = response_contents
        end

        #
        # ===バーコード決済日時（YYYYMMDDhhmmss）を取得する
        # 楽天で決済が確定した日時を返却します。
        # ※バーコード決済（店舗スキャン型）で返却します。
        # @return:: バーコード決済日時（YYYYMMDDhhmmss）
        #
        def rakuten_barcode_paid_datetime
          @rakuten_barcode_paid_datetime = nil unless instance_variable_defined?(:@rakuten_barcode_paid_datetime)
          @rakuten_barcode_paid_datetime
        end

        #
        # ===バーコード決済日時（YYYYMMDDhhmmss）を設定する
        # @param:: rakuten_barcode_paid_datetime バーコード決済日時（YYYYMMDDhhmmss）
        #
        def rakuten_barcode_paid_datetime=(rakuten_barcode_paid_datetime)
          @rakuten_barcode_paid_datetime = rakuten_barcode_paid_datetime
        end

        #
        # ===決済トランザクションIDを取得する
        # 決済申込時にGWで設定する処理通番
        # ※バーコード決済（店舗スキャン型）、バーコード決済（消費者スキャン型）で返却します。
        # @return:: 決済トランザクションID
        #
        def payment_txn_id
          @payment_txn_id = nil unless instance_variable_defined?(:@payment_txn_id)
          @payment_txn_id
        end

        #
        # ===決済トランザクションIDを設定する
        # @param:: payment_txn_id 決済トランザクションID
        #
        def payment_txn_id=(payment_txn_id)
          @payment_txn_id = payment_txn_id
        end

        #
        # ===リダイレクトURLを取得する
        # 支払画面を表示するためのURL
        # ※オンライン決済（V2）で返却します。
        # @return:: リダイレクトURL
        #
        def redirect_url
          @redirect_url = nil unless instance_variable_defined?(:@redirect_url)
          @redirect_url
        end

        #
        # ===リダイレクトURLを設定する
        # @param:: redirect_url リダイレクトURL
        #
        def redirect_url=(redirect_url)
          @redirect_url = redirect_url
        end

        #
        # ===楽天取引IDを取得する
        # 決済センターが取引毎に発番するID。
        # ※オンライン決済（V2）かつ、都度で返却します。
        # @return:: 楽天取引ID
        #
        def rakuten_order_id
          @rakuten_order_id = nil unless instance_variable_defined?(:@rakuten_order_id)
          @rakuten_order_id
        end

        #
        # ===楽天取引IDを設定する
        # @param:: rakuten_order_id 楽天取引ID
        #
        def rakuten_order_id=(rakuten_order_id)
          @rakuten_order_id = rakuten_order_id
        end

        #
        # ===アプリ起動URLを取得する
        # アプリ起動URL
        # ※バーコード決済（消費者スキャン型）で返却します。
        # @return:: アプリ起動URL
        #
        def deeplink
          @deeplink = nil unless instance_variable_defined?(:@deeplink)
          @deeplink
        end

        #
        # ===アプリ起動URLを設定する
        # @param:: deeplink アプリ起動URL
        #
        def deeplink=(deeplink)
          @deeplink = deeplink
        end

        #
        # ===決済期限を取得する
        # アプリ起動URLで決済を行う有効期限(YYYYMMDDHHMMSSFFF)を返却します。
        # ※バーコード決済（消費者スキャン型）で返却します。
        # @return:: 決済期限
        #
        def expire_datetime
          @expire_datetime = nil unless instance_variable_defined?(:@expire_datetime)
          @expire_datetime
        end

        #
        # ===決済期限を設定する
        # @param:: expire_datetime 決済期限
        #
        def expire_datetime=(expire_datetime)
          @expire_datetime = expire_datetime
        end

        #
        # ===決済取引IDを取得する
        # GWが取引毎に発番するID。
        # ※オンライン決済（V2）かつ、都度で返却します。
        # @return:: 決済取引ID
        #
        def gateway_order_id
          @gateway_order_id = nil unless instance_variable_defined?(:@gateway_order_id)
          @gateway_order_id
        end

        #
        # ===決済取引IDを設定する
        # @param:: gateway_order_id 決済取引ID
        #
        def gateway_order_id=(gateway_order_id)
          @gateway_order_id = gateway_order_id
        end

        #
        # ===楽天承諾時取引IDを取得する
        # 決済センターが随時決済承諾時に発番するID。
        # ※オンライン決済（V2）かつ、随時で返却します。
        # @return:: 楽天承諾時取引ID
        #
        def rakuten_consent_order_id
          @rakuten_consent_order_id = nil unless instance_variable_defined?(:@rakuten_consent_order_id)
          @rakuten_consent_order_id
        end

        #
        # ===楽天承諾時取引IDを設定する
        # @param:: rakuten_consent_order_id 楽天承諾時取引ID
        #
        def rakuten_consent_order_id=(rakuten_consent_order_id)
          @rakuten_consent_order_id = rakuten_consent_order_id
        end


        #
        # ===PayNowIDオブジェクトを取得する
        # @return:: PayNowIDオブジェクト
        #
        def pay_now_id_response
          @pay_now_id_response = nil unless instance_variable_defined?(:@pay_now_id_response)
          @pay_now_id_response
        end

        #
        # ===PayNowIDオブジェクトを設定する
        # @param:: pay_now_id_response PayNowIDオブジェクト
        #
        def pay_now_id_response=(pay_now_id_response)
          @pay_now_id_response = pay_now_id_response
        end



      end
    end
  end
end
