# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/abstract_payment_request_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：Tenpay、コマンド名：決済申込の要求Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class TenpayAuthorizeRequestDto < Veritrans::Tercerog::Mdk::AbstractPaymentRequestDto

        #
        # ===コンストラクタ
        #
        def initialize
          @service_type = SERVICE_TYPE
          @service_command = SERVICE_COMMAND
        end


        #
        # 決済サービスタイプ
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_TYPE = "tenpay"

        #
        # 決済サービスコマンド
        # 半角英数字
        # 必須項目、固定値
        #
        SERVICE_COMMAND = "Authorize"


        #
        # ===決済サービスタイプを取得する
        # @return:: 決済サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===決済サービスコマンドを取得する
        # @return:: 決済サービスコマンド
        #
        def service_command
          @service_command = nil unless instance_variable_defined?(:@service_command)
          @service_command
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # - マーチャント側で取引を一意に表す注文管理IDを指定します。
        # - 申込処理ごとに一意である必要があります。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===サービスオプションタイプを取得する
        # @return:: サービスオプションタイプ
        #
        def service_option_type
          @service_option_type = nil unless instance_variable_defined?(:@service_option_type)
          @service_option_type
        end

        #
        # ===サービスオプションタイプを設定する
        # - "barcode":バーコード決済
        # - "scancode":スキャンコード決済
        # @param:: service_option_type サービスオプションタイプ
        #
        def service_option_type=(service_option_type)
          @service_option_type = service_option_type
        end

        #
        # ===決済金額を取得する
        # @return:: 決済金額
        #
        def amount
          @amount = nil unless instance_variable_defined?(:@amount)
          @amount
        end

        #
        # ===決済金額を設定する
        # 決済金額を指定します。
        # - 1 以上かつ 9999999(7桁) 以下
        # @param:: amount 決済金額
        #
        def amount=(amount)
          @amount = amount
        end

        #
        # ===与信同時売上フラグを取得する
        # @return:: 与信同時売上フラグ
        #
        def with_capture
          @with_capture = nil unless instance_variable_defined?(:@with_capture)
          @with_capture
        end

        #
        # ===与信同時売上フラグを設定する
        # - true : 与信同時売上（設定可能な値は"true"のみです。）
        # ※未指定の場合は、true:与信同時売上。
        # @param:: with_capture 与信同時売上フラグ
        #
        def with_capture=(with_capture)
          @with_capture = with_capture
        end

        #
        # ===デバイス情報を取得する
        # @return:: デバイス情報
        #
        def device_info
          @device_info = nil unless instance_variable_defined?(:@device_info)
          @device_info
        end

        #
        # ===デバイス情報を設定する
        # デバイス情報を指定します。
        # - 最大文字数:32byte
        # @param:: device_info デバイス情報
        #
        def device_info=(device_info)
          @device_info = device_info
        end

        #
        # ===商品名を取得する
        # @return:: 商品名
        #
        def item_name
          @item_name = nil unless instance_variable_defined?(:@item_name)
          @item_name
        end

        #
        # ===商品名を設定する
        # 商品名
        # - 最大文字数：32byte
        # @param:: item_name 商品名
        #
        def item_name=(item_name)
          @item_name = item_name
        end

        #
        # ===商品詳細を取得する
        # @return:: 商品詳細
        #
        def item_detail
          @item_detail = nil unless instance_variable_defined?(:@item_detail)
          @item_detail
        end

        #
        # ===商品詳細を設定する
        # 商品詳細
        # - 最大文字数：1000byte
        # @param:: item_detail 商品詳細
        #
        def item_detail=(item_detail)
          @item_detail = item_detail
        end

        #
        # ===商品タグを取得する
        # @return:: 商品タグ
        #
        def item_label
          @item_label = nil unless instance_variable_defined?(:@item_label)
          @item_label
        end

        #
        # ===商品タグを設定する
        # 商品に付与できるタグ情報。
        # - 最大文字数:32byte
        # @param:: item_label 商品タグ
        #
        def item_label=(item_label)
          @item_label = item_label
        end

        #
        # ===承認コードを取得する
        # @return:: 承認コード
        #
        def authorization_code
          @authorization_code = nil unless instance_variable_defined?(:@authorization_code)
          @authorization_code
        end

        #
        # ===承認コードを設定する
        # バーコード決済を利用する際のQRコード、バーコードの値を指定します。
        # 
        # serviceOptionType="barcode"：指定必須
        # 上記以外、指定不可。
        # @param:: authorization_code 承認コード
        #
        def authorization_code=(authorization_code)
          @authorization_code = authorization_code
        end

        #
        # ===レスポンスタイプを取得する
        # @return:: レスポンスタイプ
        #
        def response_type
          @response_type = nil unless instance_variable_defined?(:@response_type)
          @response_type
        end

        #
        # ===レスポンスタイプを設定する
        # レスポンスのタイプを指定します。
        # "0"：取引確定時にレスポンスを返却する。
        # "1"：即時にレスポンスを返却する。
        # 
        # serviceOptionType="barcode"：指定任意
        # 上記以外、指定不可。
        # ※未指定の場合は、0：取引確定時にレスポンスを返却する。
        # @param:: response_type レスポンスタイプ
        #
        def response_type=(response_type)
          @response_type = response_type
        end

        #
        # ===店舗IDを取得する
        # @return:: 店舗ID
        #
        def store_id
          @store_id = nil unless instance_variable_defined?(:@store_id)
          @store_id
        end

        #
        # ===店舗IDを設定する
        # 店舗IDを指定します。
        # - 半角英数字、“-”（ハイフン）、“_”（アンダースコア）も使用可能です。
        # @param:: store_id 店舗ID
        #
        def store_id=(store_id)
          @store_id = store_id
        end

        #
        # ===店舗名を取得する
        # @return:: 店舗名
        #
        def store_name
          @store_name = nil unless instance_variable_defined?(:@store_name)
          @store_name
        end

        #
        # ===店舗名を設定する
        # 店舗名を指定します。
        # - 最大文字数：64byte
        # @param:: store_name 店舗名
        #
        def store_name=(store_name)
          @store_name = store_name
        end

        #
        # ===スキャンコードタイプを取得する
        # @return:: スキャンコードタイプ
        #
        def scancode_type
          @scancode_type = nil unless instance_variable_defined?(:@scancode_type)
          @scancode_type
        end

        #
        # ===スキャンコードタイプを設定する
        # シーンのタイプを指定します。
        # "0"：サービスプロバイダー発行QR利用。
        # "1"：加盟店発行QR利用。
        # 
        # serviceOptionType="scancode"：指定任意
        # 上記以外、指定不可。
        # ※未指定の場合は、0：サービスプロバイダー発行QR利用。
        # @param:: scancode_type スキャンコードタイプ
        #
        def scancode_type=(scancode_type)
          @scancode_type = scancode_type
        end

        #
        # ===製品IDを取得する
        # @return:: 製品ID
        #
        def product_id
          @product_id = nil unless instance_variable_defined?(:@product_id)
          @product_id
        end

        #
        # ===製品IDを設定する
        # 製品IDを指定します。
        # - 最大文字数：32byte
        # 
        # serviceOptionType="scancode"、かつ、scancodeType="0"：指定必須
        # 上記以外、指定不可。
        # @param:: product_id 製品ID
        #
        def product_id=(product_id)
          @product_id = product_id
        end

        #
        # ===ユーザータグを取得する
        # @return:: ユーザータグ
        #
        def openid
          @openid = nil unless instance_variable_defined?(:@openid)
          @openid
        end

        #
        # ===ユーザータグを設定する
        # ユーザータグを指定します。
        # 
        # serviceOptionType="scancode"、かつ、scancodeType="1"：指定任意
        # ※subOpenidが未指定の場合は指定必須。
        # 上記以外、指定不可。
        # @param:: openid ユーザータグ
        #
        def openid=(openid)
          @openid = openid
        end

        #
        # ===サブユーザータグを取得する
        # @return:: サブユーザータグ
        #
        def sub_openid
          @sub_openid = nil unless instance_variable_defined?(:@sub_openid)
          @sub_openid
        end

        #
        # ===サブユーザータグを設定する
        # サブユーザータグを指定します。
        # 
        # serviceOptionType="scancode"、かつ、scancodeType="1"：指定任意
        # ※openidが未指定の場合は指定必須。
        # 上記以外、指定不可。
        # @param:: sub_openid サブユーザータグ
        #
        def sub_openid=(sub_openid)
          @sub_openid = sub_openid
        end

        #
        # ===決済完了時URLを取得する
        # @return:: 決済完了時URL
        #
        def success_url
          @success_url = nil unless instance_variable_defined?(:@success_url)
          @success_url
        end

        #
        # ===決済完了時URLを設定する
        # 決済完了後に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # serviceOptionType="scancode"、かつ、scancodeType="1"：指定任意
        # 上記以外、指定不可。
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: success_url 決済完了時URL
        #
        def success_url=(success_url)
          @success_url = success_url
        end

        #
        # ===決済キャンセル時URLを取得する
        # @return:: 決済キャンセル時URL
        #
        def cancel_url
          @cancel_url = nil unless instance_variable_defined?(:@cancel_url)
          @cancel_url
        end

        #
        # ===決済キャンセル時URLを設定する
        # 決済キャンセル時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # serviceOptionType="scancode"、かつ、scancodeType="1"：指定任意
        # 上記以外、指定不可。
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: cancel_url 決済キャンセル時URL
        #
        def cancel_url=(cancel_url)
          @cancel_url = cancel_url
        end

        #
        # ===決済エラー時URLを取得する
        # @return:: 決済エラー時URL
        #
        def error_url
          @error_url = nil unless instance_variable_defined?(:@error_url)
          @error_url
        end

        #
        # ===決済エラー時URLを設定する
        # 決済失敗時に、店舗側サイトに画面遷移を戻すためのURLを指定します。
        # 
        # serviceOptionType="scancode"、かつ、scancodeType="1"：指定任意
        # 上記以外、指定不可。
        # ※ 未指定の場合は、マーチャント登録時に設定した値を使用
        # @param:: error_url 決済エラー時URL
        #
        def error_url=(error_url)
          @error_url = error_url
        end


      end
    end
  end
end
