# -*- encoding: utf-8 -*-
require 'tg_mdk/mdk_dto/response_base_dto'

module Veritrans
  module Tercerog
    module Mdk

      #
      # =決済サービスタイプ：UPOP、コマンド名：売上の応答Dtoクラス
      #
      # @author:: VeriTrans Inc.
      #
      class UpopCaptureResponseDto < Veritrans::Tercerog::Mdk::ResponseBaseDto

        #
        # ===サービスタイプを取得する
        # 決済サービスの区分を返却します。
        # - "upop"： 銀聯ネット決済（UPOP）
        # @return:: サービスタイプ
        #
        def service_type
          @service_type = nil unless instance_variable_defined?(:@service_type)
          @service_type
        end

        #
        # ===サービスタイプを設定する
        # 決済サービスの区分を返却します。
        # - "upop"： 銀聯ネット決済（UPOP）
        # @param:: service_type サービスタイプ
        #
        def service_type=(service_type)
          @service_type = service_type
        end

        #
        # ===処理結果コードを取得する
        # 決済請求処理後、応答電文に含まれる値。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # - pending：保留状態
        # @return:: 処理結果コード
        #
        def mstatus
          @mstatus = nil unless instance_variable_defined?(:@mstatus)
          @mstatus
        end

        #
        # ===処理結果コードを設定する
        # 決済請求処理後、応答電文に含まれる値。
        # 以下の処理結果のいずれかが格納される
        # - success：正常終了
        # - failure：異常終了
        # - pending：保留状態
        # @param:: mstatus 処理結果コード
        #
        def mstatus=(mstatus)
          @mstatus = mstatus
        end

        #
        # ===詳細結果コードを取得する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @return:: 詳細結果コード
        #
        def v_result_code
          @v_result_code = nil unless instance_variable_defined?(:@v_result_code)
          @v_result_code
        end

        #
        # ===詳細結果コードを設定する
        # 処理結果を詳細に表すコードを返却します。
        # 
        # 4桁ずつ4つのブロックで構成され、各ブロックでサービス毎の処理結果を表します。
        # @param:: v_result_code 詳細結果コード
        #
        def v_result_code=(v_result_code)
          @v_result_code = v_result_code
        end

        #
        # ===エラーメッセージを取得する
        # 処理結果に対するメッセージを返却します。
        # @return:: エラーメッセージ
        #
        def merr_msg
          @merr_msg = nil unless instance_variable_defined?(:@merr_msg)
          @merr_msg
        end

        #
        # ===エラーメッセージを設定する
        # 処理結果に対するメッセージを返却します。
        # @param:: merr_msg エラーメッセージ
        #
        def merr_msg=(merr_msg)
          @merr_msg = merr_msg
        end

        #
        # ===トランザクションID(取引毎につけるID)を取得する
        # @return:: トランザクションID(取引毎につけるID)
        #
        def cust_txn
          @cust_txn = nil unless instance_variable_defined?(:@cust_txn)
          @cust_txn
        end

        #
        # ===トランザクションID(取引毎につけるID)を設定する
        # @param:: cust_txn トランザクションID(取引毎につけるID)
        #
        def cust_txn=(cust_txn)
          @cust_txn = cust_txn
        end

        #
        # ===電文IDを取得する
        # @return:: 電文ID
        #
        def march_txn
          @march_txn = nil unless instance_variable_defined?(:@march_txn)
          @march_txn
        end

        #
        # ===電文IDを設定する
        # @param:: march_txn 電文ID
        #
        def march_txn=(march_txn)
          @march_txn = march_txn
        end

        #
        # ===取引IDを取得する
        # @return:: 取引ID
        #
        def order_id
          @order_id = nil unless instance_variable_defined?(:@order_id)
          @order_id
        end

        #
        # ===取引IDを設定する
        # @param:: order_id 取引ID
        #
        def order_id=(order_id)
          @order_id = order_id
        end

        #
        # ===MDKバージョンを取得する
        # 電文のバージョン番号を返却します。
        # @return:: MDKバージョン
        #
        def txn_version
          @txn_version = nil unless instance_variable_defined?(:@txn_version)
          @txn_version
        end

        #
        # ===MDKバージョンを設定する
        # 電文のバージョン番号を返却します。
        # @param:: txn_version MDKバージョン
        #
        def txn_version=(txn_version)
          @txn_version = txn_version
        end

        #
        # ===決済時刻（日本時間）を取得する
        # 銀聯ネット決済（UPOP）で売上が確定した日時（日本時間）を返します。
        # @return:: 決済時刻（日本時間）
        #
        def txn_datetime_jp
          @txn_datetime_jp = nil unless instance_variable_defined?(:@txn_datetime_jp)
          @txn_datetime_jp
        end

        #
        # ===決済時刻（日本時間）を設定する
        # 銀聯ネット決済（UPOP）で売上が確定した日時（日本時間）を返します。
        # @param:: txn_datetime_jp 決済時刻（日本時間）
        #
        def txn_datetime_jp=(txn_datetime_jp)
          @txn_datetime_jp = txn_datetime_jp
        end

        #
        # ===決済時刻（中国時間）を取得する
        # 銀聯ネット決済（UPOP）で売上が確定した日時（中国時間）を返します。
        # @return:: 決済時刻（中国時間）
        #
        def txn_datetime_cn
          @txn_datetime_cn = nil unless instance_variable_defined?(:@txn_datetime_cn)
          @txn_datetime_cn
        end

        #
        # ===決済時刻（中国時間）を設定する
        # 銀聯ネット決済（UPOP）で売上が確定した日時（中国時間）を返します。
        # @param:: txn_datetime_cn 決済時刻（中国時間）
        #
        def txn_datetime_cn=(txn_datetime_cn)
          @txn_datetime_cn = txn_datetime_cn
        end

        #
        # ===売上金額を取得する
        # 売上金額
        # @return:: 売上金額
        #
        def captured_amount
          @captured_amount = nil unless instance_variable_defined?(:@captured_amount)
          @captured_amount
        end

        #
        # ===売上金額を設定する
        # 売上金額
        # @param:: captured_amount 売上金額
        #
        def captured_amount=(captured_amount)
          @captured_amount = captured_amount
        end

        #
        # ===返品後の金額を取得する
        # 返品後の金額
        # @return:: 返品後の金額
        #
        def remaining_amount
          @remaining_amount = nil unless instance_variable_defined?(:@remaining_amount)
          @remaining_amount
        end

        #
        # ===返品後の金額を設定する
        # 返品後の金額
        # @param:: remaining_amount 返品後の金額
        #
        def remaining_amount=(remaining_amount)
          @remaining_amount = remaining_amount
        end

        #
        # ===清算金額を取得する
        # 清算金額
        # @return:: 清算金額
        #
        def settle_amount
          @settle_amount = nil unless instance_variable_defined?(:@settle_amount)
          @settle_amount
        end

        #
        # ===清算金額を設定する
        # 清算金額
        # @param:: settle_amount 清算金額
        #
        def settle_amount=(settle_amount)
          @settle_amount = settle_amount
        end

        #
        # ===清算日付を取得する
        # 清算日付（MMDD形式）
        # @return:: 清算日付
        #
        def settle_date
          @settle_date = nil unless instance_variable_defined?(:@settle_date)
          @settle_date
        end

        #
        # ===清算日付を設定する
        # 清算日付（MMDD形式）
        # @param:: settle_date 清算日付
        #
        def settle_date=(settle_date)
          @settle_date = settle_date
        end

        #
        # ===清算通貨種類を取得する
        # 清算通貨種類
        # 392：日本円（固定）
        # @return:: 清算通貨種類
        #
        def settle_currency
          @settle_currency = nil unless instance_variable_defined?(:@settle_currency)
          @settle_currency
        end

        #
        # ===清算通貨種類を設定する
        # 清算通貨種類
        # 392：日本円（固定）
        # @param:: settle_currency 清算通貨種類
        #
        def settle_currency=(settle_currency)
          @settle_currency = settle_currency
        end

        #
        # ===清算レートを取得する
        # 清算レート
        # @return:: 清算レート
        #
        def settle_rate
          @settle_rate = nil unless instance_variable_defined?(:@settle_rate)
          @settle_rate
        end

        #
        # ===清算レートを設定する
        # 清算レート
        # @param:: settle_rate 清算レート
        #
        def settle_rate=(settle_rate)
          @settle_rate = settle_rate
        end

        #
        # ===決済センターとの取引IDを取得する
        # 決済センターとの取引ID
        # @return:: 決済センターとの取引ID
        #
        def upop_order_id
          @upop_order_id = nil unless instance_variable_defined?(:@upop_order_id)
          @upop_order_id
        end

        #
        # ===決済センターとの取引IDを設定する
        # 決済センターとの取引ID
        # @param:: upop_order_id 決済センターとの取引ID
        #
        def upop_order_id=(upop_order_id)
          @upop_order_id = upop_order_id
        end


        #
        # ===PayNowIDオブジェクトを取得する
        # @return:: PayNowIDオブジェクト
        #
        def pay_now_id_response
          @pay_now_id_response = nil unless instance_variable_defined?(:@pay_now_id_response)
          @pay_now_id_response
        end

        #
        # ===PayNowIDオブジェクトを設定する
        # @param:: pay_now_id_response PayNowIDオブジェクト
        #
        def pay_now_id_response=(pay_now_id_response)
          @pay_now_id_response = pay_now_id_response
        end

      end
    end
  end
end
